Class: Google::Apis::DataflowV1b3::AutoscalingSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

A schedule for autoscaling.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalingSchedule

Returns a new instance of AutoscalingSchedule.



234
235
236
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crontabString

Optional. A crontab specification of when this schedule should trigger applying overrides. The overrides will be applied from the trigger time until the specified duration elapses. Corresponds to the JSON property crontab

Returns:

  • (String)


197
198
199
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 197

def crontab
  @crontab
end

#durationString

Optional. The duration for which the parameter overrides for this schedule will be applied when triggered by the crontab. Corresponds to the JSON property duration

Returns:

  • (String)


203
204
205
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 203

def duration
  @duration
end

#nameString

Optional. The name of the schedule. Corresponds to the JSON property name

Returns:

  • (String)


208
209
210
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 208

def name
  @name
end

#parametersGoogle::Apis::DataflowV1b3::Parameters

The parameters to use for autoscaling when this schedule is active. Corresponds to the JSON property parameters



213
214
215
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 213

def parameters
  @parameters
end

#priorityFixnum

Optional. Specifies the priority of the schedule. If two schedules overlap, the one with the higher priority will be used. The higher the value, the higher the priority of the schedule. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


220
221
222
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 220

def priority
  @priority
end

#time_zoneString

Optional. The time zone for the schedule. The value of this field must be a time zone name from the tz database . The default value is UTC. Corresponds to the JSON property timeZone

Returns:

  • (String)


227
228
229
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 227

def time_zone
  @time_zone
end

#update_timeString

Output only. When the customer last updated the schedule. Corresponds to the JSON property updateTime

Returns:

  • (String)


232
233
234
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 232

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



239
240
241
242
243
244
245
246
247
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 239

def update!(**args)
  @crontab = args[:crontab] if args.key?(:crontab)
  @duration = args[:duration] if args.key?(:duration)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @priority = args[:priority] if args.key?(:priority)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @update_time = args[:update_time] if args.key?(:update_time)
end