Class: Google::Apis::DataflowV1b3::CounterStructuredName
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::CounterStructuredName
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Identifies a counter within a per-job namespace. Counters whose structured names are the same get merged into a single value for the job.
Instance Attribute Summary collapse
-
#component_step_name ⇒ String
Name of the optimized step being executed by the workers.
-
#execution_step_name ⇒ String
Name of the stage.
-
#input_index ⇒ Fixnum
Index of an input collection that's being read from/written to as a side input.
-
#name ⇒ String
Counter name.
-
#origin ⇒ String
One of the standard Origins defined above.
-
#origin_namespace ⇒ String
A string containing a more specific namespace of the counter's origin.
-
#original_requesting_step_name ⇒ String
The step name requesting an operation, such as GBK.
-
#original_step_name ⇒ String
System generated name of the original step in the user's graph, before optimization.
-
#portion ⇒ String
Portion of this counter, either key or value.
-
#worker_id ⇒ String
ID of a particular worker.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CounterStructuredName
constructor
A new instance of CounterStructuredName.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CounterStructuredName
Returns a new instance of CounterStructuredName.
787 788 789 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#component_step_name ⇒ String
Name of the optimized step being executed by the workers.
Corresponds to the JSON property componentStepName
733 734 735 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 733 def component_step_name @component_step_name end |
#execution_step_name ⇒ String
Name of the stage. An execution step contains multiple component steps.
Corresponds to the JSON property executionStepName
738 739 740 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 738 def execution_step_name @execution_step_name end |
#input_index ⇒ Fixnum
Index of an input collection that's being read from/written to as a side input.
The index identifies a step's side inputs starting by 1 (e.g. the first side
input has input_index 1, the third has input_index 3). Side inputs are
identified by a pair of (original_step_name, input_index). This field helps
uniquely identify them.
Corresponds to the JSON property inputIndex
747 748 749 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 747 def input_index @input_index end |
#name ⇒ String
Counter name. Not necessarily globally-unique, but unique within the context
of the other fields. Required.
Corresponds to the JSON property name
753 754 755 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 753 def name @name end |
#origin ⇒ String
One of the standard Origins defined above.
Corresponds to the JSON property origin
758 759 760 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 758 def origin @origin end |
#origin_namespace ⇒ String
A string containing a more specific namespace of the counter's origin.
Corresponds to the JSON property originNamespace
763 764 765 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 763 def origin_namespace @origin_namespace end |
#original_requesting_step_name ⇒ String
The step name requesting an operation, such as GBK. I.e. the ParDo causing a
read/write from shuffle to occur, or a read from side inputs.
Corresponds to the JSON property originalRequestingStepName
769 770 771 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 769 def original_requesting_step_name @original_requesting_step_name end |
#original_step_name ⇒ String
System generated name of the original step in the user's graph, before
optimization.
Corresponds to the JSON property originalStepName
775 776 777 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 775 def original_step_name @original_step_name end |
#portion ⇒ String
Portion of this counter, either key or value.
Corresponds to the JSON property portion
780 781 782 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 780 def portion @portion end |
#worker_id ⇒ String
ID of a particular worker.
Corresponds to the JSON property workerId
785 786 787 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 785 def worker_id @worker_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
792 793 794 795 796 797 798 799 800 801 802 803 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 792 def update!(**args) @component_step_name = args[:component_step_name] if args.key?(:component_step_name) @execution_step_name = args[:execution_step_name] if args.key?(:execution_step_name) @input_index = args[:input_index] if args.key?(:input_index) @name = args[:name] if args.key?(:name) @origin = args[:origin] if args.key?(:origin) @origin_namespace = args[:origin_namespace] if args.key?(:origin_namespace) @original_requesting_step_name = args[:original_requesting_step_name] if args.key?(:original_requesting_step_name) @original_step_name = args[:original_step_name] if args.key?(:original_step_name) @portion = args[:portion] if args.key?(:portion) @worker_id = args[:worker_id] if args.key?(:worker_id) end |