Class: Google::Apis::DataflowV1b3::DataSamplingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Configuration options for sampling elements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSamplingConfig

Returns a new instance of DataSamplingConfig.



1057
1058
1059
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorsArray<String>

List of given sampling behaviors to enable. For example, specifying behaviors = [ALWAYS_ON] samples in-flight elements but does not sample exceptions. Can be used to specify multiple behaviors like, behaviors = [ALWAYS_ON, EXCEPTIONS] for specifying periodic sampling and exception sampling. If DISABLED is in the list, then sampling will be disabled and ignore the other given behaviors. Ordering does not matter. Corresponds to the JSON property behaviors

Returns:

  • (Array<String>)


1055
1056
1057
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1055

def behaviors
  @behaviors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1062
1063
1064
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1062

def update!(**args)
  @behaviors = args[:behaviors] if args.key?(:behaviors)
end