Class: Google::Apis::DataflowV1b3::DataSamplingReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Contains per-worker telemetry about the data sampling feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSamplingReport

Returns a new instance of DataSamplingReport.



1109
1110
1111
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1109

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bytes_written_deltaFixnum

Optional. Delta of bytes written to file from previous report. Corresponds to the JSON property bytesWrittenDelta

Returns:

  • (Fixnum)


1074
1075
1076
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1074

def bytes_written_delta
  @bytes_written_delta
end

#elements_sampled_bytesFixnum

Optional. Delta of bytes sampled from previous report. Corresponds to the JSON property elementsSampledBytes

Returns:

  • (Fixnum)


1079
1080
1081
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1079

def elements_sampled_bytes
  @elements_sampled_bytes
end

#elements_sampled_countFixnum

Optional. Delta of number of elements sampled from previous report. Corresponds to the JSON property elementsSampledCount

Returns:

  • (Fixnum)


1084
1085
1086
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1084

def elements_sampled_count
  @elements_sampled_count
end

#exceptions_sampled_countFixnum

Optional. Delta of number of samples taken from user code exceptions from previous report. Corresponds to the JSON property exceptionsSampledCount

Returns:

  • (Fixnum)


1090
1091
1092
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1090

def exceptions_sampled_count
  @exceptions_sampled_count
end

#pcollections_sampled_countFixnum

Optional. Delta of number of PCollections sampled from previous report. Corresponds to the JSON property pcollectionsSampledCount

Returns:

  • (Fixnum)


1095
1096
1097
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1095

def pcollections_sampled_count
  @pcollections_sampled_count
end

#persistence_errors_countFixnum

Optional. Delta of errors counts from persisting the samples from previous report. Corresponds to the JSON property persistenceErrorsCount

Returns:

  • (Fixnum)


1101
1102
1103
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1101

def persistence_errors_count
  @persistence_errors_count
end

#translation_errors_countFixnum

Optional. Delta of errors counts from retrieving, or translating the samples from previous report. Corresponds to the JSON property translationErrorsCount

Returns:

  • (Fixnum)


1107
1108
1109
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1107

def translation_errors_count
  @translation_errors_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1114
1115
1116
1117
1118
1119
1120
1121
1122
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1114

def update!(**args)
  @bytes_written_delta = args[:bytes_written_delta] if args.key?(:bytes_written_delta)
  @elements_sampled_bytes = args[:elements_sampled_bytes] if args.key?(:elements_sampled_bytes)
  @elements_sampled_count = args[:elements_sampled_count] if args.key?(:elements_sampled_count)
  @exceptions_sampled_count = args[:exceptions_sampled_count] if args.key?(:exceptions_sampled_count)
  @pcollections_sampled_count = args[:pcollections_sampled_count] if args.key?(:pcollections_sampled_count)
  @persistence_errors_count = args[:persistence_errors_count] if args.key?(:persistence_errors_count)
  @translation_errors_count = args[:translation_errors_count] if args.key?(:translation_errors_count)
end