Class: Google::Apis::DataflowV1b3::DataflowHistogramValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Summary statistics for a population of values. HistogramValue contains a sequence of buckets and gives a count of values that fall into each bucket. Bucket boundares are defined by a formula and bucket widths are either fixed or exponentially increasing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataflowHistogramValue

Returns a new instance of DataflowHistogramValue.



1180
1181
1182
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_countsArray<Fixnum>

Optional. The number of values in each bucket of the histogram, as described in bucket_options. bucket_counts should contain N values, where N is the number of buckets specified in bucket_options. If bucket_counts has fewer than N values, the remaining values are assumed to be 0. Corresponds to the JSON property bucketCounts

Returns:

  • (Array<Fixnum>)


1163
1164
1165
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1163

def bucket_counts
  @bucket_counts
end

#bucket_optionsGoogle::Apis::DataflowV1b3::BucketOptions

BucketOptions describes the bucket boundaries used in the histogram. Corresponds to the JSON property bucketOptions



1168
1169
1170
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1168

def bucket_options
  @bucket_options
end

#countFixnum

Number of values recorded in this histogram. Corresponds to the JSON property count

Returns:

  • (Fixnum)


1173
1174
1175
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1173

def count
  @count
end

#outlier_statsGoogle::Apis::DataflowV1b3::OutlierStats

Statistics for the underflow and overflow bucket. Corresponds to the JSON property outlierStats



1178
1179
1180
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1178

def outlier_stats
  @outlier_stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1185
1186
1187
1188
1189
1190
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1185

def update!(**args)
  @bucket_counts = args[:bucket_counts] if args.key?(:bucket_counts)
  @bucket_options = args[:bucket_options] if args.key?(:bucket_options)
  @count = args[:count] if args.key?(:count)
  @outlier_stats = args[:outlier_stats] if args.key?(:outlier_stats)
end