Class: Google::Apis::DataflowV1b3::DebugOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Describes any options that have an effect on the debugging of pipelines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DebugOptions

Returns a new instance of DebugOptions.



1234
1235
1236
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_samplingGoogle::Apis::DataflowV1b3::DataSamplingConfig

Configuration options for sampling elements. Corresponds to the JSON property dataSampling



1225
1226
1227
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1225

def data_sampling
  @data_sampling
end

#enable_hot_key_loggingBoolean Also known as: enable_hot_key_logging?

Optional. When true, enables the logging of the literal hot key to the user's Cloud Logging. Corresponds to the JSON property enableHotKeyLogging

Returns:

  • (Boolean)


1231
1232
1233
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1231

def enable_hot_key_logging
  @enable_hot_key_logging
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1239
1240
1241
1242
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1239

def update!(**args)
  @data_sampling = args[:data_sampling] if args.key?(:data_sampling)
  @enable_hot_key_logging = args[:enable_hot_key_logging] if args.key?(:enable_hot_key_logging)
end