Class: Google::Apis::DataflowV1b3::DisplayData
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::DisplayData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Data provided with a pipeline or transform to provide descriptive info.
Instance Attribute Summary collapse
-
#bool_value ⇒ Boolean
(also: #bool_value?)
Contains value if the data is of a boolean type.
-
#duration_value ⇒ String
Contains value if the data is of duration type.
-
#float_value ⇒ Float
Contains value if the data is of float type.
-
#int64_value ⇒ Fixnum
Contains value if the data is of int64 type.
-
#java_class_value ⇒ String
Contains value if the data is of java class type.
-
#key ⇒ String
The key identifying the display data.
-
#label ⇒ String
An optional label to display in a dax UI for the element.
-
#namespace ⇒ String
The namespace for the key.
-
#short_str_value ⇒ String
A possible additional shorter value to display.
-
#str_value ⇒ String
Contains value if the data is of string type.
-
#timestamp_value ⇒ String
Contains value if the data is of timestamp type.
-
#url ⇒ String
An optional full URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DisplayData
constructor
A new instance of DisplayData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DisplayData
Returns a new instance of DisplayData.
1401 1402 1403 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bool_value ⇒ Boolean Also known as: bool_value?
Contains value if the data is of a boolean type.
Corresponds to the JSON property boolValue
1335 1336 1337 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1335 def bool_value @bool_value end |
#duration_value ⇒ String
Contains value if the data is of duration type.
Corresponds to the JSON property durationValue
1341 1342 1343 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1341 def duration_value @duration_value end |
#float_value ⇒ Float
Contains value if the data is of float type.
Corresponds to the JSON property floatValue
1346 1347 1348 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1346 def float_value @float_value end |
#int64_value ⇒ Fixnum
Contains value if the data is of int64 type.
Corresponds to the JSON property int64Value
1351 1352 1353 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1351 def int64_value @int64_value end |
#java_class_value ⇒ String
Contains value if the data is of java class type.
Corresponds to the JSON property javaClassValue
1356 1357 1358 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1356 def java_class_value @java_class_value end |
#key ⇒ String
The key identifying the display data. This is intended to be used as a label
for the display data when viewed in a dax monitoring system.
Corresponds to the JSON property key
1362 1363 1364 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1362 def key @key end |
#label ⇒ String
An optional label to display in a dax UI for the element.
Corresponds to the JSON property label
1367 1368 1369 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1367 def label @label end |
#namespace ⇒ String
The namespace for the key. This is usually a class name or programming
language namespace (i.e. python module) which defines the display data. This
allows a dax monitoring system to specially handle the data and perform custom
rendering.
Corresponds to the JSON property namespace
1375 1376 1377 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1375 def namespace @namespace end |
#short_str_value ⇒ String
A possible additional shorter value to display. For example a
java_class_name_value of com.mypackage.MyDoFn will be stored with MyDoFn as
the short_str_value and com.mypackage.MyDoFn as the java_class_name value.
short_str_value can be displayed and java_class_name_value will be displayed
as a tooltip.
Corresponds to the JSON property shortStrValue
1384 1385 1386 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1384 def short_str_value @short_str_value end |
#str_value ⇒ String
Contains value if the data is of string type.
Corresponds to the JSON property strValue
1389 1390 1391 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1389 def str_value @str_value end |
#timestamp_value ⇒ String
Contains value if the data is of timestamp type.
Corresponds to the JSON property timestampValue
1394 1395 1396 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1394 def @timestamp_value end |
#url ⇒ String
An optional full URL.
Corresponds to the JSON property url
1399 1400 1401 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1399 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1406 def update!(**args) @bool_value = args[:bool_value] if args.key?(:bool_value) @duration_value = args[:duration_value] if args.key?(:duration_value) @float_value = args[:float_value] if args.key?(:float_value) @int64_value = args[:int64_value] if args.key?(:int64_value) @java_class_value = args[:java_class_value] if args.key?(:java_class_value) @key = args[:key] if args.key?(:key) @label = args[:label] if args.key?(:label) @namespace = args[:namespace] if args.key?(:namespace) @short_str_value = args[:short_str_value] if args.key?(:short_str_value) @str_value = args[:str_value] if args.key?(:str_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) @url = args[:url] if args.key?(:url) end |