Class: Google::Apis::DataflowV1b3::DistributionUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

A metric value representing a distribution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DistributionUpdate

Returns a new instance of DistributionUpdate.



1464
1465
1466
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property count



1430
1431
1432
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1430

def count
  @count
end

#histogramGoogle::Apis::DataflowV1b3::Histogram

Histogram of value counts for a distribution. Buckets have an inclusive lower bound and exclusive upper bound and use "1,2,5 bucketing": The first bucket range is from [0,1) and all subsequent bucket boundaries are powers of ten multiplied by 1, 2, or 5. Thus, bucket boundaries are 0, 1, 2, 5, 10, 20, 50, 100, 200, 500, 1000, ... Negative values are not supported. Corresponds to the JSON property histogram



1439
1440
1441
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1439

def histogram
  @histogram
end

#maxGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property max



1445
1446
1447
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1445

def max
  @max
end

#minGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property min



1451
1452
1453
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1451

def min
  @min
end

#sumGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property sum



1457
1458
1459
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1457

def sum
  @sum
end

#sum_of_squaresFloat

Use a double since the sum of squares is likely to overflow int64. Corresponds to the JSON property sumOfSquares

Returns:

  • (Float)


1462
1463
1464
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1462

def sum_of_squares
  @sum_of_squares
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1469

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @histogram = args[:histogram] if args.key?(:histogram)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @sum = args[:sum] if args.key?(:sum)
  @sum_of_squares = args[:sum_of_squares] if args.key?(:sum_of_squares)
end