Class: Google::Apis::DataflowV1b3::ExecutionStageSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Description of the composing transforms, names/ids, and input/outputs of a stage of execution. Some composing transforms and sources may have been generated by the Dataflow service during execution planning.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecutionStageSummary

Returns a new instance of ExecutionStageSummary.



1755
1756
1757
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_sourceArray<Google::Apis::DataflowV1b3::ComponentSource>

Collections produced and consumed by component transforms of this stage. Corresponds to the JSON property componentSource



1718
1719
1720
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1718

def component_source
  @component_source
end

#component_transformArray<Google::Apis::DataflowV1b3::ComponentTransform>

Transforms that comprise this execution stage. Corresponds to the JSON property componentTransform



1723
1724
1725
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1723

def component_transform
  @component_transform
end

#idString

Dataflow service generated id for this stage. Corresponds to the JSON property id

Returns:

  • (String)


1728
1729
1730
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1728

def id
  @id
end

#input_sourceArray<Google::Apis::DataflowV1b3::StageSource>

Input sources for this stage. Corresponds to the JSON property inputSource



1733
1734
1735
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1733

def input_source
  @input_source
end

#kindString

Type of transform this stage is executing. Corresponds to the JSON property kind

Returns:

  • (String)


1738
1739
1740
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1738

def kind
  @kind
end

#nameString

Dataflow service generated name for this stage. Corresponds to the JSON property name

Returns:

  • (String)


1743
1744
1745
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1743

def name
  @name
end

#output_sourceArray<Google::Apis::DataflowV1b3::StageSource>

Output sources for this stage. Corresponds to the JSON property outputSource



1748
1749
1750
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1748

def output_source
  @output_source
end

#prerequisite_stageArray<String>

Other stages that must complete before this stage can run. Corresponds to the JSON property prerequisiteStage

Returns:

  • (Array<String>)


1753
1754
1755
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1753

def prerequisite_stage
  @prerequisite_stage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 1760

def update!(**args)
  @component_source = args[:component_source] if args.key?(:component_source)
  @component_transform = args[:component_transform] if args.key?(:component_transform)
  @id = args[:id] if args.key?(:id)
  @input_source = args[:input_source] if args.key?(:input_source)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @output_source = args[:output_source] if args.key?(:output_source)
  @prerequisite_stage = args[:prerequisite_stage] if args.key?(:prerequisite_stage)
end