Class: Google::Apis::DataflowV1b3::FloatingPointMean
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::FloatingPointMean
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
A representation of a floating point mean metric contribution.
Instance Attribute Summary collapse
-
#count ⇒ Google::Apis::DataflowV1b3::SplitInt64
A representation of an int64, n, that is immune to precision loss when encoded in JSON.
-
#sum ⇒ Float
The sum of all values being aggregated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FloatingPointMean
constructor
A new instance of FloatingPointMean.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FloatingPointMean
Returns a new instance of FloatingPointMean.
2015 2016 2017 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Google::Apis::DataflowV1b3::SplitInt64
A representation of an int64, n, that is immune to precision loss when encoded
in JSON.
Corresponds to the JSON property count
2008 2009 2010 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2008 def count @count end |
#sum ⇒ Float
The sum of all values being aggregated.
Corresponds to the JSON property sum
2013 2014 2015 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2013 def sum @sum end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2020 2021 2022 2023 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2020 def update!(**args) @count = args[:count] if args.key?(:count) @sum = args[:sum] if args.key?(:sum) end |