Class: Google::Apis::DataflowV1b3::GetDebugConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Request to get updated debug configuration for component.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetDebugConfigRequest

Returns a new instance of GetDebugConfigRequest.



2091
2092
2093
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_idString

The internal component id for which debug configuration is requested. Corresponds to the JSON property componentId

Returns:

  • (String)


2078
2079
2080
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2078

def component_id
  @component_id
end

#locationString

The regional endpoint that contains the job specified by job_id. Corresponds to the JSON property location

Returns:

  • (String)


2084
2085
2086
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2084

def location
  @location
end

#worker_idString

The worker id, i.e., VM hostname. Corresponds to the JSON property workerId

Returns:

  • (String)


2089
2090
2091
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2089

def worker_id
  @worker_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2096
2097
2098
2099
2100
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2096

def update!(**args)
  @component_id = args[:component_id] if args.key?(:component_id)
  @location = args[:location] if args.key?(:location)
  @worker_id = args[:worker_id] if args.key?(:worker_id)
end