Class: Google::Apis::DataflowV1b3::GetTemplateResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::GetTemplateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
The response to a GetTemplate request.
Instance Attribute Summary collapse
-
#metadata ⇒ Google::Apis::DataflowV1b3::TemplateMetadata
Metadata describing a template.
-
#runtime_metadata ⇒ Google::Apis::DataflowV1b3::RuntimeMetadata
RuntimeMetadata describing a runtime environment.
-
#status ⇒ Google::Apis::DataflowV1b3::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#template_type ⇒ String
Template Type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetTemplateResponse
constructor
A new instance of GetTemplateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetTemplateResponse
Returns a new instance of GetTemplateResponse.
2213 2214 2215 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata ⇒ Google::Apis::DataflowV1b3::TemplateMetadata
Metadata describing a template.
Corresponds to the JSON property metadata
2191 2192 2193 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2191 def @metadata end |
#runtime_metadata ⇒ Google::Apis::DataflowV1b3::RuntimeMetadata
RuntimeMetadata describing a runtime environment.
Corresponds to the JSON property runtimeMetadata
2196 2197 2198 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2196 def @runtime_metadata end |
#status ⇒ Google::Apis::DataflowV1b3::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
2206 2207 2208 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2206 def status @status end |
#template_type ⇒ String
Template Type.
Corresponds to the JSON property templateType
2211 2212 2213 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2211 def template_type @template_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2218 2219 2220 2221 2222 2223 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2218 def update!(**args) @metadata = args[:metadata] if args.key?(:metadata) @runtime_metadata = args[:runtime_metadata] if args.key?(:runtime_metadata) @status = args[:status] if args.key?(:status) @template_type = args[:template_type] if args.key?(:template_type) end |