Class: Google::Apis::DataflowV1b3::HotKeyDetection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Proto describing a hot key detected on a given WorkItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HotKeyDetection

Returns a new instance of HotKeyDetection.



2345
2346
2347
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hot_key_ageString

The age of the hot key measured from when it was first detected. Corresponds to the JSON property hotKeyAge

Returns:

  • (String)


2332
2333
2334
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2332

def hot_key_age
  @hot_key_age
end

#system_nameString

System-defined name of the step containing this hot key. Unique across the workflow. Corresponds to the JSON property systemName

Returns:

  • (String)


2338
2339
2340
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2338

def system_name
  @system_name
end

#user_step_nameString

User-provided name of the step that contains this hot key. Corresponds to the JSON property userStepName

Returns:

  • (String)


2343
2344
2345
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2343

def user_step_name
  @user_step_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2350
2351
2352
2353
2354
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2350

def update!(**args)
  @hot_key_age = args[:hot_key_age] if args.key?(:hot_key_age)
  @system_name = args[:system_name] if args.key?(:system_name)
  @user_step_name = args[:user_step_name] if args.key?(:user_step_name)
end