Class: Google::Apis::DataflowV1b3::InstructionInput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

An input of an instruction, as a reference to an output of a producer instruction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstructionInput

Returns a new instance of InstructionInput.



2409
2410
2411
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_numFixnum

The output index (origin zero) within the producer. Corresponds to the JSON property outputNum

Returns:

  • (Fixnum)


2400
2401
2402
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2400

def output_num
  @output_num
end

#producer_instruction_indexFixnum

The index (origin zero) of the parallel instruction that produces the output to be consumed by this input. This index is relative to the list of instructions in this input's instruction's containing MapTask. Corresponds to the JSON property producerInstructionIndex

Returns:

  • (Fixnum)


2407
2408
2409
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2407

def producer_instruction_index
  @producer_instruction_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2414
2415
2416
2417
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2414

def update!(**args)
  @output_num = args[:output_num] if args.key?(:output_num)
  @producer_instruction_index = args[:producer_instruction_index] if args.key?(:producer_instruction_index)
end