Class: Google::Apis::DataflowV1b3::IntegerMean

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

A representation of an integer mean metric contribution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntegerMean

Returns a new instance of IntegerMean.



2473
2474
2475
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property count



2465
2466
2467
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2465

def count
  @count
end

#sumGoogle::Apis::DataflowV1b3::SplitInt64

A representation of an int64, n, that is immune to precision loss when encoded in JSON. Corresponds to the JSON property sum



2471
2472
2473
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2471

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2478
2479
2480
2481
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2478

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @sum = args[:sum] if args.key?(:sum)
end