Class: Google::Apis::DataflowV1b3::JobMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Metadata available primarily for filtering jobs. Will be included in the ListJob response and Job SUMMARY view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobMetadata

Returns a new instance of JobMetadata.



2875
2876
2877
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2875

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_table_detailsArray<Google::Apis::DataflowV1b3::BigTableIoDetails>

Identification of a Cloud Bigtable source used in the Dataflow job. Corresponds to the JSON property bigTableDetails



2838
2839
2840
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2838

def big_table_details
  @big_table_details
end

#bigquery_detailsArray<Google::Apis::DataflowV1b3::BigQueryIoDetails>

Identification of a BigQuery source used in the Dataflow job. Corresponds to the JSON property bigqueryDetails



2843
2844
2845
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2843

def bigquery_details
  @bigquery_details
end

#datastore_detailsArray<Google::Apis::DataflowV1b3::DatastoreIoDetails>

Identification of a Datastore source used in the Dataflow job. Corresponds to the JSON property datastoreDetails



2848
2849
2850
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2848

def datastore_details
  @datastore_details
end

#file_detailsArray<Google::Apis::DataflowV1b3::FileIoDetails>

Identification of a File source used in the Dataflow job. Corresponds to the JSON property fileDetails



2853
2854
2855
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2853

def file_details
  @file_details
end

#pubsub_detailsArray<Google::Apis::DataflowV1b3::PubSubIoDetails>

Identification of a Pub/Sub source used in the Dataflow job. Corresponds to the JSON property pubsubDetails



2858
2859
2860
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2858

def pubsub_details
  @pubsub_details
end

#sdk_versionGoogle::Apis::DataflowV1b3::SdkVersion

The version of the SDK used to run the job. Corresponds to the JSON property sdkVersion



2863
2864
2865
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2863

def sdk_version
  @sdk_version
end

#spanner_detailsArray<Google::Apis::DataflowV1b3::SpannerIoDetails>

Identification of a Spanner source used in the Dataflow job. Corresponds to the JSON property spannerDetails



2868
2869
2870
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2868

def spanner_details
  @spanner_details
end

#user_display_propertiesHash<String,String>

List of display properties to help UI filter jobs. Corresponds to the JSON property userDisplayProperties

Returns:

  • (Hash<String,String>)


2873
2874
2875
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2873

def user_display_properties
  @user_display_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2880

def update!(**args)
  @big_table_details = args[:big_table_details] if args.key?(:big_table_details)
  @bigquery_details = args[:bigquery_details] if args.key?(:bigquery_details)
  @datastore_details = args[:datastore_details] if args.key?(:datastore_details)
  @file_details = args[:file_details] if args.key?(:file_details)
  @pubsub_details = args[:pubsub_details] if args.key?(:pubsub_details)
  @sdk_version = args[:sdk_version] if args.key?(:sdk_version)
  @spanner_details = args[:spanner_details] if args.key?(:spanner_details)
  @user_display_properties = args[:user_display_properties] if args.key?(:user_display_properties)
end