Class: Google::Apis::DataflowV1b3::JobMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

JobMetrics contains a collection of metrics describing the detailed progress of a Dataflow job. Metrics correspond to user-defined and system-defined metrics in the job. For more information, see Dataflow job metrics. This resource captures only the most recent values of each metric; time-series data can be queried for them (under the same metric names) from Cloud Monitoring.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobMetrics

Returns a new instance of JobMetrics.



2973
2974
2975
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metric_timeString

Timestamp as of which metric values are current. Corresponds to the JSON property metricTime

Returns:

  • (String)


2966
2967
2968
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2966

def metric_time
  @metric_time
end

#metricsArray<Google::Apis::DataflowV1b3::MetricUpdate>

All metrics for this job. Corresponds to the JSON property metrics



2971
2972
2973
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2971

def metrics
  @metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2978
2979
2980
2981
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2978

def update!(**args)
  @metric_time = args[:metric_time] if args.key?(:metric_time)
  @metrics = args[:metrics] if args.key?(:metrics)
end