Class: Google::Apis::DataflowV1b3::KeyRangeLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Location information for a specific key-range of a sharded computation. Currently we only support UTF-8 character splits to simplify encoding into JSON.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KeyRangeLocation

Returns a new instance of KeyRangeLocation.



3054
3055
3056
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3054

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_diskString

The name of the data disk where data for this range is stored. This name is local to the Google Cloud Platform project and uniquely identifies the disk within that project, for example "myproject-1014-104817-4c2-harness-0-disk-1". Corresponds to the JSON property dataDisk

Returns:

  • (String)


3030
3031
3032
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3030

def data_disk
  @data_disk
end

#delivery_endpointString

The physical location of this range assignment to be used for streaming computation cross-worker message delivery. Corresponds to the JSON property deliveryEndpoint

Returns:

  • (String)


3036
3037
3038
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3036

def delivery_endpoint
  @delivery_endpoint
end

#deprecated_persistent_directoryString

DEPRECATED. The location of the persistent state for this range, as a persistent directory in the worker local filesystem. Corresponds to the JSON property deprecatedPersistentDirectory

Returns:

  • (String)


3042
3043
3044
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3042

def deprecated_persistent_directory
  @deprecated_persistent_directory
end

#endString

The end (exclusive) of the key range. Corresponds to the JSON property end

Returns:

  • (String)


3047
3048
3049
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3047

def end
  @end
end

#startString

The start (inclusive) of the key range. Corresponds to the JSON property start

Returns:

  • (String)


3052
3053
3054
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3052

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3059
3060
3061
3062
3063
3064
3065
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3059

def update!(**args)
  @data_disk = args[:data_disk] if args.key?(:data_disk)
  @delivery_endpoint = args[:delivery_endpoint] if args.key?(:delivery_endpoint)
  @deprecated_persistent_directory = args[:deprecated_persistent_directory] if args.key?(:deprecated_persistent_directory)
  @end = args[:end] if args.key?(:end)
  @start = args[:start] if args.key?(:start)
end