Class: Google::Apis::DataflowV1b3::LaunchTemplateParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Parameters to provide to the template being launched. Note that the metadata in the pipeline code determines which runtime parameters are valid.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LaunchTemplateParameters

Returns a new instance of LaunchTemplateParameters.



3215
3216
3217
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environmentGoogle::Apis::DataflowV1b3::RuntimeEnvironment

The environment values to set at runtime. Corresponds to the JSON property environment



3189
3190
3191
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3189

def environment
  @environment
end

#job_nameString

Required. The job name to use for the created job. The name must match the regular expression [a-z]([-a-z0-9]0,1022[a-z0-9])? Corresponds to the JSON property jobName

Returns:

  • (String)


3195
3196
3197
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3195

def job_name
  @job_name
end

#parametersHash<String,String>

The runtime parameters to pass to the job. Corresponds to the JSON property parameters

Returns:

  • (Hash<String,String>)


3200
3201
3202
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3200

def parameters
  @parameters
end

#transform_name_mappingHash<String,String>

Only applicable when updating a pipeline. Map of transform name prefixes of the job to be replaced to the corresponding name prefixes of the new job. Corresponds to the JSON property transformNameMapping

Returns:

  • (Hash<String,String>)


3206
3207
3208
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3206

def transform_name_mapping
  @transform_name_mapping
end

#updateBoolean Also known as: update?

If set, replace the existing pipeline with the name specified by jobName with this pipeline, preserving state. Corresponds to the JSON property update

Returns:

  • (Boolean)


3212
3213
3214
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3212

def update
  @update
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3220
3221
3222
3223
3224
3225
3226
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3220

def update!(**args)
  @environment = args[:environment] if args.key?(:environment)
  @job_name = args[:job_name] if args.key?(:job_name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @transform_name_mapping = args[:transform_name_mapping] if args.key?(:transform_name_mapping)
  @update = args[:update] if args.key?(:update)
end