Class: Google::Apis::DataflowV1b3::LaunchTemplateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Response to the request to launch a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LaunchTemplateResponse

Returns a new instance of LaunchTemplateResponse.



3239
3240
3241
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jobGoogle::Apis::DataflowV1b3::Job

Defines a job to be run by the Cloud Dataflow service. Do not enter confidential information when you supply string values using the API. Corresponds to the JSON property job



3237
3238
3239
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3237

def job
  @job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3244
3245
3246
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3244

def update!(**args)
  @job = args[:job] if args.key?(:job)
end