Class: Google::Apis::DataflowV1b3::ListJobMessagesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ListJobMessagesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Response to a request to list job messages.
Instance Attribute Summary collapse
-
#autoscaling_events ⇒ Array<Google::Apis::DataflowV1b3::AutoscalingEvent>
Autoscaling events in ascending timestamp order.
-
#job_messages ⇒ Array<Google::Apis::DataflowV1b3::JobMessage>
Messages in ascending timestamp order.
-
#next_page_token ⇒ String
The token to obtain the next page of results if there are more.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListJobMessagesResponse
constructor
A new instance of ListJobMessagesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListJobMessagesResponse
Returns a new instance of ListJobMessagesResponse.
3389 3390 3391 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_events ⇒ Array<Google::Apis::DataflowV1b3::AutoscalingEvent>
Autoscaling events in ascending timestamp order.
Corresponds to the JSON property autoscalingEvents
3377 3378 3379 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3377 def autoscaling_events @autoscaling_events end |
#job_messages ⇒ Array<Google::Apis::DataflowV1b3::JobMessage>
Messages in ascending timestamp order.
Corresponds to the JSON property jobMessages
3382 3383 3384 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3382 def @job_messages end |
#next_page_token ⇒ String
The token to obtain the next page of results if there are more.
Corresponds to the JSON property nextPageToken
3387 3388 3389 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3387 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3394 3395 3396 3397 3398 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3394 def update!(**args) @autoscaling_events = args[:autoscaling_events] if args.key?(:autoscaling_events) @job_messages = args[:job_messages] if args.key?(:job_messages) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |