Class: Google::Apis::DataflowV1b3::ListJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Response to a request to list Cloud Dataflow jobs in a project. This might be a partial response, depending on the page size in the ListJobsRequest. However, if the project does not have any jobs, an instance of ListJobsResponse is not returned and the requests's response body is empty ``.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListJobsResponse

Returns a new instance of ListJobsResponse.



3424
3425
3426
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3424

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_locationArray<Google::Apis::DataflowV1b3::FailedLocation>

Zero or more messages describing the regional endpoints that failed to respond. Corresponds to the JSON property failedLocation



3412
3413
3414
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3412

def failed_location
  @failed_location
end

#jobsArray<Google::Apis::DataflowV1b3::Job>

A subset of the requested job information. Corresponds to the JSON property jobs



3417
3418
3419
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3417

def jobs
  @jobs
end

#next_page_tokenString

Set if there may be more results than fit in this response. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3422
3423
3424
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3422

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3429
3430
3431
3432
3433
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3429

def update!(**args)
  @failed_location = args[:failed_location] if args.key?(:failed_location)
  @jobs = args[:jobs] if args.key?(:jobs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end