Class: Google::Apis::DataflowV1b3::MetricStructuredName
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::MetricStructuredName
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Identifies a metric, by describing the source which generated the metric.
Instance Attribute Summary collapse
-
#context ⇒ Hash<String,String>
Zero or more labeled fields which identify the part of the job this metric is associated with, such as the name of a step or collection.
-
#name ⇒ String
Worker-defined metric name.
-
#origin ⇒ String
Origin (namespace) of metric name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricStructuredName
constructor
A new instance of MetricStructuredName.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricStructuredName
Returns a new instance of MetricStructuredName.
3590 3591 3592 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ Hash<String,String>
Zero or more labeled fields which identify the part of the job this metric is
associated with, such as the name of a step or collection. For example, built-
in counters associated with steps will have context['step'] = . Counters
associated with PCollections in the SDK will have context['pcollection'] = .
Corresponds to the JSON property context
3577 3578 3579 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3577 def context @context end |
#name ⇒ String
Worker-defined metric name.
Corresponds to the JSON property name
3582 3583 3584 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3582 def name @name end |
#origin ⇒ String
Origin (namespace) of metric name. May be blank for user-define metrics; will
be "dataflow" for metrics defined by the Dataflow service or SDK.
Corresponds to the JSON property origin
3588 3589 3590 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3588 def origin @origin end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3595 3596 3597 3598 3599 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3595 def update!(**args) @context = args[:context] if args.key?(:context) @name = args[:name] if args.key?(:name) @origin = args[:origin] if args.key?(:origin) end |