Class: Google::Apis::DataflowV1b3::MetricUpdate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Describes the state of a metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricUpdate

Returns a new instance of MetricUpdate.



3694
3695
3696
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3694

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bounded_trieObject

Worker-computed aggregate value for the "Trie" aggregation kind. The only possible value type is a BoundedTrieNode. Introduced this field to avoid breaking older SDKs when Dataflow service starts to populate the bounded_trie field. Corresponds to the JSON property boundedTrie

Returns:

  • (Object)


3612
3613
3614
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3612

def bounded_trie
  @bounded_trie
end

#cumulativeBoolean Also known as: cumulative?

True if this metric is reported as the total cumulative aggregate value accumulated since the worker started working on this WorkItem. By default this is false, indicating that this metric is reported as a delta that is not associated with any WorkItem. Corresponds to the JSON property cumulative

Returns:

  • (Boolean)


3620
3621
3622
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3620

def cumulative
  @cumulative
end

#distributionObject

A struct value describing properties of a distribution of numeric values. Corresponds to the JSON property distribution

Returns:

  • (Object)


3626
3627
3628
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3626

def distribution
  @distribution
end

#gaugeObject

A struct value describing properties of a Gauge. Metrics of gauge type show the value of a metric across time, and is aggregated based on the newest value. Corresponds to the JSON property gauge

Returns:

  • (Object)


3632
3633
3634
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3632

def gauge
  @gauge
end

#internalObject

Worker-computed aggregate value for internal use by the Dataflow service. Corresponds to the JSON property internal

Returns:

  • (Object)


3637
3638
3639
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3637

def internal
  @internal
end

#kindString

Metric aggregation kind. The possible metric aggregation kinds are "Sum", "Max" , "Min", "Mean", "Set", "And", "Or", and "Distribution". The specified aggregation kind is case-insensitive. If omitted, this is not an aggregated value but instead a single metric sample value. Corresponds to the JSON property kind

Returns:

  • (String)


3645
3646
3647
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3645

def kind
  @kind
end

#mean_countObject

Worker-computed aggregate value for the "Mean" aggregation kind. This holds the count of the aggregated values and is used in combination with mean_sum above to obtain the actual mean aggregate value. The only possible value type is Long. Corresponds to the JSON property meanCount

Returns:

  • (Object)


3653
3654
3655
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3653

def mean_count
  @mean_count
end

#mean_sumObject

Worker-computed aggregate value for the "Mean" aggregation kind. This holds the sum of the aggregated values and is used in combination with mean_count below to obtain the actual mean aggregate value. The only possible value types are Long and Double. Corresponds to the JSON property meanSum

Returns:

  • (Object)


3661
3662
3663
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3661

def mean_sum
  @mean_sum
end

#nameGoogle::Apis::DataflowV1b3::MetricStructuredName

Identifies a metric, by describing the source which generated the metric. Corresponds to the JSON property name



3666
3667
3668
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3666

def name
  @name
end

#scalarObject

Worker-computed aggregate value for aggregation kinds "Sum", "Max", "Min", " And", and "Or". The possible value types are Long, Double, and Boolean. Corresponds to the JSON property scalar

Returns:

  • (Object)


3672
3673
3674
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3672

def scalar
  @scalar
end

#setObject

Worker-computed aggregate value for the "Set" aggregation kind. The only possible value type is a list of Values whose type can be Long, Double, String, or BoundedTrie according to the metric's type. All Values in the list must be of the same type. Corresponds to the JSON property set

Returns:

  • (Object)


3680
3681
3682
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3680

def set
  @set
end

#trieObject

Worker-computed aggregate value for the "Trie" aggregation kind. The only possible value type is a BoundedTrieNode. Corresponds to the JSON property trie

Returns:

  • (Object)


3686
3687
3688
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3686

def trie
  @trie
end

#update_timeString

Timestamp associated with the metric value. Optional when workers are reporting work progress; it will be filled in responses from the metrics API. Corresponds to the JSON property updateTime

Returns:

  • (String)


3692
3693
3694
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3692

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3699
3700
3701
3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3699

def update!(**args)
  @bounded_trie = args[:bounded_trie] if args.key?(:bounded_trie)
  @cumulative = args[:cumulative] if args.key?(:cumulative)
  @distribution = args[:distribution] if args.key?(:distribution)
  @gauge = args[:gauge] if args.key?(:gauge)
  @internal = args[:internal] if args.key?(:internal)
  @kind = args[:kind] if args.key?(:kind)
  @mean_count = args[:mean_count] if args.key?(:mean_count)
  @mean_sum = args[:mean_sum] if args.key?(:mean_sum)
  @name = args[:name] if args.key?(:name)
  @scalar = args[:scalar] if args.key?(:scalar)
  @set = args[:set] if args.key?(:set)
  @trie = args[:trie] if args.key?(:trie)
  @update_time = args[:update_time] if args.key?(:update_time)
end