Class: Google::Apis::DataflowV1b3::Package

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

The packages that must be installed in order for a worker to run the steps of the Cloud Dataflow job that will be assigned to its worker pool. This is the mechanism by which the Cloud Dataflow SDK causes code to be loaded onto the workers. For example, the Cloud Dataflow Java SDK might use this to install jars containing the user's code and all of the various dependencies (libraries, data files, etc.) required in order for that code to run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Package

Returns a new instance of Package.



3892
3893
3894
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3892

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

The resource to read the package from. The supported resource type is: Google Cloud Storage: storage.googleapis.com/bucket bucket.storage.googleapis.com/ Corresponds to the JSON property location

Returns:

  • (String)


3878
3879
3880
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3878

def location
  @location
end

#nameString

The name of the package. Corresponds to the JSON property name

Returns:

  • (String)


3883
3884
3885
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3883

def name
  @name
end

#sha256String

Optional. The hex-encoded SHA256 checksum of the package. If the checksum is provided, the worker will verify the checksum of the package before using it. If the checksum does not match, the worker will fail to start. Corresponds to the JSON property sha256

Returns:

  • (String)


3890
3891
3892
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3890

def sha256
  @sha256
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3897
3898
3899
3900
3901
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3897

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @sha256 = args[:sha256] if args.key?(:sha256)
end