Class: Google::Apis::DataflowV1b3::ParameterMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Metadata for a specific parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParameterMetadata

Returns a new instance of ParameterMetadata.



4060
4061
4062
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_metadataHash<String,String>

Optional. Additional metadata for describing this parameter. Corresponds to the JSON property customMetadata

Returns:

  • (Hash<String,String>)


3987
3988
3989
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3987

def 
  @custom_metadata
end

#default_valueString

Optional. The default values will pre-populate the parameter with the given value from the proto. If default_value is left empty, the parameter will be populated with a default of the relevant type, e.g. false for a boolean. Corresponds to the JSON property defaultValue

Returns:

  • (String)


3994
3995
3996
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3994

def default_value
  @default_value
end

#enum_optionsArray<Google::Apis::DataflowV1b3::ParameterMetadataEnumOption>

Optional. The options shown when ENUM ParameterType is specified. Corresponds to the JSON property enumOptions



3999
4000
4001
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3999

def enum_options
  @enum_options
end

#group_nameString

Optional. Specifies a group name for this parameter to be rendered under. Group header text will be rendered exactly as specified in this field. Only considered when parent_name is NOT provided. Corresponds to the JSON property groupName

Returns:

  • (String)


4006
4007
4008
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4006

def group_name
  @group_name
end

#help_textString

Required. The help text to display for the parameter. Corresponds to the JSON property helpText

Returns:

  • (String)


4011
4012
4013
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4011

def help_text
  @help_text
end

#hidden_uiBoolean Also known as: hidden_ui?

Optional. Whether the parameter should be hidden in the UI. Corresponds to the JSON property hiddenUi

Returns:

  • (Boolean)


4016
4017
4018
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4016

def hidden_ui
  @hidden_ui
end

#is_optionalBoolean Also known as: is_optional?

Optional. Whether the parameter is optional. Defaults to false. Corresponds to the JSON property isOptional

Returns:

  • (Boolean)


4022
4023
4024
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4022

def is_optional
  @is_optional
end

#labelString

Required. The label to display for the parameter. Corresponds to the JSON property label

Returns:

  • (String)


4028
4029
4030
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4028

def label
  @label
end

#nameString

Required. The name of the parameter. Corresponds to the JSON property name

Returns:

  • (String)


4033
4034
4035
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4033

def name
  @name
end

#param_typeString

Optional. The type of the parameter. Used for selecting input picker. Corresponds to the JSON property paramType

Returns:

  • (String)


4038
4039
4040
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4038

def param_type
  @param_type
end

#parent_nameString

Optional. Specifies the name of the parent parameter. Used in conjunction with 'parent_trigger_values' to make this parameter conditional (will only be rendered conditionally). Should be mappable to a ParameterMetadata.name field. Corresponds to the JSON property parentName

Returns:

  • (String)


4045
4046
4047
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4045

def parent_name
  @parent_name
end

#parent_trigger_valuesArray<String>

Optional. The value(s) of the 'parent_name' parameter which will trigger this parameter to be shown. If left empty, ANY non-empty value in parent_name will trigger this parameter to be shown. Only considered when this parameter is conditional (when 'parent_name' has been provided). Corresponds to the JSON property parentTriggerValues

Returns:

  • (Array<String>)


4053
4054
4055
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4053

def parent_trigger_values
  @parent_trigger_values
end

#regexesArray<String>

Optional. Regexes that the parameter must match. Corresponds to the JSON property regexes

Returns:

  • (Array<String>)


4058
4059
4060
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4058

def regexes
  @regexes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
4076
4077
4078
4079
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4065

def update!(**args)
  @custom_metadata = args[:custom_metadata] if args.key?(:custom_metadata)
  @default_value = args[:default_value] if args.key?(:default_value)
  @enum_options = args[:enum_options] if args.key?(:enum_options)
  @group_name = args[:group_name] if args.key?(:group_name)
  @help_text = args[:help_text] if args.key?(:help_text)
  @hidden_ui = args[:hidden_ui] if args.key?(:hidden_ui)
  @is_optional = args[:is_optional] if args.key?(:is_optional)
  @label = args[:label] if args.key?(:label)
  @name = args[:name] if args.key?(:name)
  @param_type = args[:param_type] if args.key?(:param_type)
  @parent_name = args[:parent_name] if args.key?(:parent_name)
  @parent_trigger_values = args[:parent_trigger_values] if args.key?(:parent_trigger_values)
  @regexes = args[:regexes] if args.key?(:regexes)
end