Class: Google::Apis::DataflowV1b3::PartialGroupByKeyInstruction
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::PartialGroupByKeyInstruction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
An instruction that does a partial group-by-key. One input and one output.
Instance Attribute Summary collapse
-
#input ⇒ Google::Apis::DataflowV1b3::InstructionInput
An input of an instruction, as a reference to an output of a producer instruction.
-
#input_element_codec ⇒ Hash<String,Object>
The codec to use for interpreting an element in the input PTable.
-
#original_combine_values_input_store_name ⇒ String
If this instruction includes a combining function this is the name of the intermediate store between the GBK and the CombineValues.
-
#original_combine_values_step_name ⇒ String
If this instruction includes a combining function, this is the name of the CombineValues instruction lifted into this instruction.
-
#side_inputs ⇒ Array<Google::Apis::DataflowV1b3::SideInputInfo>
Zero or more side inputs.
-
#value_combining_fn ⇒ Hash<String,Object>
The value combining function to invoke.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartialGroupByKeyInstruction
constructor
A new instance of PartialGroupByKeyInstruction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartialGroupByKeyInstruction
Returns a new instance of PartialGroupByKeyInstruction.
4142 4143 4144 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input ⇒ Google::Apis::DataflowV1b3::InstructionInput
An input of an instruction, as a reference to an output of a producer
instruction.
Corresponds to the JSON property input
4113 4114 4115 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4113 def input @input end |
#input_element_codec ⇒ Hash<String,Object>
The codec to use for interpreting an element in the input PTable.
Corresponds to the JSON property inputElementCodec
4118 4119 4120 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4118 def input_element_codec @input_element_codec end |
#original_combine_values_input_store_name ⇒ String
If this instruction includes a combining function this is the name of the
intermediate store between the GBK and the CombineValues.
Corresponds to the JSON property originalCombineValuesInputStoreName
4124 4125 4126 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4124 def original_combine_values_input_store_name @original_combine_values_input_store_name end |
#original_combine_values_step_name ⇒ String
If this instruction includes a combining function, this is the name of the
CombineValues instruction lifted into this instruction.
Corresponds to the JSON property originalCombineValuesStepName
4130 4131 4132 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4130 def original_combine_values_step_name @original_combine_values_step_name end |
#side_inputs ⇒ Array<Google::Apis::DataflowV1b3::SideInputInfo>
Zero or more side inputs.
Corresponds to the JSON property sideInputs
4135 4136 4137 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4135 def side_inputs @side_inputs end |
#value_combining_fn ⇒ Hash<String,Object>
The value combining function to invoke.
Corresponds to the JSON property valueCombiningFn
4140 4141 4142 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4140 def value_combining_fn @value_combining_fn end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4147 4148 4149 4150 4151 4152 4153 4154 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4147 def update!(**args) @input = args[:input] if args.key?(:input) @input_element_codec = args[:input_element_codec] if args.key?(:input_element_codec) @original_combine_values_input_store_name = args[:original_combine_values_input_store_name] if args.key?(:original_combine_values_input_store_name) @original_combine_values_step_name = args[:original_combine_values_step_name] if args.key?(:original_combine_values_step_name) @side_inputs = args[:side_inputs] if args.key?(:side_inputs) @value_combining_fn = args[:value_combining_fn] if args.key?(:value_combining_fn) end |