Class: Google::Apis::DataflowV1b3::PerStepNamespaceMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Metrics for a particular unfused step and namespace. A metric is uniquely identified by the metrics_namespace, original_step, metric name and metric_labels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PerStepNamespaceMetrics

Returns a new instance of PerStepNamespaceMetrics.



4187
4188
4189
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metric_valuesArray<Google::Apis::DataflowV1b3::MetricValue>

Optional. Metrics that are recorded for this namespace and unfused step. Corresponds to the JSON property metricValues



4174
4175
4176
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4174

def metric_values
  @metric_values
end

#metrics_namespaceString

The namespace of these metrics on the worker. Corresponds to the JSON property metricsNamespace

Returns:

  • (String)


4179
4180
4181
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4179

def metrics_namespace
  @metrics_namespace
end

#original_stepString

The original system name of the unfused step that these metrics are reported from. Corresponds to the JSON property originalStep

Returns:

  • (String)


4185
4186
4187
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4185

def original_step
  @original_step
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4192
4193
4194
4195
4196
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4192

def update!(**args)
  @metric_values = args[:metric_values] if args.key?(:metric_values)
  @metrics_namespace = args[:metrics_namespace] if args.key?(:metrics_namespace)
  @original_step = args[:original_step] if args.key?(:original_step)
end