Class: Google::Apis::DataflowV1b3::ProgressTimeseries

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Information about the progress of some component of job execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProgressTimeseries

Returns a new instance of ProgressTimeseries.



4343
4344
4345
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_progressFloat

The current progress of the component, in the range [0,1]. Corresponds to the JSON property currentProgress

Returns:

  • (Float)


4336
4337
4338
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4336

def current_progress
  @current_progress
end

#data_pointsArray<Google::Apis::DataflowV1b3::Point>

History of progress for the component. Points are sorted by time. Corresponds to the JSON property dataPoints



4341
4342
4343
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4341

def data_points
  @data_points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4348
4349
4350
4351
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4348

def update!(**args)
  @current_progress = args[:current_progress] if args.key?(:current_progress)
  @data_points = args[:data_points] if args.key?(:data_points)
end