Class: Google::Apis::DataflowV1b3::Sdk
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::Sdk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
A structured representation of an SDK.
Instance Attribute Summary collapse
-
#sdk_id ⇒ String
The SDK harness id.
-
#stacks ⇒ Array<Google::Apis::DataflowV1b3::Stack>
The stacktraces for the processes running on the SDK harness.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Sdk
constructor
A new instance of Sdk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Sdk
Returns a new instance of Sdk.
4949 4950 4951 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4949 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sdk_id ⇒ String
The SDK harness id.
Corresponds to the JSON property sdkId
4942 4943 4944 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4942 def sdk_id @sdk_id end |
#stacks ⇒ Array<Google::Apis::DataflowV1b3::Stack>
The stacktraces for the processes running on the SDK harness.
Corresponds to the JSON property stacks
4947 4948 4949 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4947 def stacks @stacks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4954 4955 4956 4957 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4954 def update!(**args) @sdk_id = args[:sdk_id] if args.key?(:sdk_id) @stacks = args[:stacks] if args.key?(:stacks) end |