Class: Google::Apis::DataflowV1b3::SendDebugCaptureRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Request to send encoded debug information. Next ID: 8

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SendDebugCaptureRequest

Returns a new instance of SendDebugCaptureRequest.



5111
5112
5113
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_idString

The internal component id for which debug information is sent. Corresponds to the JSON property componentId

Returns:

  • (String)


5088
5089
5090
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5088

def component_id
  @component_id
end

#dataString

The encoded debug information. Corresponds to the JSON property data

Returns:

  • (String)


5093
5094
5095
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5093

def data
  @data
end

#data_formatString

Format for the data field above (id=5). Corresponds to the JSON property dataFormat

Returns:

  • (String)


5098
5099
5100
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5098

def data_format
  @data_format
end

#locationString

The regional endpoint that contains the job specified by job_id. Corresponds to the JSON property location

Returns:

  • (String)


5104
5105
5106
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5104

def location
  @location
end

#worker_idString

The worker id, i.e., VM hostname. Corresponds to the JSON property workerId

Returns:

  • (String)


5109
5110
5111
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5109

def worker_id
  @worker_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5116
5117
5118
5119
5120
5121
5122
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5116

def update!(**args)
  @component_id = args[:component_id] if args.key?(:component_id)
  @data = args[:data] if args.key?(:data)
  @data_format = args[:data_format] if args.key?(:data_format)
  @location = args[:location] if args.key?(:location)
  @worker_id = args[:worker_id] if args.key?(:worker_id)
end