Class: Google::Apis::DataflowV1b3::SeqMapTaskOutputInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Information about an output of a SeqMapTask.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SeqMapTaskOutputInfo

Returns a new instance of SeqMapTaskOutputInfo.



5239
5240
5241
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sinkGoogle::Apis::DataflowV1b3::Sink

A sink that records can be encoded and written to. Corresponds to the JSON property sink



5232
5233
5234
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5232

def sink
  @sink
end

#tagString

The id of the TupleTag the user code will tag the output value by. Corresponds to the JSON property tag

Returns:

  • (String)


5237
5238
5239
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5237

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5244
5245
5246
5247
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5244

def update!(**args)
  @sink = args[:sink] if args.key?(:sink)
  @tag = args[:tag] if args.key?(:tag)
end