Class: Google::Apis::DataflowV1b3::ServiceResources
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ServiceResources
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Resources used by the Dataflow Service to run the job.
Instance Attribute Summary collapse
-
#zones ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceResources
constructor
A new instance of ServiceResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceResources
Returns a new instance of ServiceResources.
5268 5269 5270 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#zones ⇒ Array<String>
Output only. List of Cloud Zones being used by the Dataflow Service for this
job. Example: us-central1-c
Corresponds to the JSON property zones
5266 5267 5268 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5266 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5273 5274 5275 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5273 def update!(**args) @zones = args[:zones] if args.key?(:zones) end |