Class: Google::Apis::DataflowV1b3::Sink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

A sink that records can be encoded and written to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Sink

Returns a new instance of Sink.



5456
5457
5458
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codecHash<String,Object>

The codec to use to encode data written to the sink. Corresponds to the JSON property codec

Returns:

  • (Hash<String,Object>)


5449
5450
5451
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5449

def codec
  @codec
end

#specHash<String,Object>

The sink to write to, plus its parameters. Corresponds to the JSON property spec

Returns:

  • (Hash<String,Object>)


5454
5455
5456
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5454

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5461
5462
5463
5464
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5461

def update!(**args)
  @codec = args[:codec] if args.key?(:codec)
  @spec = args[:spec] if args.key?(:spec)
end