Class: Google::Apis::DataflowV1b3::SnapshotJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::SnapshotJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Request to create a snapshot of a job.
Instance Attribute Summary collapse
-
#description ⇒ String
User specified description of the snapshot.
-
#location ⇒ String
The location that contains this job.
-
#snapshot_sources ⇒ Boolean
(also: #snapshot_sources?)
If true, perform snapshots for sources which support this.
-
#ttl ⇒ String
TTL for the snapshot.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotJobRequest
constructor
A new instance of SnapshotJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotJobRequest
Returns a new instance of SnapshotJobRequest.
5461 5462 5463 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
User specified description of the snapshot. Maybe empty.
Corresponds to the JSON property description
5443 5444 5445 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5443 def description @description end |
#location ⇒ String
The location that contains this job.
Corresponds to the JSON property location
5448 5449 5450 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5448 def location @location end |
#snapshot_sources ⇒ Boolean Also known as: snapshot_sources?
If true, perform snapshots for sources which support this.
Corresponds to the JSON property snapshotSources
5453 5454 5455 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5453 def snapshot_sources @snapshot_sources end |
#ttl ⇒ String
TTL for the snapshot.
Corresponds to the JSON property ttl
5459 5460 5461 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5459 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5466 5467 5468 5469 5470 5471 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5466 def update!(**args) @description = args[:description] if args.key?(:description) @location = args[:location] if args.key?(:location) @snapshot_sources = args[:snapshot_sources] if args.key?(:snapshot_sources) @ttl = args[:ttl] if args.key?(:ttl) end |