Class: Google::Apis::DataflowV1b3::SourceMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::SourceMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Metadata about a Source useful for automatically optimizing and tuning the pipeline, etc.
Instance Attribute Summary collapse
-
#estimated_size_bytes ⇒ Fixnum
An estimate of the total size (in bytes) of the data that would be read from this source.
-
#infinite ⇒ Boolean
(also: #infinite?)
Specifies that the size of this source is known to be infinite (this is a streaming source).
-
#produces_sorted_keys ⇒ Boolean
(also: #produces_sorted_keys?)
Whether this source is known to produce key/value pairs with the (encoded) keys in lexicographically sorted order.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceMetadata
constructor
A new instance of SourceMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceMetadata
Returns a new instance of SourceMetadata.
5745 5746 5747 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5745 def initialize(**args) update!(**args) end |
Instance Attribute Details
#estimated_size_bytes ⇒ Fixnum
An estimate of the total size (in bytes) of the data that would be read from
this source. This estimate is in terms of external storage size, before any
decompression or other processing done by the reader.
Corresponds to the JSON property estimatedSizeBytes
5729 5730 5731 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5729 def estimated_size_bytes @estimated_size_bytes end |
#infinite ⇒ Boolean Also known as: infinite?
Specifies that the size of this source is known to be infinite (this is a
streaming source).
Corresponds to the JSON property infinite
5735 5736 5737 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5735 def infinite @infinite end |
#produces_sorted_keys ⇒ Boolean Also known as: produces_sorted_keys?
Whether this source is known to produce key/value pairs with the (encoded)
keys in lexicographically sorted order.
Corresponds to the JSON property producesSortedKeys
5742 5743 5744 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5742 def produces_sorted_keys @produces_sorted_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5750 5751 5752 5753 5754 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5750 def update!(**args) @estimated_size_bytes = args[:estimated_size_bytes] if args.key?(:estimated_size_bytes) @infinite = args[:infinite] if args.key?(:infinite) @produces_sorted_keys = args[:produces_sorted_keys] if args.key?(:produces_sorted_keys) end |