Class: Google::Apis::DataflowV1b3::StageSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Description of an input or output of an execution stage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StageSource

Returns a new instance of StageSource.



6009
6010
6011
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Dataflow service generated name for this source. Corresponds to the JSON property name

Returns:

  • (String)


5991
5992
5993
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5991

def name
  @name
end

#original_transform_or_collectionString

User name for the original user transform or collection with which this source is most closely associated. Corresponds to the JSON property originalTransformOrCollection

Returns:

  • (String)


5997
5998
5999
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5997

def original_transform_or_collection
  @original_transform_or_collection
end

#size_bytesFixnum

Size of the source, if measurable. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


6002
6003
6004
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6002

def size_bytes
  @size_bytes
end

#user_nameString

Human-readable name for this source; may be user or system generated. Corresponds to the JSON property userName

Returns:

  • (String)


6007
6008
6009
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6007

def user_name
  @user_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6014
6015
6016
6017
6018
6019
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6014

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @original_transform_or_collection = args[:original_transform_or_collection] if args.key?(:original_transform_or_collection)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @user_name = args[:user_name] if args.key?(:user_name)
end