Class: Google::Apis::DataflowV1b3::Step

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Defines a particular step within a Cloud Dataflow job. A job consists of multiple steps, each of which performs some specific operation as part of the overall job. Data is typically passed from one step to another as part of the job. Note: The properties of this object are not stable and might change. Here's an example of a sequence of steps which together implement a Map-Reduce job: * Read a collection of data from some source, parsing the collection's elements. * Validate the elements. * Apply a user-defined function to map each element to some value and extract an element-specific key value. * Group elements with the same key into a single element with that key, transforming a multiply-keyed collection into a uniquely-keyed collection. * Write the elements out to some data sink. Note that the Cloud Dataflow service may be used to run many different types of jobs, not just Map-Reduce.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Step

Returns a new instance of Step.



6176
6177
6178
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

The kind of step in the Cloud Dataflow job. Corresponds to the JSON property kind

Returns:

  • (String)


6161
6162
6163
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6161

def kind
  @kind
end

#nameString

The name that identifies the step. This must be unique for each step with respect to all other steps in the Cloud Dataflow job. Corresponds to the JSON property name

Returns:

  • (String)


6167
6168
6169
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6167

def name
  @name
end

#propertiesHash<String,Object>

Named properties associated with the step. Each kind of predefined step has its own required set of properties. Must be provided on Create. Only retrieved with JOB_VIEW_ALL. Corresponds to the JSON property properties

Returns:

  • (Hash<String,Object>)


6174
6175
6176
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6174

def properties
  @properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6181
6182
6183
6184
6185
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6181

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
end