Class: Google::Apis::DataflowV1b3::StragglerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Information useful for straggler identification and debugging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StragglerInfo

Returns a new instance of StragglerInfo.



6257
6258
6259
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#causesHash<String,Google::Apis::DataflowV1b3::StragglerDebuggingInfo>

The straggler causes, keyed by the string representation of the StragglerCause enum and contains specialized debugging information for each straggler cause. Corresponds to the JSON property causes



6250
6251
6252
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6250

def causes
  @causes
end

#start_timeString

The time when the work item attempt became a straggler. Corresponds to the JSON property startTime

Returns:

  • (String)


6255
6256
6257
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6255

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6262
6263
6264
6265
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6262

def update!(**args)
  @causes = args[:causes] if args.key?(:causes)
  @start_time = args[:start_time] if args.key?(:start_time)
end