Class: Google::Apis::DataflowV1b3::StreamLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Describes a stream of data, either as input to be processed or as output of a streaming Dataflow job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamLocation

Returns a new instance of StreamLocation.



6319
6320
6321
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_source_locationGoogle::Apis::DataflowV1b3::CustomSourceLocation

Identifies the location of a custom souce. Corresponds to the JSON property customSourceLocation



6300
6301
6302
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6300

def custom_source_location
  @custom_source_location
end

#pubsub_locationGoogle::Apis::DataflowV1b3::PubsubLocation

Identifies a pubsub location to use for transferring data into or out of a streaming Dataflow job. Corresponds to the JSON property pubsubLocation



6306
6307
6308
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6306

def pubsub_location
  @pubsub_location
end

#side_input_locationGoogle::Apis::DataflowV1b3::StreamingSideInputLocation

Identifies the location of a streaming side input. Corresponds to the JSON property sideInputLocation



6311
6312
6313
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6311

def side_input_location
  @side_input_location
end

#streaming_stage_locationGoogle::Apis::DataflowV1b3::StreamingStageLocation

Identifies the location of a streaming computation stage, for stage-to-stage communication. Corresponds to the JSON property streamingStageLocation



6317
6318
6319
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6317

def streaming_stage_location
  @streaming_stage_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6324
6325
6326
6327
6328
6329
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6324

def update!(**args)
  @custom_source_location = args[:custom_source_location] if args.key?(:custom_source_location)
  @pubsub_location = args[:pubsub_location] if args.key?(:pubsub_location)
  @side_input_location = args[:side_input_location] if args.key?(:side_input_location)
  @streaming_stage_location = args[:streaming_stage_location] if args.key?(:streaming_stage_location)
end