Class: Google::Apis::DataflowV1b3::StreamingApplianceSnapshotConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Streaming appliance snapshot configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamingApplianceSnapshotConfig

Returns a new instance of StreamingApplianceSnapshotConfig.



6354
6355
6356
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#import_state_endpointString

Indicates which endpoint is used to import appliance state. Corresponds to the JSON property importStateEndpoint

Returns:

  • (String)


6347
6348
6349
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6347

def import_state_endpoint
  @import_state_endpoint
end

#snapshot_idString

If set, indicates the snapshot id for the snapshot being performed. Corresponds to the JSON property snapshotId

Returns:

  • (String)


6352
6353
6354
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6352

def snapshot_id
  @snapshot_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6359
6360
6361
6362
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6359

def update!(**args)
  @import_state_endpoint = args[:import_state_endpoint] if args.key?(:import_state_endpoint)
  @snapshot_id = args[:snapshot_id] if args.key?(:snapshot_id)
end