Class: Google::Apis::DataflowV1b3::StreamingComputationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::StreamingComputationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Configuration information for a single streaming computation.
Instance Attribute Summary collapse
-
#computation_id ⇒ String
Unique identifier for this computation.
-
#instructions ⇒ Array<Google::Apis::DataflowV1b3::ParallelInstruction>
Instructions that comprise the computation.
-
#stage_name ⇒ String
Stage name of this computation.
-
#system_name ⇒ String
System defined name for this computation.
-
#transform_user_name_to_state_family ⇒ Hash<String,String>
Map from user name of stateful transforms in this stage to their state family.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamingComputationConfig
constructor
A new instance of StreamingComputationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamingComputationConfig
Returns a new instance of StreamingComputationConfig.
6499 6500 6501 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#computation_id ⇒ String
Unique identifier for this computation.
Corresponds to the JSON property computationId
6477 6478 6479 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6477 def computation_id @computation_id end |
#instructions ⇒ Array<Google::Apis::DataflowV1b3::ParallelInstruction>
Instructions that comprise the computation.
Corresponds to the JSON property instructions
6482 6483 6484 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6482 def instructions @instructions end |
#stage_name ⇒ String
Stage name of this computation.
Corresponds to the JSON property stageName
6487 6488 6489 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6487 def stage_name @stage_name end |
#system_name ⇒ String
System defined name for this computation.
Corresponds to the JSON property systemName
6492 6493 6494 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6492 def system_name @system_name end |
#transform_user_name_to_state_family ⇒ Hash<String,String>
Map from user name of stateful transforms in this stage to their state family.
Corresponds to the JSON property transformUserNameToStateFamily
6497 6498 6499 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6497 def transform_user_name_to_state_family @transform_user_name_to_state_family end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6504 6505 6506 6507 6508 6509 6510 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6504 def update!(**args) @computation_id = args[:computation_id] if args.key?(:computation_id) @instructions = args[:instructions] if args.key?(:instructions) @stage_name = args[:stage_name] if args.key?(:stage_name) @system_name = args[:system_name] if args.key?(:system_name) @transform_user_name_to_state_family = args[:transform_user_name_to_state_family] if args.key?(:transform_user_name_to_state_family) end |