Class: Google::Apis::DataflowV1b3::StreamingConfigTask
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::StreamingConfigTask
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
A task that carries configuration information for streaming computations.
Instance Attribute Summary collapse
-
#commit_stream_chunk_size_bytes ⇒ Fixnum
Chunk size for commit streams from the harness to windmill.
-
#get_data_stream_chunk_size_bytes ⇒ Fixnum
Chunk size for get data streams from the harness to windmill.
-
#max_work_item_commit_bytes ⇒ Fixnum
Maximum size for work item commit supported windmill storage layer.
-
#operational_limits ⇒ Google::Apis::DataflowV1b3::StreamingOperationalLimits
Operational limits imposed on streaming jobs by the backend.
-
#streaming_computation_configs ⇒ Array<Google::Apis::DataflowV1b3::StreamingComputationConfig>
Set of computation configuration information.
-
#streaming_engine_state_tag_encoding_version ⇒ Fixnum
Optional.
-
#user_step_to_state_family_name_map ⇒ Hash<String,String>
Map from user step names to state families.
-
#user_worker_runner_v1_settings ⇒ String
Binary encoded proto to control runtime behavior of the java runner v1 user worker.
-
#user_worker_runner_v2_settings ⇒ String
Binary encoded proto to control runtime behavior of the runner v2 user worker.
-
#windmill_service_endpoint ⇒ String
If present, the worker must use this endpoint to communicate with Windmill Service dispatchers, otherwise the worker must continue to use whatever endpoint it had been using.
-
#windmill_service_port ⇒ Fixnum
If present, the worker must use this port to communicate with Windmill Service dispatchers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamingConfigTask
constructor
A new instance of StreamingConfigTask.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamingConfigTask
Returns a new instance of StreamingConfigTask.
6636 6637 6638 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commit_stream_chunk_size_bytes ⇒ Fixnum
Chunk size for commit streams from the harness to windmill.
Corresponds to the JSON property commitStreamChunkSizeBytes
6578 6579 6580 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6578 def commit_stream_chunk_size_bytes @commit_stream_chunk_size_bytes end |
#get_data_stream_chunk_size_bytes ⇒ Fixnum
Chunk size for get data streams from the harness to windmill.
Corresponds to the JSON property getDataStreamChunkSizeBytes
6583 6584 6585 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6583 def get_data_stream_chunk_size_bytes @get_data_stream_chunk_size_bytes end |
#max_work_item_commit_bytes ⇒ Fixnum
Maximum size for work item commit supported windmill storage layer.
Corresponds to the JSON property maxWorkItemCommitBytes
6588 6589 6590 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6588 def max_work_item_commit_bytes @max_work_item_commit_bytes end |
#operational_limits ⇒ Google::Apis::DataflowV1b3::StreamingOperationalLimits
Operational limits imposed on streaming jobs by the backend.
Corresponds to the JSON property operationalLimits
6593 6594 6595 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6593 def operational_limits @operational_limits end |
#streaming_computation_configs ⇒ Array<Google::Apis::DataflowV1b3::StreamingComputationConfig>
Set of computation configuration information.
Corresponds to the JSON property streamingComputationConfigs
6598 6599 6600 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6598 def streaming_computation_configs @streaming_computation_configs end |
#streaming_engine_state_tag_encoding_version ⇒ Fixnum
Optional. The state tag encoding format version for streaming engine jobs.
Corresponds to the JSON property streamingEngineStateTagEncodingVersion
6603 6604 6605 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6603 def streaming_engine_state_tag_encoding_version @streaming_engine_state_tag_encoding_version end |
#user_step_to_state_family_name_map ⇒ Hash<String,String>
Map from user step names to state families.
Corresponds to the JSON property userStepToStateFamilyNameMap
6608 6609 6610 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6608 def user_step_to_state_family_name_map @user_step_to_state_family_name_map end |
#user_worker_runner_v1_settings ⇒ String
Binary encoded proto to control runtime behavior of the java runner v1 user
worker.
Corresponds to the JSON property userWorkerRunnerV1Settings
NOTE: Values are automatically base64 encoded/decoded in the client library.
6615 6616 6617 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6615 def user_worker_runner_v1_settings @user_worker_runner_v1_settings end |
#user_worker_runner_v2_settings ⇒ String
Binary encoded proto to control runtime behavior of the runner v2 user worker.
Corresponds to the JSON property userWorkerRunnerV2Settings
NOTE: Values are automatically base64 encoded/decoded in the client library.
6621 6622 6623 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6621 def user_worker_runner_v2_settings @user_worker_runner_v2_settings end |
#windmill_service_endpoint ⇒ String
If present, the worker must use this endpoint to communicate with Windmill
Service dispatchers, otherwise the worker must continue to use whatever
endpoint it had been using.
Corresponds to the JSON property windmillServiceEndpoint
6628 6629 6630 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6628 def windmill_service_endpoint @windmill_service_endpoint end |
#windmill_service_port ⇒ Fixnum
If present, the worker must use this port to communicate with Windmill Service
dispatchers. Only applicable when windmill_service_endpoint is specified.
Corresponds to the JSON property windmillServicePort
6634 6635 6636 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6634 def windmill_service_port @windmill_service_port end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6641 6642 6643 6644 6645 6646 6647 6648 6649 6650 6651 6652 6653 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6641 def update!(**args) @commit_stream_chunk_size_bytes = args[:commit_stream_chunk_size_bytes] if args.key?(:commit_stream_chunk_size_bytes) @get_data_stream_chunk_size_bytes = args[:get_data_stream_chunk_size_bytes] if args.key?(:get_data_stream_chunk_size_bytes) @max_work_item_commit_bytes = args[:max_work_item_commit_bytes] if args.key?(:max_work_item_commit_bytes) @operational_limits = args[:operational_limits] if args.key?(:operational_limits) @streaming_computation_configs = args[:streaming_computation_configs] if args.key?(:streaming_computation_configs) @streaming_engine_state_tag_encoding_version = args[:streaming_engine_state_tag_encoding_version] if args.key?(:streaming_engine_state_tag_encoding_version) @user_step_to_state_family_name_map = args[:user_step_to_state_family_name_map] if args.key?(:user_step_to_state_family_name_map) @user_worker_runner_v1_settings = args[:user_worker_runner_v1_settings] if args.key?(:user_worker_runner_v1_settings) @user_worker_runner_v2_settings = args[:user_worker_runner_v2_settings] if args.key?(:user_worker_runner_v2_settings) @windmill_service_endpoint = args[:windmill_service_endpoint] if args.key?(:windmill_service_endpoint) @windmill_service_port = args[:windmill_service_port] if args.key?(:windmill_service_port) end |