Class: Google::Apis::DataflowV1b3::StreamingSetupTask

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

A task which initializes part of a streaming Dataflow job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamingSetupTask

Returns a new instance of StreamingSetupTask.



6723
6724
6725
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#drainBoolean Also known as: drain?

The user has requested drain. Corresponds to the JSON property drain

Returns:

  • (Boolean)


6697
6698
6699
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6697

def drain
  @drain
end

#receive_work_portFixnum

The TCP port on which the worker should listen for messages from other streaming computation workers. Corresponds to the JSON property receiveWorkPort

Returns:

  • (Fixnum)


6704
6705
6706
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6704

def receive_work_port
  @receive_work_port
end

#snapshot_configGoogle::Apis::DataflowV1b3::StreamingApplianceSnapshotConfig

Streaming appliance snapshot configuration. Corresponds to the JSON property snapshotConfig



6709
6710
6711
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6709

def snapshot_config
  @snapshot_config
end

#streaming_computation_topologyGoogle::Apis::DataflowV1b3::TopologyConfig

Global topology of the streaming Dataflow job, including all computations and their sharded locations. Corresponds to the JSON property streamingComputationTopology



6715
6716
6717
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6715

def streaming_computation_topology
  @streaming_computation_topology
end

#worker_harness_portFixnum

The TCP port used by the worker to communicate with the Dataflow worker harness. Corresponds to the JSON property workerHarnessPort

Returns:

  • (Fixnum)


6721
6722
6723
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6721

def worker_harness_port
  @worker_harness_port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6728
6729
6730
6731
6732
6733
6734
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6728

def update!(**args)
  @drain = args[:drain] if args.key?(:drain)
  @receive_work_port = args[:receive_work_port] if args.key?(:receive_work_port)
  @snapshot_config = args[:snapshot_config] if args.key?(:snapshot_config)
  @streaming_computation_topology = args[:streaming_computation_topology] if args.key?(:streaming_computation_topology)
  @worker_harness_port = args[:worker_harness_port] if args.key?(:worker_harness_port)
end