Class: Google::Apis::DataflowV1b3::StreamingSideInputLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Identifies the location of a streaming side input.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamingSideInputLocation

Returns a new instance of StreamingSideInputLocation.



6864
6865
6866
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#state_familyString

Identifies the state family where this side input is stored. Corresponds to the JSON property stateFamily

Returns:

  • (String)


6857
6858
6859
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6857

def state_family
  @state_family
end

#tagString

Identifies the particular side input within the streaming Dataflow job. Corresponds to the JSON property tag

Returns:

  • (String)


6862
6863
6864
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6862

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6869
6870
6871
6872
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6869

def update!(**args)
  @state_family = args[:state_family] if args.key?(:state_family)
  @tag = args[:tag] if args.key?(:tag)
end