Class: Google::Apis::DataflowV1b3::StreamingStragglerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Information useful for streaming straggler identification and debugging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamingStragglerInfo

Returns a new instance of StreamingStragglerInfo.



6924
6925
6926
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_watermark_lagString

The event-time watermark lag at the time of the straggler detection. Corresponds to the JSON property dataWatermarkLag

Returns:

  • (String)


6902
6903
6904
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6902

def data_watermark_lag
  @data_watermark_lag
end

#end_timeString

End time of this straggler. Corresponds to the JSON property endTime

Returns:

  • (String)


6907
6908
6909
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6907

def end_time
  @end_time
end

#start_timeString

Start time of this straggler. Corresponds to the JSON property startTime

Returns:

  • (String)


6912
6913
6914
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6912

def start_time
  @start_time
end

#system_watermark_lagString

The system watermark lag at the time of the straggler detection. Corresponds to the JSON property systemWatermarkLag

Returns:

  • (String)


6917
6918
6919
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6917

def system_watermark_lag
  @system_watermark_lag
end

#worker_nameString

Name of the worker where the straggler was detected. Corresponds to the JSON property workerName

Returns:

  • (String)


6922
6923
6924
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6922

def worker_name
  @worker_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6929
6930
6931
6932
6933
6934
6935
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6929

def update!(**args)
  @data_watermark_lag = args[:data_watermark_lag] if args.key?(:data_watermark_lag)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @system_watermark_lag = args[:system_watermark_lag] if args.key?(:system_watermark_lag)
  @worker_name = args[:worker_name] if args.key?(:worker_name)
end