Class: Google::Apis::DataflowV1b3::StructuredMessage
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::StructuredMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
A rich message format, including a human readable string, a key for identifying the message, and structured data associated with the message for programmatic consumption.
Instance Attribute Summary collapse
-
#message_key ⇒ String
Identifier for this message type.
-
#message_text ⇒ String
Human-readable version of message.
-
#parameters ⇒ Array<Google::Apis::DataflowV1b3::Parameter>
The structured data associated with this message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StructuredMessage
constructor
A new instance of StructuredMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StructuredMessage
Returns a new instance of StructuredMessage.
6874 6875 6876 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message_key ⇒ String
Identifier for this message type. Used by external systems to internationalize
or personalize message.
Corresponds to the JSON property messageKey
6862 6863 6864 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6862 def @message_key end |
#message_text ⇒ String
Human-readable version of message.
Corresponds to the JSON property messageText
6867 6868 6869 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6867 def @message_text end |
#parameters ⇒ Array<Google::Apis::DataflowV1b3::Parameter>
The structured data associated with this message.
Corresponds to the JSON property parameters
6872 6873 6874 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6872 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6879 6880 6881 6882 6883 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6879 def update!(**args) @message_key = args[:message_key] if args.key?(:message_key) @message_text = args[:message_text] if args.key?(:message_text) @parameters = args[:parameters] if args.key?(:parameters) end |