Class: Google::Apis::DataflowV1b3::TemplateMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Metadata describing a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TemplateMetadata

Returns a new instance of TemplateMetadata.



7182
7183
7184
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_streaming_modeString

Optional. Indicates the default streaming mode for a streaming template. Only valid if both supports_at_least_once and supports_exactly_once are true. Possible values: UNSPECIFIED, EXACTLY_ONCE and AT_LEAST_ONCE Corresponds to the JSON property defaultStreamingMode

Returns:

  • (String)


7142
7143
7144
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7142

def default_streaming_mode
  @default_streaming_mode
end

#descriptionString

Optional. A description of the template. Corresponds to the JSON property description

Returns:

  • (String)


7147
7148
7149
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7147

def description
  @description
end

#nameString

Required. The name of the template. Corresponds to the JSON property name

Returns:

  • (String)


7152
7153
7154
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7152

def name
  @name
end

#parametersArray<Google::Apis::DataflowV1b3::ParameterMetadata>

The parameters for the template. Corresponds to the JSON property parameters



7157
7158
7159
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7157

def parameters
  @parameters
end

#streamingBoolean Also known as: streaming?

Optional. Indicates if the template is streaming or not. Corresponds to the JSON property streaming

Returns:

  • (Boolean)


7162
7163
7164
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7162

def streaming
  @streaming
end

#supports_at_least_onceBoolean Also known as: supports_at_least_once?

Optional. Indicates if the streaming template supports at least once mode. Corresponds to the JSON property supportsAtLeastOnce

Returns:

  • (Boolean)


7168
7169
7170
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7168

def supports_at_least_once
  @supports_at_least_once
end

#supports_exactly_onceBoolean Also known as: supports_exactly_once?

Optional. Indicates if the streaming template supports exactly once mode. Corresponds to the JSON property supportsExactlyOnce

Returns:

  • (Boolean)


7174
7175
7176
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7174

def supports_exactly_once
  @supports_exactly_once
end

#yaml_definitionString

Optional. For future use. Corresponds to the JSON property yamlDefinition

Returns:

  • (String)


7180
7181
7182
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7180

def yaml_definition
  @yaml_definition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7187
7188
7189
7190
7191
7192
7193
7194
7195
7196
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7187

def update!(**args)
  @default_streaming_mode = args[:default_streaming_mode] if args.key?(:default_streaming_mode)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @streaming = args[:streaming] if args.key?(:streaming)
  @supports_at_least_once = args[:supports_at_least_once] if args.key?(:supports_at_least_once)
  @supports_exactly_once = args[:supports_exactly_once] if args.key?(:supports_exactly_once)
  @yaml_definition = args[:yaml_definition] if args.key?(:yaml_definition)
end