Class: Google::Apis::DataflowV1b3::TopologyConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::TopologyConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Global topology of the streaming Dataflow job, including all computations and their sharded locations.
Instance Attribute Summary collapse
-
#computations ⇒ Array<Google::Apis::DataflowV1b3::ComputationTopology>
The computations associated with a streaming Dataflow job.
-
#data_disk_assignments ⇒ Array<Google::Apis::DataflowV1b3::DataDiskAssignment>
The disks assigned to a streaming Dataflow job.
-
#forwarding_key_bits ⇒ Fixnum
The size (in bits) of keys that will be assigned to source messages.
-
#persistent_state_version ⇒ Fixnum
Version number for persistent state.
-
#user_stage_to_computation_name_map ⇒ Hash<String,String>
Maps user stage names to stable computation names.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TopologyConfig
constructor
A new instance of TopologyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TopologyConfig
Returns a new instance of TopologyConfig.
7124 7125 7126 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7124 def initialize(**args) update!(**args) end |
Instance Attribute Details
#computations ⇒ Array<Google::Apis::DataflowV1b3::ComputationTopology>
The computations associated with a streaming Dataflow job.
Corresponds to the JSON property computations
7102 7103 7104 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7102 def computations @computations end |
#data_disk_assignments ⇒ Array<Google::Apis::DataflowV1b3::DataDiskAssignment>
The disks assigned to a streaming Dataflow job.
Corresponds to the JSON property dataDiskAssignments
7107 7108 7109 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7107 def data_disk_assignments @data_disk_assignments end |
#forwarding_key_bits ⇒ Fixnum
The size (in bits) of keys that will be assigned to source messages.
Corresponds to the JSON property forwardingKeyBits
7112 7113 7114 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7112 def forwarding_key_bits @forwarding_key_bits end |
#persistent_state_version ⇒ Fixnum
Version number for persistent state.
Corresponds to the JSON property persistentStateVersion
7117 7118 7119 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7117 def persistent_state_version @persistent_state_version end |
#user_stage_to_computation_name_map ⇒ Hash<String,String>
Maps user stage names to stable computation names.
Corresponds to the JSON property userStageToComputationNameMap
7122 7123 7124 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7122 def user_stage_to_computation_name_map @user_stage_to_computation_name_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7129 7130 7131 7132 7133 7134 7135 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7129 def update!(**args) @computations = args[:computations] if args.key?(:computations) @data_disk_assignments = args[:data_disk_assignments] if args.key?(:data_disk_assignments) @forwarding_key_bits = args[:forwarding_key_bits] if args.key?(:forwarding_key_bits) @persistent_state_version = args[:persistent_state_version] if args.key?(:persistent_state_version) @user_stage_to_computation_name_map = args[:user_stage_to_computation_name_map] if args.key?(:user_stage_to_computation_name_map) end |