Class: Google::Apis::DataflowV1b3::TransformSummary
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::TransformSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Description of the type, names/ids, and input/outputs for a transform.
Instance Attribute Summary collapse
-
#display_data ⇒ Array<Google::Apis::DataflowV1b3::DisplayData>
Transform-specific display data.
-
#id ⇒ String
SDK generated id of this transform instance.
-
#input_collection_name ⇒ Array<String>
User names for all collection inputs to this transform.
-
#kind ⇒ String
Type of transform.
-
#name ⇒ String
User provided name for this transform instance.
-
#output_collection_name ⇒ Array<String>
User names for all collection outputs to this transform.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransformSummary
constructor
A new instance of TransformSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransformSummary
Returns a new instance of TransformSummary.
7277 7278 7279 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_data ⇒ Array<Google::Apis::DataflowV1b3::DisplayData>
Transform-specific display data.
Corresponds to the JSON property displayData
7250 7251 7252 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7250 def display_data @display_data end |
#id ⇒ String
SDK generated id of this transform instance.
Corresponds to the JSON property id
7255 7256 7257 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7255 def id @id end |
#input_collection_name ⇒ Array<String>
User names for all collection inputs to this transform.
Corresponds to the JSON property inputCollectionName
7260 7261 7262 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7260 def input_collection_name @input_collection_name end |
#kind ⇒ String
Type of transform.
Corresponds to the JSON property kind
7265 7266 7267 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7265 def kind @kind end |
#name ⇒ String
User provided name for this transform instance.
Corresponds to the JSON property name
7270 7271 7272 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7270 def name @name end |
#output_collection_name ⇒ Array<String>
User names for all collection outputs to this transform.
Corresponds to the JSON property outputCollectionName
7275 7276 7277 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7275 def output_collection_name @output_collection_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7282 7283 7284 7285 7286 7287 7288 7289 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7282 def update!(**args) @display_data = args[:display_data] if args.key?(:display_data) @id = args[:id] if args.key?(:id) @input_collection_name = args[:input_collection_name] if args.key?(:input_collection_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @output_collection_name = args[:output_collection_name] if args.key?(:output_collection_name) end |