Class: Google::Apis::DataflowV1b3::WorkItemServiceState
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkItemServiceState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
The Dataflow service's idea of the current state of a WorkItem being processed by a worker.
Instance Attribute Summary collapse
-
#complete_work_status ⇒ Google::Apis::DataflowV1b3::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#harness_data ⇒ Hash<String,Object>
Other data returned by the service, specific to the particular worker harness.
-
#hot_key_detection ⇒ Google::Apis::DataflowV1b3::HotKeyDetection
Proto describing a hot key detected on a given WorkItem.
-
#lease_expire_time ⇒ String
Time at which the current lease will expire.
-
#metric_short_id ⇒ Array<Google::Apis::DataflowV1b3::MetricShortId>
The short ids that workers should use in subsequent metric updates.
-
#next_report_index ⇒ Fixnum
The index value to use for the next report sent by the worker.
-
#report_status_interval ⇒ String
New recommended reporting interval.
-
#split_request ⇒ Google::Apis::DataflowV1b3::ApproximateSplitRequest
A suggestion by the service to the worker to dynamically split the WorkItem.
-
#suggested_stop_point ⇒ Google::Apis::DataflowV1b3::ApproximateProgress
Obsolete in favor of ApproximateReportedProgress and ApproximateSplitRequest.
-
#suggested_stop_position ⇒ Google::Apis::DataflowV1b3::Position
Position defines a position within a collection of data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkItemServiceState
constructor
A new instance of WorkItemServiceState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkItemServiceState
Returns a new instance of WorkItemServiceState.
7532 7533 7534 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#complete_work_status ⇒ Google::Apis::DataflowV1b3::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property completeWorkStatus
7477 7478 7479 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7477 def complete_work_status @complete_work_status end |
#harness_data ⇒ Hash<String,Object>
Other data returned by the service, specific to the particular worker harness.
Corresponds to the JSON property harnessData
7482 7483 7484 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7482 def harness_data @harness_data end |
#hot_key_detection ⇒ Google::Apis::DataflowV1b3::HotKeyDetection
Proto describing a hot key detected on a given WorkItem.
Corresponds to the JSON property hotKeyDetection
7487 7488 7489 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7487 def hot_key_detection @hot_key_detection end |
#lease_expire_time ⇒ String
Time at which the current lease will expire.
Corresponds to the JSON property leaseExpireTime
7492 7493 7494 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7492 def lease_expire_time @lease_expire_time end |
#metric_short_id ⇒ Array<Google::Apis::DataflowV1b3::MetricShortId>
The short ids that workers should use in subsequent metric updates. Workers
should strive to use short ids whenever possible, but it is ok to request the
short_id again if a worker lost track of it (e.g. if the worker is recovering
from a crash). NOTE: it is possible that the response may have short ids for a
subset of the metrics.
Corresponds to the JSON property metricShortId
7501 7502 7503 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7501 def metric_short_id @metric_short_id end |
#next_report_index ⇒ Fixnum
The index value to use for the next report sent by the worker. Note: If the
report call fails for whatever reason, the worker should reuse this index for
subsequent report attempts.
Corresponds to the JSON property nextReportIndex
7508 7509 7510 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7508 def next_report_index @next_report_index end |
#report_status_interval ⇒ String
New recommended reporting interval.
Corresponds to the JSON property reportStatusInterval
7513 7514 7515 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7513 def report_status_interval @report_status_interval end |
#split_request ⇒ Google::Apis::DataflowV1b3::ApproximateSplitRequest
A suggestion by the service to the worker to dynamically split the WorkItem.
Corresponds to the JSON property splitRequest
7518 7519 7520 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7518 def split_request @split_request end |
#suggested_stop_point ⇒ Google::Apis::DataflowV1b3::ApproximateProgress
Obsolete in favor of ApproximateReportedProgress and ApproximateSplitRequest.
Corresponds to the JSON property suggestedStopPoint
7523 7524 7525 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7523 def suggested_stop_point @suggested_stop_point end |
#suggested_stop_position ⇒ Google::Apis::DataflowV1b3::Position
Position defines a position within a collection of data. The value can be
either the end position, a key (used with ordered collections), a byte offset,
or a record index.
Corresponds to the JSON property suggestedStopPosition
7530 7531 7532 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7530 def suggested_stop_position @suggested_stop_position end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7537 def update!(**args) @complete_work_status = args[:complete_work_status] if args.key?(:complete_work_status) @harness_data = args[:harness_data] if args.key?(:harness_data) @hot_key_detection = args[:hot_key_detection] if args.key?(:hot_key_detection) @lease_expire_time = args[:lease_expire_time] if args.key?(:lease_expire_time) @metric_short_id = args[:metric_short_id] if args.key?(:metric_short_id) @next_report_index = args[:next_report_index] if args.key?(:next_report_index) @report_status_interval = args[:report_status_interval] if args.key?(:report_status_interval) @split_request = args[:split_request] if args.key?(:split_request) @suggested_stop_point = args[:suggested_stop_point] if args.key?(:suggested_stop_point) @suggested_stop_position = args[:suggested_stop_position] if args.key?(:suggested_stop_position) end |