Class: Google::Apis::DataflowV1b3::WorkerHealthReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

WorkerHealthReportResponse contains information returned to the worker in response to a health ping.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkerHealthReportResponse

Returns a new instance of WorkerHealthReportResponse.



7765
7766
7767
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#report_intervalString

A positive value indicates the worker should change its reporting interval to the specified value. The default value of zero means no change in report rate is requested by the server. Corresponds to the JSON property reportInterval

Returns:

  • (String)


7763
7764
7765
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7763

def report_interval
  @report_interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7770
7771
7772
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7770

def update!(**args)
  @report_interval = args[:report_interval] if args.key?(:report_interval)
end