Class: Google::Apis::DataflowV1b3::WriteInstruction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

An instruction that writes records. Takes one input, produces no outputs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WriteInstruction

Returns a new instance of WriteInstruction.



8331
8332
8333
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inputGoogle::Apis::DataflowV1b3::InstructionInput

An input of an instruction, as a reference to an output of a producer instruction. Corresponds to the JSON property input



8324
8325
8326
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8324

def input
  @input
end

#sinkGoogle::Apis::DataflowV1b3::Sink

A sink that records can be encoded and written to. Corresponds to the JSON property sink



8329
8330
8331
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8329

def sink
  @sink
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8336
8337
8338
8339
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8336

def update!(**args)
  @input = args[:input] if args.key?(:input)
  @sink = args[:sink] if args.key?(:sink)
end