Class: Google::Apis::DataflowV1b3::BoundedTrie
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::BoundedTrie
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
The message type used for encoding metrics of type bounded trie.
Instance Attribute Summary collapse
-
#bound ⇒ Fixnum
The maximum number of elements to store before truncation.
-
#root ⇒ Google::Apis::DataflowV1b3::BoundedTrieNode
A single node in a BoundedTrie.
-
#singleton ⇒ Array<String>
A more efficient representation for metrics consisting of a single value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BoundedTrie
constructor
A new instance of BoundedTrie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BoundedTrie
Returns a new instance of BoundedTrie.
391 392 393 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 391 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bound ⇒ Fixnum
The maximum number of elements to store before truncation.
Corresponds to the JSON property bound
379 380 381 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 379 def bound @bound end |
#root ⇒ Google::Apis::DataflowV1b3::BoundedTrieNode
A single node in a BoundedTrie.
Corresponds to the JSON property root
384 385 386 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 384 def root @root end |
#singleton ⇒ Array<String>
A more efficient representation for metrics consisting of a single value.
Corresponds to the JSON property singleton
389 390 391 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 389 def singleton @singleton end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
396 397 398 399 400 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 396 def update!(**args) @bound = args[:bound] if args.key?(:bound) @root = args[:root] if args.key?(:root) @singleton = args[:singleton] if args.key?(:singleton) end |