Class: Google::Apis::DataflowV1b3::CounterUpdate
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::CounterUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
An update to a Counter sent from a worker. Next ID: 17
Instance Attribute Summary collapse
-
#boolean ⇒ Boolean
(also: #boolean?)
Boolean value for And, Or.
-
#bounded_trie ⇒ Google::Apis::DataflowV1b3::BoundedTrie
The message type used for encoding metrics of type bounded trie.
-
#cumulative ⇒ Boolean
(also: #cumulative?)
True if this counter is reported as the total cumulative aggregate value accumulated since the worker started working on this WorkItem.
-
#distribution ⇒ Google::Apis::DataflowV1b3::DistributionUpdate
A metric value representing a distribution.
-
#floating_point ⇒ Float
Floating point value for Sum, Max, Min.
-
#floating_point_list ⇒ Google::Apis::DataflowV1b3::FloatingPointList
A metric value representing a list of floating point numbers.
-
#floating_point_mean ⇒ Google::Apis::DataflowV1b3::FloatingPointMean
A representation of a floating point mean metric contribution.
-
#integer ⇒ Google::Apis::DataflowV1b3::SplitInt64
A representation of an int64, n, that is immune to precision loss when encoded in JSON.
-
#integer_gauge ⇒ Google::Apis::DataflowV1b3::IntegerGauge
A metric value representing temporal values of a variable.
-
#integer_list ⇒ Google::Apis::DataflowV1b3::IntegerList
A metric value representing a list of integers.
-
#integer_mean ⇒ Google::Apis::DataflowV1b3::IntegerMean
A representation of an integer mean metric contribution.
-
#internal ⇒ Object
Value for internally-defined counters used by the Dataflow service.
-
#name_and_kind ⇒ Google::Apis::DataflowV1b3::NameAndKind
Basic metadata about a counter.
-
#short_id ⇒ Fixnum
The service-generated short identifier for this counter.
-
#string_list ⇒ Google::Apis::DataflowV1b3::StringList
A metric value representing a list of strings.
-
#structured_name_and_metadata ⇒ Google::Apis::DataflowV1b3::CounterStructuredNameAndMetadata
A single message which encapsulates structured name and metadata for a given counter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CounterUpdate
constructor
A new instance of CounterUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CounterUpdate
Returns a new instance of CounterUpdate.
924 925 926 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean ⇒ Boolean Also known as: boolean?
Boolean value for And, Or.
Corresponds to the JSON property boolean
840 841 842 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 840 def boolean @boolean end |
#bounded_trie ⇒ Google::Apis::DataflowV1b3::BoundedTrie
The message type used for encoding metrics of type bounded trie.
Corresponds to the JSON property boundedTrie
846 847 848 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 846 def bounded_trie @bounded_trie end |
#cumulative ⇒ Boolean Also known as: cumulative?
True if this counter is reported as the total cumulative aggregate value
accumulated since the worker started working on this WorkItem. By default this
is false, indicating that this counter is reported as a delta.
Corresponds to the JSON property cumulative
853 854 855 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 853 def cumulative @cumulative end |
#distribution ⇒ Google::Apis::DataflowV1b3::DistributionUpdate
A metric value representing a distribution.
Corresponds to the JSON property distribution
859 860 861 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 859 def distribution @distribution end |
#floating_point ⇒ Float
Floating point value for Sum, Max, Min.
Corresponds to the JSON property floatingPoint
864 865 866 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 864 def floating_point @floating_point end |
#floating_point_list ⇒ Google::Apis::DataflowV1b3::FloatingPointList
A metric value representing a list of floating point numbers.
Corresponds to the JSON property floatingPointList
869 870 871 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 869 def floating_point_list @floating_point_list end |
#floating_point_mean ⇒ Google::Apis::DataflowV1b3::FloatingPointMean
A representation of a floating point mean metric contribution.
Corresponds to the JSON property floatingPointMean
874 875 876 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 874 def floating_point_mean @floating_point_mean end |
#integer ⇒ Google::Apis::DataflowV1b3::SplitInt64
A representation of an int64, n, that is immune to precision loss when encoded
in JSON.
Corresponds to the JSON property integer
880 881 882 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 880 def integer @integer end |
#integer_gauge ⇒ Google::Apis::DataflowV1b3::IntegerGauge
A metric value representing temporal values of a variable.
Corresponds to the JSON property integerGauge
885 886 887 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 885 def integer_gauge @integer_gauge end |
#integer_list ⇒ Google::Apis::DataflowV1b3::IntegerList
A metric value representing a list of integers.
Corresponds to the JSON property integerList
890 891 892 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 890 def integer_list @integer_list end |
#integer_mean ⇒ Google::Apis::DataflowV1b3::IntegerMean
A representation of an integer mean metric contribution.
Corresponds to the JSON property integerMean
895 896 897 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 895 def integer_mean @integer_mean end |
#internal ⇒ Object
Value for internally-defined counters used by the Dataflow service.
Corresponds to the JSON property internal
900 901 902 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 900 def internal @internal end |
#name_and_kind ⇒ Google::Apis::DataflowV1b3::NameAndKind
Basic metadata about a counter.
Corresponds to the JSON property nameAndKind
905 906 907 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 905 def name_and_kind @name_and_kind end |
#short_id ⇒ Fixnum
The service-generated short identifier for this counter. The short_id -> (name,
metadata) mapping is constant for the lifetime of a job.
Corresponds to the JSON property shortId
911 912 913 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 911 def short_id @short_id end |
#string_list ⇒ Google::Apis::DataflowV1b3::StringList
A metric value representing a list of strings.
Corresponds to the JSON property stringList
916 917 918 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 916 def string_list @string_list end |
#structured_name_and_metadata ⇒ Google::Apis::DataflowV1b3::CounterStructuredNameAndMetadata
A single message which encapsulates structured name and metadata for a given
counter.
Corresponds to the JSON property structuredNameAndMetadata
922 923 924 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 922 def @structured_name_and_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 929 def update!(**args) @boolean = args[:boolean] if args.key?(:boolean) @bounded_trie = args[:bounded_trie] if args.key?(:bounded_trie) @cumulative = args[:cumulative] if args.key?(:cumulative) @distribution = args[:distribution] if args.key?(:distribution) @floating_point = args[:floating_point] if args.key?(:floating_point) @floating_point_list = args[:floating_point_list] if args.key?(:floating_point_list) @floating_point_mean = args[:floating_point_mean] if args.key?(:floating_point_mean) @integer = args[:integer] if args.key?(:integer) @integer_gauge = args[:integer_gauge] if args.key?(:integer_gauge) @integer_list = args[:integer_list] if args.key?(:integer_list) @integer_mean = args[:integer_mean] if args.key?(:integer_mean) @internal = args[:internal] if args.key?(:internal) @name_and_kind = args[:name_and_kind] if args.key?(:name_and_kind) @short_id = args[:short_id] if args.key?(:short_id) @string_list = args[:string_list] if args.key?(:string_list) @structured_name_and_metadata = args[:structured_name_and_metadata] if args.key?(:structured_name_and_metadata) end |