Class: Google::Apis::DataflowV1b3::GetTemplateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

The response to a GetTemplate request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetTemplateResponse

Returns a new instance of GetTemplateResponse.



2151
2152
2153
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataGoogle::Apis::DataflowV1b3::TemplateMetadata

Metadata describing a template. Corresponds to the JSON property metadata



2129
2130
2131
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2129

def 
  @metadata
end

#runtime_metadataGoogle::Apis::DataflowV1b3::RuntimeMetadata

RuntimeMetadata describing a runtime environment. Corresponds to the JSON property runtimeMetadata



2134
2135
2136
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2134

def 
  @runtime_metadata
end

#statusGoogle::Apis::DataflowV1b3::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



2144
2145
2146
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2144

def status
  @status
end

#template_typeString

Template Type. Corresponds to the JSON property templateType

Returns:

  • (String)


2149
2150
2151
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2149

def template_type
  @template_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2156
2157
2158
2159
2160
2161
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2156

def update!(**args)
  @metadata = args[:metadata] if args.key?(:metadata)
  @runtime_metadata = args[:runtime_metadata] if args.key?(:runtime_metadata)
  @status = args[:status] if args.key?(:status)
  @template_type = args[:template_type] if args.key?(:template_type)
end