Class: Google::Apis::DataflowV1b3::InstructionInput
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::InstructionInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
An input of an instruction, as a reference to an output of a producer instruction.
Instance Attribute Summary collapse
-
#output_num ⇒ Fixnum
The output index (origin zero) within the producer.
-
#producer_instruction_index ⇒ Fixnum
The index (origin zero) of the parallel instruction that produces the output to be consumed by this input.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstructionInput
constructor
A new instance of InstructionInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstructionInput
Returns a new instance of InstructionInput.
2347 2348 2349 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2347 def initialize(**args) update!(**args) end |
Instance Attribute Details
#output_num ⇒ Fixnum
The output index (origin zero) within the producer.
Corresponds to the JSON property outputNum
2338 2339 2340 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2338 def output_num @output_num end |
#producer_instruction_index ⇒ Fixnum
The index (origin zero) of the parallel instruction that produces the output
to be consumed by this input. This index is relative to the list of
instructions in this input's instruction's containing MapTask.
Corresponds to the JSON property producerInstructionIndex
2345 2346 2347 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2345 def producer_instruction_index @producer_instruction_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2352 2353 2354 2355 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2352 def update!(**args) @output_num = args[:output_num] if args.key?(:output_num) @producer_instruction_index = args[:producer_instruction_index] if args.key?(:producer_instruction_index) end |