Class: Google::Apis::DataflowV1b3::InstructionOutput
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::InstructionOutput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
An output of an instruction.
Instance Attribute Summary collapse
-
#codec ⇒ Hash<String,Object>
The codec to use to encode data being written via this output.
-
#name ⇒ String
The user-provided name of this output.
-
#only_count_key_bytes ⇒ Boolean
(also: #only_count_key_bytes?)
For system-generated byte and mean byte metrics, certain instructions should only report the key size.
-
#only_count_value_bytes ⇒ Boolean
(also: #only_count_value_bytes?)
For system-generated byte and mean byte metrics, certain instructions should only report the value size.
-
#original_name ⇒ String
System-defined name for this output in the original workflow graph.
-
#system_name ⇒ String
System-defined name of this output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstructionOutput
constructor
A new instance of InstructionOutput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstructionOutput
Returns a new instance of InstructionOutput.
2397 2398 2399 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#codec ⇒ Hash<String,Object>
The codec to use to encode data being written via this output.
Corresponds to the JSON property codec
2365 2366 2367 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2365 def codec @codec end |
#name ⇒ String
The user-provided name of this output.
Corresponds to the JSON property name
2370 2371 2372 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2370 def name @name end |
#only_count_key_bytes ⇒ Boolean Also known as: only_count_key_bytes?
For system-generated byte and mean byte metrics, certain instructions should
only report the key size.
Corresponds to the JSON property onlyCountKeyBytes
2376 2377 2378 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2376 def only_count_key_bytes @only_count_key_bytes end |
#only_count_value_bytes ⇒ Boolean Also known as: only_count_value_bytes?
For system-generated byte and mean byte metrics, certain instructions should
only report the value size.
Corresponds to the JSON property onlyCountValueBytes
2383 2384 2385 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2383 def only_count_value_bytes @only_count_value_bytes end |
#original_name ⇒ String
System-defined name for this output in the original workflow graph. Outputs
that do not contribute to an original instruction do not set this.
Corresponds to the JSON property originalName
2390 2391 2392 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2390 def original_name @original_name end |
#system_name ⇒ String
System-defined name of this output. Unique across the workflow.
Corresponds to the JSON property systemName
2395 2396 2397 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2395 def system_name @system_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2402 2403 2404 2405 2406 2407 2408 2409 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2402 def update!(**args) @codec = args[:codec] if args.key?(:codec) @name = args[:name] if args.key?(:name) @only_count_key_bytes = args[:only_count_key_bytes] if args.key?(:only_count_key_bytes) @only_count_value_bytes = args[:only_count_value_bytes] if args.key?(:only_count_value_bytes) @original_name = args[:original_name] if args.key?(:original_name) @system_name = args[:system_name] if args.key?(:system_name) end |