Class: Google::Apis::DataflowV1b3::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Defines a job to be run by the Cloud Dataflow service. Do not enter confidential information when you supply string values using the API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



2688
2689
2690
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_request_idString

The client's unique identifier of the job, re-used across retried attempts. If this field is set, the service will ensure its uniqueness. The request to create a job will fail if the service has knowledge of a previously submitted job with the same client's ID and job name. The caller may use this field to ensure idempotence of job creation across retried attempts to create a job. By default, the field is empty and, in that case, the service ignores it. Corresponds to the JSON property clientRequestId

Returns:

  • (String)


2497
2498
2499
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2497

def client_request_id
  @client_request_id
end

#create_timeString

The timestamp when the job was initially created. Immutable and set by the Cloud Dataflow service. Corresponds to the JSON property createTime

Returns:

  • (String)


2503
2504
2505
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2503

def create_time
  @create_time
end

#created_from_snapshot_idString

If this is specified, the job's initial state is populated from the given snapshot. Corresponds to the JSON property createdFromSnapshotId

Returns:

  • (String)


2509
2510
2511
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2509

def created_from_snapshot_id
  @created_from_snapshot_id
end

#current_stateString

The current state of the job. Jobs are created in the JOB_STATE_STOPPED state unless otherwise specified. A job in the JOB_STATE_RUNNING state may asynchronously enter a terminal state. After a job has reached a terminal state, no further state updates may be made. This field might be mutated by the Dataflow service; callers cannot mutate it. Corresponds to the JSON property currentState

Returns:

  • (String)


2518
2519
2520
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2518

def current_state
  @current_state
end

#current_state_timeString

The timestamp associated with the current state. Corresponds to the JSON property currentStateTime

Returns:

  • (String)


2523
2524
2525
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2523

def current_state_time
  @current_state_time
end

#environmentGoogle::Apis::DataflowV1b3::Environment

Describes the environment in which a Dataflow Job runs. Corresponds to the JSON property environment



2528
2529
2530
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2528

def environment
  @environment
end

#execution_infoGoogle::Apis::DataflowV1b3::JobExecutionInfo

Additional information about how a Cloud Dataflow job will be executed that isn't contained in the submitted job. Corresponds to the JSON property executionInfo



2534
2535
2536
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2534

def execution_info
  @execution_info
end

#idString

The unique ID of this job. This field is set by the Dataflow service when the job is created, and is immutable for the life of the job. Corresponds to the JSON property id

Returns:

  • (String)


2540
2541
2542
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2540

def id
  @id
end

#job_metadataGoogle::Apis::DataflowV1b3::JobMetadata

Metadata available primarily for filtering jobs. Will be included in the ListJob response and Job SUMMARY view. Corresponds to the JSON property jobMetadata



2546
2547
2548
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2546

def 
  @job_metadata
end

#labelsHash<String,String>

User-defined labels for this job. The labels map can contain no more than 64 entries. Entries of the labels map are UTF8 strings that comply with the following restrictions: * Keys must conform to regexp: \pLl\pLo0,62 * Values must conform to regexp: [\pLl\pLo\pN_-]0,63 * Both keys and values are additionally constrained to be <= 128 bytes in size. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2555
2556
2557
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2555

def labels
  @labels
end

#locationString

Optional. The regional endpoint that contains this job. Corresponds to the JSON property location

Returns:

  • (String)


2561
2562
2563
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2561

def location
  @location
end

#nameString

Optional. The user-specified Dataflow job name. Only one active job with a given name can exist in a project within one region at any given time. Jobs in different regions can have the same name. If a caller attempts to create a job with the same name as an active job that already exists, the attempt returns the existing job. The name must match the regular expression [a-z]([-a-z0-9] 0,1022[a-z0-9])? Corresponds to the JSON property name

Returns:

  • (String)


2571
2572
2573
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2571

def name
  @name
end

#pausableBoolean Also known as: pausable?

Output only. Indicates whether the job can be paused. Corresponds to the JSON property pausable

Returns:

  • (Boolean)


2576
2577
2578
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2576

def pausable
  @pausable
end

#pipeline_descriptionGoogle::Apis::DataflowV1b3::PipelineDescription

A descriptive representation of submitted pipeline as well as the executed form. This data is provided by the Dataflow service for ease of visualizing the pipeline and interpreting Dataflow provided metrics. Corresponds to the JSON property pipelineDescription



2584
2585
2586
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2584

def pipeline_description
  @pipeline_description
end

#project_idString

The ID of the Google Cloud project that the job belongs to. Corresponds to the JSON property projectId

Returns:

  • (String)


2589
2590
2591
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2589

def project_id
  @project_id
end

#replace_job_idString

If this job is an update of an existing job, this field is the job ID of the job it replaced. When sending a CreateJobRequest, you can update a job by specifying it here. The job named here is stopped, and its intermediate state is transferred to this job. Corresponds to the JSON property replaceJobId

Returns:

  • (String)


2597
2598
2599
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2597

def replace_job_id
  @replace_job_id
end

#replaced_by_job_idString

If another job is an update of this job (and thus, this job is in JOB_STATE_UPDATED), this field contains the ID of that job. Corresponds to the JSON property replacedByJobId

Returns:

  • (String)


2603
2604
2605
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2603

def replaced_by_job_id
  @replaced_by_job_id
end

#requested_stateString

The job's requested state. Applies to UpdateJob requests. Set requested_state with UpdateJob requests to switch between the states JOB_STATE_STOPPED and JOB_STATE_RUNNING. You can also use UpdateJob requests to change a job's state from JOB_STATE_RUNNING to JOB_STATE_CANCELLED, JOB_STATE_DONE, or JOB_STATE_DRAINED. These states irrevocably terminate the job if it hasn't already reached a terminal state. This field has no effect on CreateJob requests. Corresponds to the JSON property requestedState

Returns:

  • (String)


2614
2615
2616
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2614

def requested_state
  @requested_state
end

#runtime_updatable_paramsGoogle::Apis::DataflowV1b3::RuntimeUpdatableParams

Additional job parameters that can only be updated during runtime using the projects.jobs.update method. These fields have no effect when specified during job creation. Corresponds to the JSON property runtimeUpdatableParams



2621
2622
2623
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2621

def runtime_updatable_params
  @runtime_updatable_params
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. This field is set only in responses from the server; it is ignored if it is set in any requests. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


2627
2628
2629
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2627

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Reserved for future use. This field is set only in responses from the server; it is ignored if it is set in any requests. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2634
2635
2636
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2634

def satisfies_pzs
  @satisfies_pzs
end

#service_resourcesGoogle::Apis::DataflowV1b3::ServiceResources

Resources used by the Dataflow Service to run the job. Corresponds to the JSON property serviceResources



2640
2641
2642
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2640

def service_resources
  @service_resources
end

#stage_statesArray<Google::Apis::DataflowV1b3::ExecutionStageState>

This field may be mutated by the Cloud Dataflow service; callers cannot mutate it. Corresponds to the JSON property stageStates



2646
2647
2648
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2646

def stage_states
  @stage_states
end

#start_timeString

The timestamp when the job was started (transitioned to JOB_STATE_PENDING). Flexible resource scheduling jobs are started with some delay after job creation, so start_time is unset before start and is updated when the job is started by the Cloud Dataflow service. For other jobs, start_time always equals to create_time and is immutable and set by the Cloud Dataflow service. Corresponds to the JSON property startTime

Returns:

  • (String)


2655
2656
2657
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2655

def start_time
  @start_time
end

#stepsArray<Google::Apis::DataflowV1b3::Step>

Exactly one of step or steps_location should be specified. The top-level steps that constitute the entire job. Only retrieved with JOB_VIEW_ALL. Corresponds to the JSON property steps



2661
2662
2663
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2661

def steps
  @steps
end

#steps_locationString

The Cloud Storage location where the steps are stored. Corresponds to the JSON property stepsLocation

Returns:

  • (String)


2666
2667
2668
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2666

def steps_location
  @steps_location
end

#temp_filesArray<String>

A set of files the system should be aware of that are used for temporary storage. These temporary files will be removed on job completion. No duplicates are allowed. No file patterns are supported. The supported files are: Google Cloud Storage: storage.googleapis.com/bucket/object bucket. storage.googleapis.com/object Corresponds to the JSON property tempFiles

Returns:

  • (Array<String>)


2675
2676
2677
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2675

def temp_files
  @temp_files
end

#transform_name_mappingHash<String,String>

Optional. The map of transform name prefixes of the job to be replaced to the corresponding name prefixes of the new job. Corresponds to the JSON property transformNameMapping

Returns:

  • (Hash<String,String>)


2681
2682
2683
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2681

def transform_name_mapping
  @transform_name_mapping
end

#typeString

Optional. The type of Dataflow job. Corresponds to the JSON property type

Returns:

  • (String)


2686
2687
2688
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2686

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
2704
2705
2706
2707
2708
2709
2710
2711
2712
2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2693

def update!(**args)
  @client_request_id = args[:client_request_id] if args.key?(:client_request_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @created_from_snapshot_id = args[:created_from_snapshot_id] if args.key?(:created_from_snapshot_id)
  @current_state = args[:current_state] if args.key?(:current_state)
  @current_state_time = args[:current_state_time] if args.key?(:current_state_time)
  @environment = args[:environment] if args.key?(:environment)
  @execution_info = args[:execution_info] if args.key?(:execution_info)
  @id = args[:id] if args.key?(:id)
  @job_metadata = args[:job_metadata] if args.key?(:job_metadata)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @pausable = args[:pausable] if args.key?(:pausable)
  @pipeline_description = args[:pipeline_description] if args.key?(:pipeline_description)
  @project_id = args[:project_id] if args.key?(:project_id)
  @replace_job_id = args[:replace_job_id] if args.key?(:replace_job_id)
  @replaced_by_job_id = args[:replaced_by_job_id] if args.key?(:replaced_by_job_id)
  @requested_state = args[:requested_state] if args.key?(:requested_state)
  @runtime_updatable_params = args[:runtime_updatable_params] if args.key?(:runtime_updatable_params)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_resources = args[:service_resources] if args.key?(:service_resources)
  @stage_states = args[:stage_states] if args.key?(:stage_states)
  @start_time = args[:start_time] if args.key?(:start_time)
  @steps = args[:steps] if args.key?(:steps)
  @steps_location = args[:steps_location] if args.key?(:steps_location)
  @temp_files = args[:temp_files] if args.key?(:temp_files)
  @transform_name_mapping = args[:transform_name_mapping] if args.key?(:transform_name_mapping)
  @type = args[:type] if args.key?(:type)
end