Class: Google::Apis::DataflowV1b3::KeyRangeDataDiskAssignment
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::KeyRangeDataDiskAssignment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Data disk assignment information for a specific key-range of a sharded computation. Currently we only support UTF-8 character splits to simplify encoding into JSON.
Instance Attribute Summary collapse
-
#data_disk ⇒ String
The name of the data disk where data for this range is stored.
-
#end ⇒ String
The end (exclusive) of the key range.
-
#start ⇒ String
The start (inclusive) of the key range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyRangeDataDiskAssignment
constructor
A new instance of KeyRangeDataDiskAssignment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyRangeDataDiskAssignment
Returns a new instance of KeyRangeDataDiskAssignment.
2945 2946 2947 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_disk ⇒ String
The name of the data disk where data for this range is stored. This name is
local to the Google Cloud Platform project and uniquely identifies the disk
within that project, for example "myproject-1014-104817-4c2-harness-0-disk-1".
Corresponds to the JSON property dataDisk
2933 2934 2935 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2933 def data_disk @data_disk end |
#end ⇒ String
The end (exclusive) of the key range.
Corresponds to the JSON property end
2938 2939 2940 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2938 def end @end end |
#start ⇒ String
The start (inclusive) of the key range.
Corresponds to the JSON property start
2943 2944 2945 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2943 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2950 2951 2952 2953 2954 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2950 def update!(**args) @data_disk = args[:data_disk] if args.key?(:data_disk) @end = args[:end] if args.key?(:end) @start = args[:start] if args.key?(:start) end |