Class: Google::Apis::DataflowV1b3::KeyRangeLocation
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::KeyRangeLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Location information for a specific key-range of a sharded computation. Currently we only support UTF-8 character splits to simplify encoding into JSON.
Instance Attribute Summary collapse
-
#data_disk ⇒ String
The name of the data disk where data for this range is stored.
-
#delivery_endpoint ⇒ String
The physical location of this range assignment to be used for streaming computation cross-worker message delivery.
-
#deprecated_persistent_directory ⇒ String
DEPRECATED.
-
#end ⇒ String
The end (exclusive) of the key range.
-
#start ⇒ String
The start (inclusive) of the key range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ KeyRangeLocation
constructor
A new instance of KeyRangeLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ KeyRangeLocation
Returns a new instance of KeyRangeLocation.
2992 2993 2994 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_disk ⇒ String
The name of the data disk where data for this range is stored. This name is
local to the Google Cloud Platform project and uniquely identifies the disk
within that project, for example "myproject-1014-104817-4c2-harness-0-disk-1".
Corresponds to the JSON property dataDisk
2968 2969 2970 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2968 def data_disk @data_disk end |
#delivery_endpoint ⇒ String
The physical location of this range assignment to be used for streaming
computation cross-worker message delivery.
Corresponds to the JSON property deliveryEndpoint
2974 2975 2976 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2974 def delivery_endpoint @delivery_endpoint end |
#deprecated_persistent_directory ⇒ String
DEPRECATED. The location of the persistent state for this range, as a
persistent directory in the worker local filesystem.
Corresponds to the JSON property deprecatedPersistentDirectory
2980 2981 2982 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2980 def deprecated_persistent_directory @deprecated_persistent_directory end |
#end ⇒ String
The end (exclusive) of the key range.
Corresponds to the JSON property end
2985 2986 2987 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2985 def end @end end |
#start ⇒ String
The start (inclusive) of the key range.
Corresponds to the JSON property start
2990 2991 2992 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2990 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2997 2998 2999 3000 3001 3002 3003 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 2997 def update!(**args) @data_disk = args[:data_disk] if args.key?(:data_disk) @delivery_endpoint = args[:delivery_endpoint] if args.key?(:delivery_endpoint) @deprecated_persistent_directory = args[:deprecated_persistent_directory] if args.key?(:deprecated_persistent_directory) @end = args[:end] if args.key?(:end) @start = args[:start] if args.key?(:start) end |