Class: Google::Apis::DataflowV1b3::LaunchFlexTemplateParameter
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::LaunchFlexTemplateParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Launch FlexTemplate Parameter.
Instance Attribute Summary collapse
-
#container_spec ⇒ Google::Apis::DataflowV1b3::ContainerSpec
Container Spec.
-
#container_spec_gcs_path ⇒ String
Cloud Storage path to a file with json serialized ContainerSpec as content.
-
#environment ⇒ Google::Apis::DataflowV1b3::FlexTemplateRuntimeEnvironment
The environment values to be set at runtime for flex template.
-
#job_name ⇒ String
Required.
-
#launch_options ⇒ Hash<String,String>
Launch options for this flex template job.
-
#parameters ⇒ Hash<String,String>
The parameters for FlexTemplate.
-
#transform_name_mappings ⇒ Hash<String,String>
Use this to pass transform_name_mappings for streaming update jobs.
-
#update ⇒ Boolean
(also: #update?)
Set this to true if you are sending a request to update a running streaming job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LaunchFlexTemplateParameter
constructor
A new instance of LaunchFlexTemplateParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LaunchFlexTemplateParameter
Returns a new instance of LaunchFlexTemplateParameter.
3117 3118 3119 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_spec ⇒ Google::Apis::DataflowV1b3::ContainerSpec
Container Spec.
Corresponds to the JSON property containerSpec
3075 3076 3077 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3075 def container_spec @container_spec end |
#container_spec_gcs_path ⇒ String
Cloud Storage path to a file with json serialized ContainerSpec as content.
Corresponds to the JSON property containerSpecGcsPath
3080 3081 3082 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3080 def container_spec_gcs_path @container_spec_gcs_path end |
#environment ⇒ Google::Apis::DataflowV1b3::FlexTemplateRuntimeEnvironment
The environment values to be set at runtime for flex template.
Corresponds to the JSON property environment
3085 3086 3087 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3085 def environment @environment end |
#job_name ⇒ String
Required. The job name to use for the created job. For update job request, job
name should be same as the existing running job.
Corresponds to the JSON property jobName
3091 3092 3093 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3091 def job_name @job_name end |
#launch_options ⇒ Hash<String,String>
Launch options for this flex template job. This is a common set of options
across languages and templates. This should not be used to pass job parameters.
Corresponds to the JSON property launchOptions
3097 3098 3099 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3097 def @launch_options end |
#parameters ⇒ Hash<String,String>
The parameters for FlexTemplate. Ex. "num_workers":"5"
Corresponds to the JSON property parameters
3102 3103 3104 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3102 def parameters @parameters end |
#transform_name_mappings ⇒ Hash<String,String>
Use this to pass transform_name_mappings for streaming update jobs. Ex:"
oldTransformName":"newTransformName",...'
Corresponds to the JSON property transformNameMappings
3108 3109 3110 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3108 def transform_name_mappings @transform_name_mappings end |
#update ⇒ Boolean Also known as: update?
Set this to true if you are sending a request to update a running streaming
job. When set, the job name should be the same as the running job.
Corresponds to the JSON property update
3114 3115 3116 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3114 def update @update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3122 def update!(**args) @container_spec = args[:container_spec] if args.key?(:container_spec) @container_spec_gcs_path = args[:container_spec_gcs_path] if args.key?(:container_spec_gcs_path) @environment = args[:environment] if args.key?(:environment) @job_name = args[:job_name] if args.key?(:job_name) @launch_options = args[:launch_options] if args.key?(:launch_options) @parameters = args[:parameters] if args.key?(:parameters) @transform_name_mappings = args[:transform_name_mappings] if args.key?(:transform_name_mappings) @update = args[:update] if args.key?(:update) end |