Class: Google::Apis::DataflowV1b3::LaunchFlexTemplateParameter
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::LaunchFlexTemplateParameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Launch FlexTemplate Parameter.
Instance Attribute Summary collapse
-
#container_spec ⇒ Google::Apis::DataflowV1b3::ContainerSpec
Container Spec.
-
#container_spec_gcs_path ⇒ String
Cloud Storage path to a file with json serialized ContainerSpec as content.
-
#environment ⇒ Google::Apis::DataflowV1b3::FlexTemplateRuntimeEnvironment
The environment values to be set at runtime for flex template.
-
#job_name ⇒ String
Required.
-
#launch_options ⇒ Hash<String,String>
Launch options for this flex template job.
-
#parameters ⇒ Hash<String,String>
The parameters for FlexTemplate.
-
#transform_name_mappings ⇒ Hash<String,String>
Use this to pass transform_name_mappings for streaming update jobs.
-
#update ⇒ Boolean
(also: #update?)
Set this to true if you are sending a request to update a running streaming job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LaunchFlexTemplateParameter
constructor
A new instance of LaunchFlexTemplateParameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LaunchFlexTemplateParameter
Returns a new instance of LaunchFlexTemplateParameter.
3055 3056 3057 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_spec ⇒ Google::Apis::DataflowV1b3::ContainerSpec
Container Spec.
Corresponds to the JSON property containerSpec
3013 3014 3015 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3013 def container_spec @container_spec end |
#container_spec_gcs_path ⇒ String
Cloud Storage path to a file with json serialized ContainerSpec as content.
Corresponds to the JSON property containerSpecGcsPath
3018 3019 3020 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3018 def container_spec_gcs_path @container_spec_gcs_path end |
#environment ⇒ Google::Apis::DataflowV1b3::FlexTemplateRuntimeEnvironment
The environment values to be set at runtime for flex template.
Corresponds to the JSON property environment
3023 3024 3025 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3023 def environment @environment end |
#job_name ⇒ String
Required. The job name to use for the created job. For update job request, job
name should be same as the existing running job.
Corresponds to the JSON property jobName
3029 3030 3031 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3029 def job_name @job_name end |
#launch_options ⇒ Hash<String,String>
Launch options for this flex template job. This is a common set of options
across languages and templates. This should not be used to pass job parameters.
Corresponds to the JSON property launchOptions
3035 3036 3037 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3035 def @launch_options end |
#parameters ⇒ Hash<String,String>
The parameters for FlexTemplate. Ex. "num_workers":"5"
Corresponds to the JSON property parameters
3040 3041 3042 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3040 def parameters @parameters end |
#transform_name_mappings ⇒ Hash<String,String>
Use this to pass transform_name_mappings for streaming update jobs. Ex:"
oldTransformName":"newTransformName",...'
Corresponds to the JSON property transformNameMappings
3046 3047 3048 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3046 def transform_name_mappings @transform_name_mappings end |
#update ⇒ Boolean Also known as: update?
Set this to true if you are sending a request to update a running streaming
job. When set, the job name should be the same as the running job.
Corresponds to the JSON property update
3052 3053 3054 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3052 def update @update end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3060 def update!(**args) @container_spec = args[:container_spec] if args.key?(:container_spec) @container_spec_gcs_path = args[:container_spec_gcs_path] if args.key?(:container_spec_gcs_path) @environment = args[:environment] if args.key?(:environment) @job_name = args[:job_name] if args.key?(:job_name) @launch_options = args[:launch_options] if args.key?(:launch_options) @parameters = args[:parameters] if args.key?(:parameters) @transform_name_mappings = args[:transform_name_mappings] if args.key?(:transform_name_mappings) @update = args[:update] if args.key?(:update) end |