Class: Google::Apis::DataflowV1b3::LaunchFlexTemplateResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::LaunchFlexTemplateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Response to the request to launch a job from Flex Template.
Instance Attribute Summary collapse
-
#job ⇒ Google::Apis::DataflowV1b3::Job
Defines a job to be run by the Cloud Dataflow service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LaunchFlexTemplateResponse
constructor
A new instance of LaunchFlexTemplateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LaunchFlexTemplateResponse
Returns a new instance of LaunchFlexTemplateResponse.
3170 3171 3172 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job ⇒ Google::Apis::DataflowV1b3::Job
Defines a job to be run by the Cloud Dataflow service. Do not enter
confidential information when you supply string values using the API.
Corresponds to the JSON property job
3168 3169 3170 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3168 def job @job end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3175 3176 3177 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3175 def update!(**args) @job = args[:job] if args.key?(:job) end |