Class: Google::Apis::DataflowV1b3::LaunchFlexTemplateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Response to the request to launch a job from Flex Template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LaunchFlexTemplateResponse

Returns a new instance of LaunchFlexTemplateResponse.



3108
3109
3110
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3108

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jobGoogle::Apis::DataflowV1b3::Job

Defines a job to be run by the Cloud Dataflow service. Do not enter confidential information when you supply string values using the API. Corresponds to the JSON property job



3106
3107
3108
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3106

def job
  @job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3113
3114
3115
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3113

def update!(**args)
  @job = args[:job] if args.key?(:job)
end