Class: Google::Apis::DataflowV1b3::ListJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ListJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Response to a request to list Cloud Dataflow jobs in a project. This might be a partial response, depending on the page size in the ListJobsRequest. However, if the project does not have any jobs, an instance of ListJobsResponse is not returned and the requests's response body is empty ``.
Instance Attribute Summary collapse
-
#failed_location ⇒ Array<Google::Apis::DataflowV1b3::FailedLocation>
Zero or more messages describing the regional endpoints that failed to respond.
-
#jobs ⇒ Array<Google::Apis::DataflowV1b3::Job>
A subset of the requested job information.
-
#next_page_token ⇒ String
Set if there may be more results than fit in this response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListJobsResponse
constructor
A new instance of ListJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListJobsResponse
Returns a new instance of ListJobsResponse.
3362 3363 3364 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_location ⇒ Array<Google::Apis::DataflowV1b3::FailedLocation>
Zero or more messages describing the regional endpoints that failed to respond.
Corresponds to the JSON property failedLocation
3350 3351 3352 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3350 def failed_location @failed_location end |
#jobs ⇒ Array<Google::Apis::DataflowV1b3::Job>
A subset of the requested job information.
Corresponds to the JSON property jobs
3355 3356 3357 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3355 def jobs @jobs end |
#next_page_token ⇒ String
Set if there may be more results than fit in this response.
Corresponds to the JSON property nextPageToken
3360 3361 3362 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3360 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3367 3368 3369 3370 3371 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3367 def update!(**args) @failed_location = args[:failed_location] if args.key?(:failed_location) @jobs = args[:jobs] if args.key?(:jobs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |