Class: Google::Apis::DataflowV1b3::MapTask
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::MapTask
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
MapTask consists of an ordered set of instructions, each of which describes one particular low-level operation for the worker to perform in order to accomplish the MapTask's WorkItem. Each instruction must appear in the list before any instructions which depends on its output.
Instance Attribute Summary collapse
-
#counter_prefix ⇒ String
Counter prefix that can be used to prefix counters.
-
#instructions ⇒ Array<Google::Apis::DataflowV1b3::ParallelInstruction>
The instructions in the MapTask.
-
#stage_name ⇒ String
System-defined name of the stage containing this MapTask.
-
#system_name ⇒ String
System-defined name of this MapTask.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MapTask
constructor
A new instance of MapTask.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MapTask
Returns a new instance of MapTask.
3422 3423 3424 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3422 def initialize(**args) update!(**args) end |
Instance Attribute Details
#counter_prefix ⇒ String
Counter prefix that can be used to prefix counters. Not currently used in
Dataflow.
Corresponds to the JSON property counterPrefix
3404 3405 3406 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3404 def counter_prefix @counter_prefix end |
#instructions ⇒ Array<Google::Apis::DataflowV1b3::ParallelInstruction>
The instructions in the MapTask.
Corresponds to the JSON property instructions
3409 3410 3411 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3409 def instructions @instructions end |
#stage_name ⇒ String
System-defined name of the stage containing this MapTask. Unique across the
workflow.
Corresponds to the JSON property stageName
3415 3416 3417 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3415 def stage_name @stage_name end |
#system_name ⇒ String
System-defined name of this MapTask. Unique across the workflow.
Corresponds to the JSON property systemName
3420 3421 3422 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3420 def system_name @system_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3427 3428 3429 3430 3431 3432 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3427 def update!(**args) @counter_prefix = args[:counter_prefix] if args.key?(:counter_prefix) @instructions = args[:instructions] if args.key?(:instructions) @stage_name = args[:stage_name] if args.key?(:stage_name) @system_name = args[:system_name] if args.key?(:system_name) end |