Class: Google::Apis::DataflowV1b3::MetricUpdate
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::MetricUpdate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Describes the state of a metric.
Instance Attribute Summary collapse
-
#bounded_trie ⇒ Object
Worker-computed aggregate value for the "Trie" aggregation kind.
-
#cumulative ⇒ Boolean
(also: #cumulative?)
True if this metric is reported as the total cumulative aggregate value accumulated since the worker started working on this WorkItem.
-
#distribution ⇒ Object
A struct value describing properties of a distribution of numeric values.
-
#gauge ⇒ Object
A struct value describing properties of a Gauge.
-
#internal ⇒ Object
Worker-computed aggregate value for internal use by the Dataflow service.
-
#kind ⇒ String
Metric aggregation kind.
-
#mean_count ⇒ Object
Worker-computed aggregate value for the "Mean" aggregation kind.
-
#mean_sum ⇒ Object
Worker-computed aggregate value for the "Mean" aggregation kind.
-
#name ⇒ Google::Apis::DataflowV1b3::MetricStructuredName
Identifies a metric, by describing the source which generated the metric.
-
#scalar ⇒ Object
Worker-computed aggregate value for aggregation kinds "Sum", "Max", "Min", " And", and "Or".
-
#set ⇒ Object
Worker-computed aggregate value for the "Set" aggregation kind.
-
#trie ⇒ Object
Worker-computed aggregate value for the "Trie" aggregation kind.
-
#update_time ⇒ String
Timestamp associated with the metric value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricUpdate
constructor
A new instance of MetricUpdate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricUpdate
Returns a new instance of MetricUpdate.
3632 3633 3634 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3632 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bounded_trie ⇒ Object
Worker-computed aggregate value for the "Trie" aggregation kind. The only
possible value type is a BoundedTrieNode. Introduced this field to avoid
breaking older SDKs when Dataflow service starts to populate the bounded_trie
field.
Corresponds to the JSON property boundedTrie
3550 3551 3552 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3550 def bounded_trie @bounded_trie end |
#cumulative ⇒ Boolean Also known as: cumulative?
True if this metric is reported as the total cumulative aggregate value
accumulated since the worker started working on this WorkItem. By default this
is false, indicating that this metric is reported as a delta that is not
associated with any WorkItem.
Corresponds to the JSON property cumulative
3558 3559 3560 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3558 def cumulative @cumulative end |
#distribution ⇒ Object
A struct value describing properties of a distribution of numeric values.
Corresponds to the JSON property distribution
3564 3565 3566 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3564 def distribution @distribution end |
#gauge ⇒ Object
A struct value describing properties of a Gauge. Metrics of gauge type show
the value of a metric across time, and is aggregated based on the newest value.
Corresponds to the JSON property gauge
3570 3571 3572 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3570 def gauge @gauge end |
#internal ⇒ Object
Worker-computed aggregate value for internal use by the Dataflow service.
Corresponds to the JSON property internal
3575 3576 3577 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3575 def internal @internal end |
#kind ⇒ String
Metric aggregation kind. The possible metric aggregation kinds are "Sum", "Max"
, "Min", "Mean", "Set", "And", "Or", and "Distribution". The specified
aggregation kind is case-insensitive. If omitted, this is not an aggregated
value but instead a single metric sample value.
Corresponds to the JSON property kind
3583 3584 3585 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3583 def kind @kind end |
#mean_count ⇒ Object
Worker-computed aggregate value for the "Mean" aggregation kind. This holds
the count of the aggregated values and is used in combination with mean_sum
above to obtain the actual mean aggregate value. The only possible value type
is Long.
Corresponds to the JSON property meanCount
3591 3592 3593 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3591 def mean_count @mean_count end |
#mean_sum ⇒ Object
Worker-computed aggregate value for the "Mean" aggregation kind. This holds
the sum of the aggregated values and is used in combination with mean_count
below to obtain the actual mean aggregate value. The only possible value types
are Long and Double.
Corresponds to the JSON property meanSum
3599 3600 3601 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3599 def mean_sum @mean_sum end |
#name ⇒ Google::Apis::DataflowV1b3::MetricStructuredName
Identifies a metric, by describing the source which generated the metric.
Corresponds to the JSON property name
3604 3605 3606 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3604 def name @name end |
#scalar ⇒ Object
Worker-computed aggregate value for aggregation kinds "Sum", "Max", "Min", "
And", and "Or". The possible value types are Long, Double, and Boolean.
Corresponds to the JSON property scalar
3610 3611 3612 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3610 def scalar @scalar end |
#set ⇒ Object
Worker-computed aggregate value for the "Set" aggregation kind. The only
possible value type is a list of Values whose type can be Long, Double, String,
or BoundedTrie according to the metric's type. All Values in the list must be
of the same type.
Corresponds to the JSON property set
3618 3619 3620 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3618 def set @set end |
#trie ⇒ Object
Worker-computed aggregate value for the "Trie" aggregation kind. The only
possible value type is a BoundedTrieNode.
Corresponds to the JSON property trie
3624 3625 3626 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3624 def trie @trie end |
#update_time ⇒ String
Timestamp associated with the metric value. Optional when workers are
reporting work progress; it will be filled in responses from the metrics API.
Corresponds to the JSON property updateTime
3630 3631 3632 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3630 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3637 def update!(**args) @bounded_trie = args[:bounded_trie] if args.key?(:bounded_trie) @cumulative = args[:cumulative] if args.key?(:cumulative) @distribution = args[:distribution] if args.key?(:distribution) @gauge = args[:gauge] if args.key?(:gauge) @internal = args[:internal] if args.key?(:internal) @kind = args[:kind] if args.key?(:kind) @mean_count = args[:mean_count] if args.key?(:mean_count) @mean_sum = args[:mean_sum] if args.key?(:mean_sum) @name = args[:name] if args.key?(:name) @scalar = args[:scalar] if args.key?(:scalar) @set = args[:set] if args.key?(:set) @trie = args[:trie] if args.key?(:trie) @update_time = args[:update_time] if args.key?(:update_time) end |