Class: Google::Apis::DataflowV1b3::MetricValue
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::MetricValue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
The value of a metric along with its name and labels.
Instance Attribute Summary collapse
-
#metric ⇒ String
Base name for this metric.
-
#metric_labels ⇒ Hash<String,String>
Optional.
-
#value_gauge64 ⇒ Google::Apis::DataflowV1b3::DataflowGaugeValue
The gauge value of a metric.
-
#value_histogram ⇒ Google::Apis::DataflowV1b3::DataflowHistogramValue
Summary statistics for a population of values.
-
#value_int64 ⇒ Fixnum
Integer value of this metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricValue
constructor
A new instance of MetricValue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricValue
Returns a new instance of MetricValue.
3748 3749 3750 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metric ⇒ String
Base name for this metric.
Corresponds to the JSON property metric
3723 3724 3725 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3723 def metric @metric end |
#metric_labels ⇒ Hash<String,String>
Optional. Set of metric labels for this metric.
Corresponds to the JSON property metricLabels
3728 3729 3730 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3728 def metric_labels @metric_labels end |
#value_gauge64 ⇒ Google::Apis::DataflowV1b3::DataflowGaugeValue
The gauge value of a metric.
Corresponds to the JSON property valueGauge64
3733 3734 3735 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3733 def value_gauge64 @value_gauge64 end |
#value_histogram ⇒ Google::Apis::DataflowV1b3::DataflowHistogramValue
Summary statistics for a population of values. HistogramValue contains a
sequence of buckets and gives a count of values that fall into each bucket.
Bucket boundares are defined by a formula and bucket widths are either fixed
or exponentially increasing.
Corresponds to the JSON property valueHistogram
3741 3742 3743 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3741 def value_histogram @value_histogram end |
#value_int64 ⇒ Fixnum
Integer value of this metric.
Corresponds to the JSON property valueInt64
3746 3747 3748 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3746 def value_int64 @value_int64 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3753 3754 3755 3756 3757 3758 3759 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3753 def update!(**args) @metric = args[:metric] if args.key?(:metric) @metric_labels = args[:metric_labels] if args.key?(:metric_labels) @value_gauge64 = args[:value_gauge64] if args.key?(:value_gauge64) @value_histogram = args[:value_histogram] if args.key?(:value_histogram) @value_int64 = args[:value_int64] if args.key?(:value_int64) end |