Class: Google::Apis::DataflowV1b3::Package
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::Package
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
The packages that must be installed in order for a worker to run the steps of the Cloud Dataflow job that will be assigned to its worker pool. This is the mechanism by which the Cloud Dataflow SDK causes code to be loaded onto the workers. For example, the Cloud Dataflow Java SDK might use this to install jars containing the user's code and all of the various dependencies (libraries, data files, etc.) required in order for that code to run.
Instance Attribute Summary collapse
-
#location ⇒ String
The resource to read the package from.
-
#name ⇒ String
The name of the package.
-
#sha256 ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Package
constructor
A new instance of Package.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Package
Returns a new instance of Package.
3830 3831 3832 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
The resource to read the package from. The supported resource type is: Google
Cloud Storage: storage.googleapis.com/bucket bucket.storage.googleapis.com/
Corresponds to the JSON property location
3816 3817 3818 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3816 def location @location end |
#name ⇒ String
The name of the package.
Corresponds to the JSON property name
3821 3822 3823 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3821 def name @name end |
#sha256 ⇒ String
Optional. The hex-encoded SHA256 checksum of the package. If the checksum is
provided, the worker will verify the checksum of the package before using it.
If the checksum does not match, the worker will fail to start.
Corresponds to the JSON property sha256
3828 3829 3830 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3828 def sha256 @sha256 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3835 3836 3837 3838 3839 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3835 def update!(**args) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @sha256 = args[:sha256] if args.key?(:sha256) end |