Class: Google::Apis::DataflowV1b3::ParallelInstruction
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ParallelInstruction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Describes a particular operation comprising a MapTask.
Instance Attribute Summary collapse
-
#flatten ⇒ Google::Apis::DataflowV1b3::FlattenInstruction
An instruction that copies its inputs (zero or more) to its (single) output.
-
#name ⇒ String
User-provided name of this operation.
-
#original_name ⇒ String
System-defined name for the operation in the original workflow graph.
-
#outputs ⇒ Array<Google::Apis::DataflowV1b3::InstructionOutput>
Describes the outputs of the instruction.
-
#par_do ⇒ Google::Apis::DataflowV1b3::ParDoInstruction
An instruction that does a ParDo operation.
-
#partial_group_by_key ⇒ Google::Apis::DataflowV1b3::PartialGroupByKeyInstruction
An instruction that does a partial group-by-key.
-
#read ⇒ Google::Apis::DataflowV1b3::ReadInstruction
An instruction that reads records.
-
#system_name ⇒ String
System-defined name of this operation.
-
#write ⇒ Google::Apis::DataflowV1b3::WriteInstruction
An instruction that writes records.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ParallelInstruction
constructor
A new instance of ParallelInstruction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ParallelInstruction
Returns a new instance of ParallelInstruction.
3937 3938 3939 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#flatten ⇒ Google::Apis::DataflowV1b3::FlattenInstruction
An instruction that copies its inputs (zero or more) to its (single) output.
Corresponds to the JSON property flatten
3894 3895 3896 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3894 def flatten @flatten end |
#name ⇒ String
User-provided name of this operation.
Corresponds to the JSON property name
3899 3900 3901 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3899 def name @name end |
#original_name ⇒ String
System-defined name for the operation in the original workflow graph.
Corresponds to the JSON property originalName
3904 3905 3906 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3904 def original_name @original_name end |
#outputs ⇒ Array<Google::Apis::DataflowV1b3::InstructionOutput>
Describes the outputs of the instruction.
Corresponds to the JSON property outputs
3909 3910 3911 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3909 def outputs @outputs end |
#par_do ⇒ Google::Apis::DataflowV1b3::ParDoInstruction
An instruction that does a ParDo operation. Takes one main input and zero or
more side inputs, and produces zero or more outputs. Runs user code.
Corresponds to the JSON property parDo
3915 3916 3917 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3915 def par_do @par_do end |
#partial_group_by_key ⇒ Google::Apis::DataflowV1b3::PartialGroupByKeyInstruction
An instruction that does a partial group-by-key. One input and one output.
Corresponds to the JSON property partialGroupByKey
3920 3921 3922 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3920 def partial_group_by_key @partial_group_by_key end |
#read ⇒ Google::Apis::DataflowV1b3::ReadInstruction
An instruction that reads records. Takes no inputs, produces one output.
Corresponds to the JSON property read
3925 3926 3927 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3925 def read @read end |
#system_name ⇒ String
System-defined name of this operation. Unique across the workflow.
Corresponds to the JSON property systemName
3930 3931 3932 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3930 def system_name @system_name end |
#write ⇒ Google::Apis::DataflowV1b3::WriteInstruction
An instruction that writes records. Takes one input, produces no outputs.
Corresponds to the JSON property write
3935 3936 3937 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3935 def write @write end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3942 3943 3944 3945 3946 3947 3948 3949 3950 3951 3952 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 3942 def update!(**args) @flatten = args[:flatten] if args.key?(:flatten) @name = args[:name] if args.key?(:name) @original_name = args[:original_name] if args.key?(:original_name) @outputs = args[:outputs] if args.key?(:outputs) @par_do = args[:par_do] if args.key?(:par_do) @partial_group_by_key = args[:partial_group_by_key] if args.key?(:partial_group_by_key) @read = args[:read] if args.key?(:read) @system_name = args[:system_name] if args.key?(:system_name) @write = args[:write] if args.key?(:write) end |