Class: Google::Apis::DataflowV1b3::PipelineDescription
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::PipelineDescription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
A descriptive representation of submitted pipeline as well as the executed form. This data is provided by the Dataflow service for ease of visualizing the pipeline and interpreting Dataflow provided metrics.
Instance Attribute Summary collapse
-
#display_data ⇒ Array<Google::Apis::DataflowV1b3::DisplayData>
Pipeline level display data.
-
#execution_pipeline_stage ⇒ Array<Google::Apis::DataflowV1b3::ExecutionStageSummary>
Description of each stage of execution of the pipeline.
-
#original_pipeline_transform ⇒ Array<Google::Apis::DataflowV1b3::TransformSummary>
Description of each transform in the pipeline and collections between them.
-
#step_names_hash ⇒ String
A hash value of the submitted pipeline portable graph step names if exists.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PipelineDescription
constructor
A new instance of PipelineDescription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PipelineDescription
Returns a new instance of PipelineDescription.
4343 4344 4345 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_data ⇒ Array<Google::Apis::DataflowV1b3::DisplayData>
Pipeline level display data.
Corresponds to the JSON property displayData
4326 4327 4328 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4326 def display_data @display_data end |
#execution_pipeline_stage ⇒ Array<Google::Apis::DataflowV1b3::ExecutionStageSummary>
Description of each stage of execution of the pipeline.
Corresponds to the JSON property executionPipelineStage
4331 4332 4333 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4331 def execution_pipeline_stage @execution_pipeline_stage end |
#original_pipeline_transform ⇒ Array<Google::Apis::DataflowV1b3::TransformSummary>
Description of each transform in the pipeline and collections between them.
Corresponds to the JSON property originalPipelineTransform
4336 4337 4338 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4336 def original_pipeline_transform @original_pipeline_transform end |
#step_names_hash ⇒ String
A hash value of the submitted pipeline portable graph step names if exists.
Corresponds to the JSON property stepNamesHash
4341 4342 4343 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4341 def step_names_hash @step_names_hash end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4348 4349 4350 4351 4352 4353 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4348 def update!(**args) @display_data = args[:display_data] if args.key?(:display_data) @execution_pipeline_stage = args[:execution_pipeline_stage] if args.key?(:execution_pipeline_stage) @original_pipeline_transform = args[:original_pipeline_transform] if args.key?(:original_pipeline_transform) @step_names_hash = args[:step_names_hash] if args.key?(:step_names_hash) end |