Class: Google::Apis::DataflowV1b3::PipelineDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

A descriptive representation of submitted pipeline as well as the executed form. This data is provided by the Dataflow service for ease of visualizing the pipeline and interpreting Dataflow provided metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PipelineDescription

Returns a new instance of PipelineDescription.



4236
4237
4238
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4236

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_dataArray<Google::Apis::DataflowV1b3::DisplayData>

Pipeline level display data. Corresponds to the JSON property displayData



4219
4220
4221
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4219

def display_data
  @display_data
end

#execution_pipeline_stageArray<Google::Apis::DataflowV1b3::ExecutionStageSummary>

Description of each stage of execution of the pipeline. Corresponds to the JSON property executionPipelineStage



4224
4225
4226
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4224

def execution_pipeline_stage
  @execution_pipeline_stage
end

#original_pipeline_transformArray<Google::Apis::DataflowV1b3::TransformSummary>

Description of each transform in the pipeline and collections between them. Corresponds to the JSON property originalPipelineTransform



4229
4230
4231
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4229

def original_pipeline_transform
  @original_pipeline_transform
end

#step_names_hashString

A hash value of the submitted pipeline portable graph step names if exists. Corresponds to the JSON property stepNamesHash

Returns:

  • (String)


4234
4235
4236
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4234

def step_names_hash
  @step_names_hash
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4241
4242
4243
4244
4245
4246
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4241

def update!(**args)
  @display_data = args[:display_data] if args.key?(:display_data)
  @execution_pipeline_stage = args[:execution_pipeline_stage] if args.key?(:execution_pipeline_stage)
  @original_pipeline_transform = args[:original_pipeline_transform] if args.key?(:original_pipeline_transform)
  @step_names_hash = args[:step_names_hash] if args.key?(:step_names_hash)
end