Class: Google::Apis::DataflowV1b3::ReportWorkItemStatusRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ReportWorkItemStatusRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Request to report the status of WorkItems.
Instance Attribute Summary collapse
-
#current_worker_time ⇒ String
The current timestamp at the worker.
-
#location ⇒ String
The regional endpoint that contains the WorkItem's job.
-
#project_number ⇒ Fixnum
Optional.
-
#unified_worker_request ⇒ Hash<String,Object>
Untranslated bag-of-bytes WorkProgressUpdateRequest from UnifiedWorker.
-
#work_item_statuses ⇒ Array<Google::Apis::DataflowV1b3::WorkItemStatus>
The order is unimportant, except that the order of the WorkItemServiceState messages in the ReportWorkItemStatusResponse corresponds to the order of WorkItemStatus messages here.
-
#worker_id ⇒ String
The ID of the worker reporting the WorkItem status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportWorkItemStatusRequest
constructor
A new instance of ReportWorkItemStatusRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportWorkItemStatusRequest
Returns a new instance of ReportWorkItemStatusRequest.
4643 4644 4645 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4643 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_worker_time ⇒ String
The current timestamp at the worker.
Corresponds to the JSON property currentWorkerTime
4611 4612 4613 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4611 def current_worker_time @current_worker_time end |
#location ⇒ String
The regional endpoint that contains the WorkItem's job.
Corresponds to the JSON property location
4617 4618 4619 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4617 def location @location end |
#project_number ⇒ Fixnum
Optional. The project number of the project which owns the WorkItem's job.
Corresponds to the JSON property projectNumber
4622 4623 4624 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4622 def project_number @project_number end |
#unified_worker_request ⇒ Hash<String,Object>
Untranslated bag-of-bytes WorkProgressUpdateRequest from UnifiedWorker.
Corresponds to the JSON property unifiedWorkerRequest
4627 4628 4629 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4627 def unified_worker_request @unified_worker_request end |
#work_item_statuses ⇒ Array<Google::Apis::DataflowV1b3::WorkItemStatus>
The order is unimportant, except that the order of the WorkItemServiceState
messages in the ReportWorkItemStatusResponse corresponds to the order of
WorkItemStatus messages here.
Corresponds to the JSON property workItemStatuses
4634 4635 4636 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4634 def work_item_statuses @work_item_statuses end |
#worker_id ⇒ String
The ID of the worker reporting the WorkItem status. If this does not match the
ID of the worker which the Dataflow service believes currently has the lease
on the WorkItem, the report will be dropped (with an error response).
Corresponds to the JSON property workerId
4641 4642 4643 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4641 def worker_id @worker_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4648 4649 4650 4651 4652 4653 4654 4655 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4648 def update!(**args) @current_worker_time = args[:current_worker_time] if args.key?(:current_worker_time) @location = args[:location] if args.key?(:location) @project_number = args[:project_number] if args.key?(:project_number) @unified_worker_request = args[:unified_worker_request] if args.key?(:unified_worker_request) @work_item_statuses = args[:work_item_statuses] if args.key?(:work_item_statuses) @worker_id = args[:worker_id] if args.key?(:worker_id) end |