Class: Google::Apis::DataflowV1b3::ReportWorkItemStatusRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Request to report the status of WorkItems.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportWorkItemStatusRequest

Returns a new instance of ReportWorkItemStatusRequest.



4536
4537
4538
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_worker_timeString

The current timestamp at the worker. Corresponds to the JSON property currentWorkerTime

Returns:

  • (String)


4504
4505
4506
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4504

def current_worker_time
  @current_worker_time
end

#locationString

The regional endpoint that contains the WorkItem's job. Corresponds to the JSON property location

Returns:

  • (String)


4510
4511
4512
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4510

def location
  @location
end

#project_numberFixnum

Optional. The project number of the project which owns the WorkItem's job. Corresponds to the JSON property projectNumber

Returns:

  • (Fixnum)


4515
4516
4517
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4515

def project_number
  @project_number
end

#unified_worker_requestHash<String,Object>

Untranslated bag-of-bytes WorkProgressUpdateRequest from UnifiedWorker. Corresponds to the JSON property unifiedWorkerRequest

Returns:

  • (Hash<String,Object>)


4520
4521
4522
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4520

def unified_worker_request
  @unified_worker_request
end

#work_item_statusesArray<Google::Apis::DataflowV1b3::WorkItemStatus>

The order is unimportant, except that the order of the WorkItemServiceState messages in the ReportWorkItemStatusResponse corresponds to the order of WorkItemStatus messages here. Corresponds to the JSON property workItemStatuses



4527
4528
4529
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4527

def work_item_statuses
  @work_item_statuses
end

#worker_idString

The ID of the worker reporting the WorkItem status. If this does not match the ID of the worker which the Dataflow service believes currently has the lease on the WorkItem, the report will be dropped (with an error response). Corresponds to the JSON property workerId

Returns:

  • (String)


4534
4535
4536
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4534

def worker_id
  @worker_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4541
4542
4543
4544
4545
4546
4547
4548
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4541

def update!(**args)
  @current_worker_time = args[:current_worker_time] if args.key?(:current_worker_time)
  @location = args[:location] if args.key?(:location)
  @project_number = args[:project_number] if args.key?(:project_number)
  @unified_worker_request = args[:unified_worker_request] if args.key?(:unified_worker_request)
  @work_item_statuses = args[:work_item_statuses] if args.key?(:work_item_statuses)
  @worker_id = args[:worker_id] if args.key?(:worker_id)
end