Class: Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::ReportWorkItemStatusResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Response from a request to report the status of WorkItems.
Instance Attribute Summary collapse
-
#unified_worker_response ⇒ Hash<String,Object>
Untranslated bag-of-bytes WorkProgressUpdateResponse for UnifiedWorker.
-
#work_item_service_states ⇒ Array<Google::Apis::DataflowV1b3::WorkItemServiceState>
A set of messages indicating the service-side state for each WorkItem whose status was reported, in the same order as the WorkItemStatus messages in the ReportWorkItemStatusRequest which resulting in this response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportWorkItemStatusResponse
constructor
A new instance of ReportWorkItemStatusResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportWorkItemStatusResponse
Returns a new instance of ReportWorkItemStatusResponse.
4575 4576 4577 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4575 def initialize(**args) update!(**args) end |
Instance Attribute Details
#unified_worker_response ⇒ Hash<String,Object>
Untranslated bag-of-bytes WorkProgressUpdateResponse for UnifiedWorker.
Corresponds to the JSON property unifiedWorkerResponse
4566 4567 4568 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4566 def unified_worker_response @unified_worker_response end |
#work_item_service_states ⇒ Array<Google::Apis::DataflowV1b3::WorkItemServiceState>
A set of messages indicating the service-side state for each WorkItem whose
status was reported, in the same order as the WorkItemStatus messages in the
ReportWorkItemStatusRequest which resulting in this response.
Corresponds to the JSON property workItemServiceStates
4573 4574 4575 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4573 def work_item_service_states @work_item_service_states end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4580 4581 4582 4583 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4580 def update!(**args) @unified_worker_response = args[:unified_worker_response] if args.key?(:unified_worker_response) @work_item_service_states = args[:work_item_service_states] if args.key?(:work_item_service_states) end |