Class: Google::Apis::DataflowV1b3::RuntimeUpdatableParams
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::RuntimeUpdatableParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Additional job parameters that can only be updated during runtime using the projects.jobs.update method. These fields have no effect when specified during job creation.
Instance Attribute Summary collapse
-
#acceptable_backlog_duration ⇒ String
Optional.
-
#autoscaling_tier ⇒ String
Optional.
-
#latency_tier ⇒ String
Optional.
-
#max_num_workers ⇒ Fixnum
The maximum number of workers to cap autoscaling at.
-
#min_num_workers ⇒ Fixnum
The minimum number of workers to scale down to.
-
#schedules ⇒ Array<Google::Apis::DataflowV1b3::AutoscalingSchedule>
Optional.
-
#worker_utilization_hint ⇒ Float
Target worker utilization, compared against the aggregate utilization of the worker pool by autoscaler, to determine upscaling and downscaling when absent other constraints such as backlog.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeUpdatableParams
constructor
A new instance of RuntimeUpdatableParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeUpdatableParams
Returns a new instance of RuntimeUpdatableParams.
5007 5008 5009 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acceptable_backlog_duration ⇒ String
Optional. Deprecated: Use latency_tier instead. The backlog threshold
duration in seconds for autoscaling. Value must be non-negative.
Corresponds to the JSON property acceptableBacklogDuration
4966 4967 4968 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4966 def acceptable_backlog_duration @acceptable_backlog_duration end |
#autoscaling_tier ⇒ String
Optional. Deprecated: Use latency_tier instead. The backlog threshold tier
for autoscaling. Value must be one of "low-latency", "medium-latency", or "
high-latency".
Corresponds to the JSON property autoscalingTier
4973 4974 4975 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4973 def autoscaling_tier @autoscaling_tier end |
#latency_tier ⇒ String
Optional. The backlog threshold tier for autoscaling. Value must be one of "
low-latency", "medium-latency", or "high-latency".
Corresponds to the JSON property latencyTier
4979 4980 4981 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4979 def latency_tier @latency_tier end |
#max_num_workers ⇒ Fixnum
The maximum number of workers to cap autoscaling at. This field is currently
only supported for Streaming Engine jobs.
Corresponds to the JSON property maxNumWorkers
4985 4986 4987 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4985 def max_num_workers @max_num_workers end |
#min_num_workers ⇒ Fixnum
The minimum number of workers to scale down to. This field is currently only
supported for Streaming Engine jobs.
Corresponds to the JSON property minNumWorkers
4991 4992 4993 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4991 def min_num_workers @min_num_workers end |
#schedules ⇒ Array<Google::Apis::DataflowV1b3::AutoscalingSchedule>
Optional. The schedule for autoscaling.
Corresponds to the JSON property schedules
4996 4997 4998 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4996 def schedules @schedules end |
#worker_utilization_hint ⇒ Float
Target worker utilization, compared against the aggregate utilization of the
worker pool by autoscaler, to determine upscaling and downscaling when absent
other constraints such as backlog. For more information, see Update an
existing pipeline.
Corresponds to the JSON property workerUtilizationHint
5005 5006 5007 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5005 def worker_utilization_hint @worker_utilization_hint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5012 5013 5014 5015 5016 5017 5018 5019 5020 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5012 def update!(**args) @acceptable_backlog_duration = args[:acceptable_backlog_duration] if args.key?(:acceptable_backlog_duration) @autoscaling_tier = args[:autoscaling_tier] if args.key?(:autoscaling_tier) @latency_tier = args[:latency_tier] if args.key?(:latency_tier) @max_num_workers = args[:max_num_workers] if args.key?(:max_num_workers) @min_num_workers = args[:min_num_workers] if args.key?(:min_num_workers) @schedules = args[:schedules] if args.key?(:schedules) @worker_utilization_hint = args[:worker_utilization_hint] if args.key?(:worker_utilization_hint) end |