Class: Google::Apis::DataflowV1b3::RuntimeUpdatableParams
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::RuntimeUpdatableParams
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Additional job parameters that can only be updated during runtime using the projects.jobs.update method. These fields have no effect when specified during job creation.
Instance Attribute Summary collapse
-
#acceptable_backlog_duration ⇒ String
Optional.
-
#autoscaling_tier ⇒ String
Optional.
-
#latency_tier ⇒ String
Optional.
-
#max_num_workers ⇒ Fixnum
The maximum number of workers to cap autoscaling at.
-
#min_num_workers ⇒ Fixnum
The minimum number of workers to scale down to.
-
#worker_utilization_hint ⇒ Float
Target worker utilization, compared against the aggregate utilization of the worker pool by autoscaler, to determine upscaling and downscaling when absent other constraints such as backlog.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RuntimeUpdatableParams
constructor
A new instance of RuntimeUpdatableParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RuntimeUpdatableParams
Returns a new instance of RuntimeUpdatableParams.
4903 4904 4905 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4903 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acceptable_backlog_duration ⇒ String
Optional. Deprecated: Use latency_tier instead. The backlog threshold
duration in seconds for autoscaling. Value must be non-negative.
Corresponds to the JSON property acceptableBacklogDuration
4867 4868 4869 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4867 def acceptable_backlog_duration @acceptable_backlog_duration end |
#autoscaling_tier ⇒ String
Optional. Deprecated: Use latency_tier instead. The backlog threshold tier
for autoscaling. Value must be one of "low-latency", "medium-latency", or "
high-latency".
Corresponds to the JSON property autoscalingTier
4874 4875 4876 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4874 def autoscaling_tier @autoscaling_tier end |
#latency_tier ⇒ String
Optional. The backlog threshold tier for autoscaling. Value must be one of "
low-latency", "medium-latency", or "high-latency".
Corresponds to the JSON property latencyTier
4880 4881 4882 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4880 def latency_tier @latency_tier end |
#max_num_workers ⇒ Fixnum
The maximum number of workers to cap autoscaling at. This field is currently
only supported for Streaming Engine jobs.
Corresponds to the JSON property maxNumWorkers
4886 4887 4888 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4886 def max_num_workers @max_num_workers end |
#min_num_workers ⇒ Fixnum
The minimum number of workers to scale down to. This field is currently only
supported for Streaming Engine jobs.
Corresponds to the JSON property minNumWorkers
4892 4893 4894 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4892 def min_num_workers @min_num_workers end |
#worker_utilization_hint ⇒ Float
Target worker utilization, compared against the aggregate utilization of the
worker pool by autoscaler, to determine upscaling and downscaling when absent
other constraints such as backlog. For more information, see Update an
existing pipeline.
Corresponds to the JSON property workerUtilizationHint
4901 4902 4903 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4901 def worker_utilization_hint @worker_utilization_hint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4908 4909 4910 4911 4912 4913 4914 4915 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 4908 def update!(**args) @acceptable_backlog_duration = args[:acceptable_backlog_duration] if args.key?(:acceptable_backlog_duration) @autoscaling_tier = args[:autoscaling_tier] if args.key?(:autoscaling_tier) @latency_tier = args[:latency_tier] if args.key?(:latency_tier) @max_num_workers = args[:max_num_workers] if args.key?(:max_num_workers) @min_num_workers = args[:min_num_workers] if args.key?(:min_num_workers) @worker_utilization_hint = args[:worker_utilization_hint] if args.key?(:worker_utilization_hint) end |