Class: Google::Apis::DataflowV1b3::SdkHarnessContainerImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Defines an SDK harness container for executing Dataflow pipelines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SdkHarnessContainerImage

Returns a new instance of SdkHarnessContainerImage.



5023
5024
5025
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capabilitiesArray<String>

The set of capabilities enumerated in the above Environment proto. See also beam_runner_api.proto Corresponds to the JSON property capabilities

Returns:

  • (Array<String>)


5001
5002
5003
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5001

def capabilities
  @capabilities
end

#container_imageString

A docker container image that resides in Google Container Registry. Corresponds to the JSON property containerImage

Returns:

  • (String)


5006
5007
5008
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5006

def container_image
  @container_image
end

#environment_idString

Environment ID for the Beam runner API proto Environment that corresponds to the current SDK Harness. Corresponds to the JSON property environmentId

Returns:

  • (String)


5012
5013
5014
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5012

def environment_id
  @environment_id
end

#use_single_core_per_containerBoolean Also known as: use_single_core_per_container?

If true, recommends the Dataflow service to use only one core per SDK container instance with this image. If false (or unset) recommends using more than one core per SDK container instance with this image for efficiency. Note that Dataflow service may choose to override this property if needed. Corresponds to the JSON property useSingleCorePerContainer

Returns:

  • (Boolean)


5020
5021
5022
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5020

def use_single_core_per_container
  @use_single_core_per_container
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5028
5029
5030
5031
5032
5033
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5028

def update!(**args)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @container_image = args[:container_image] if args.key?(:container_image)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @use_single_core_per_container = args[:use_single_core_per_container] if args.key?(:use_single_core_per_container)
end