Class: Google::Apis::DataflowV1b3::SendDebugCaptureRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::SendDebugCaptureRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Request to send encoded debug information. Next ID: 8
Instance Attribute Summary collapse
-
#component_id ⇒ String
The internal component id for which debug information is sent.
-
#data ⇒ String
The encoded debug information.
-
#data_format ⇒ String
Format for the data field above (id=5).
-
#location ⇒ String
The regional endpoint that contains the job specified by job_id.
-
#worker_id ⇒ String
The worker id, i.e., VM hostname.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SendDebugCaptureRequest
constructor
A new instance of SendDebugCaptureRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SendDebugCaptureRequest
Returns a new instance of SendDebugCaptureRequest.
5103 5104 5105 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#component_id ⇒ String
The internal component id for which debug information is sent.
Corresponds to the JSON property componentId
5080 5081 5082 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5080 def component_id @component_id end |
#data ⇒ String
The encoded debug information.
Corresponds to the JSON property data
5085 5086 5087 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5085 def data @data end |
#data_format ⇒ String
Format for the data field above (id=5).
Corresponds to the JSON property dataFormat
5090 5091 5092 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5090 def data_format @data_format end |
#location ⇒ String
The regional endpoint that contains the job specified by job_id.
Corresponds to the JSON property location
5096 5097 5098 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5096 def location @location end |
#worker_id ⇒ String
The worker id, i.e., VM hostname.
Corresponds to the JSON property workerId
5101 5102 5103 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5101 def worker_id @worker_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5108 5109 5110 5111 5112 5113 5114 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5108 def update!(**args) @component_id = args[:component_id] if args.key?(:component_id) @data = args[:data] if args.key?(:data) @data_format = args[:data_format] if args.key?(:data_format) @location = args[:location] if args.key?(:location) @worker_id = args[:worker_id] if args.key?(:worker_id) end |