Class: Google::Apis::DataflowV1b3::SideInputInfo
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::SideInputInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Information about a side input of a DoFn or an input of a SeqDoFn.
Instance Attribute Summary collapse
-
#kind ⇒ Hash<String,Object>
How to interpret the source element(s) as a side input value.
-
#sources ⇒ Array<Google::Apis::DataflowV1b3::Source>
The source(s) to read element(s) from to get the value of this side input.
-
#tag ⇒ String
The id of the tag the user code will access this side input by; this should correspond to the tag of some MultiOutputInfo.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SideInputInfo
constructor
A new instance of SideInputInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SideInputInfo
Returns a new instance of SideInputInfo.
5317 5318 5319 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ Hash<String,Object>
How to interpret the source element(s) as a side input value.
Corresponds to the JSON property kind
5302 5303 5304 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5302 def kind @kind end |
#sources ⇒ Array<Google::Apis::DataflowV1b3::Source>
The source(s) to read element(s) from to get the value of this side input. If
more than one source, then the elements are taken from the sources, in the
specified order if order matters. At least one source is required.
Corresponds to the JSON property sources
5309 5310 5311 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5309 def sources @sources end |
#tag ⇒ String
The id of the tag the user code will access this side input by; this should
correspond to the tag of some MultiOutputInfo.
Corresponds to the JSON property tag
5315 5316 5317 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5315 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5322 5323 5324 5325 5326 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5322 def update!(**args) @kind = args[:kind] if args.key?(:kind) @sources = args[:sources] if args.key?(:sources) @tag = args[:tag] if args.key?(:tag) end |