Class: Google::Apis::DataflowV1b3::SourceOperationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

A work item that represents the different operations that can be performed on a user-defined Source specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceOperationRequest

Returns a new instance of SourceOperationRequest.



5691
5692
5693
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#get_metadataGoogle::Apis::DataflowV1b3::SourceGetMetadataRequest

A request to compute the SourceMetadata of a Source. Corresponds to the JSON property getMetadata



5652
5653
5654
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5652

def 
  @get_metadata
end

#nameString

User-provided name of the Read instruction for this source. Corresponds to the JSON property name

Returns:

  • (String)


5657
5658
5659
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5657

def name
  @name
end

#original_nameString

System-defined name for the Read instruction for this source in the original workflow graph. Corresponds to the JSON property originalName

Returns:

  • (String)


5663
5664
5665
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5663

def original_name
  @original_name
end

#splitGoogle::Apis::DataflowV1b3::SourceSplitRequest

Represents the operation to split a high-level Source specification into bundles (parts for parallel processing). At a high level, splitting of a source into bundles happens as follows: SourceSplitRequest is applied to the source. If it returns SOURCE_SPLIT_OUTCOME_USE_CURRENT, no further splitting happens and the source is used "as is". Otherwise, splitting is applied recursively to each produced DerivedSource. As an optimization, for any Source, if its does_not_need_splitting is true, the framework assumes that splitting this source would return SOURCE_SPLIT_OUTCOME_USE_CURRENT, and doesn't initiate a SourceSplitRequest. This applies both to the initial source being split and to bundles produced from it. Corresponds to the JSON property split



5677
5678
5679
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5677

def split
  @split
end

#stage_nameString

System-defined name of the stage containing the source operation. Unique across the workflow. Corresponds to the JSON property stageName

Returns:

  • (String)


5683
5684
5685
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5683

def stage_name
  @stage_name
end

#system_nameString

System-defined name of the Read instruction for this source. Unique across the workflow. Corresponds to the JSON property systemName

Returns:

  • (String)


5689
5690
5691
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5689

def system_name
  @system_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5696
5697
5698
5699
5700
5701
5702
5703
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5696

def update!(**args)
  @get_metadata = args[:get_metadata] if args.key?(:get_metadata)
  @name = args[:name] if args.key?(:name)
  @original_name = args[:original_name] if args.key?(:original_name)
  @split = args[:split] if args.key?(:split)
  @stage_name = args[:stage_name] if args.key?(:stage_name)
  @system_name = args[:system_name] if args.key?(:system_name)
end