Class: Google::Apis::DataflowV1b3::SourceSplitResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::SourceSplitResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
The response to a SourceSplitRequest.
Instance Attribute Summary collapse
-
#bundles ⇒ Array<Google::Apis::DataflowV1b3::DerivedSource>
If outcome is SPLITTING_HAPPENED, then this is a list of bundles into which the source was split.
-
#outcome ⇒ String
Indicates whether splitting happened and produced a list of bundles.
-
#shards ⇒ Array<Google::Apis::DataflowV1b3::SourceSplitShard>
DEPRECATED in favor of bundles.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceSplitResponse
constructor
A new instance of SourceSplitResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceSplitResponse
Returns a new instance of SourceSplitResponse.
5932 5933 5934 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5932 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bundles ⇒ Array<Google::Apis::DataflowV1b3::DerivedSource>
If outcome is SPLITTING_HAPPENED, then this is a list of bundles into which
the source was split. Otherwise this field is ignored. This list can be empty,
which means the source represents an empty input.
Corresponds to the JSON property bundles
5916 5917 5918 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5916 def bundles @bundles end |
#outcome ⇒ String
Indicates whether splitting happened and produced a list of bundles. If this
is USE_CURRENT_SOURCE_AS_IS, the current source should be processed "as is"
without splitting. "bundles" is ignored in this case. If this is
SPLITTING_HAPPENED, then "bundles" contains a list of bundles into which the
source was split.
Corresponds to the JSON property outcome
5925 5926 5927 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5925 def outcome @outcome end |
#shards ⇒ Array<Google::Apis::DataflowV1b3::SourceSplitShard>
DEPRECATED in favor of bundles.
Corresponds to the JSON property shards
5930 5931 5932 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5930 def shards @shards end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5937 5938 5939 5940 5941 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5937 def update!(**args) @bundles = args[:bundles] if args.key?(:bundles) @outcome = args[:outcome] if args.key?(:outcome) @shards = args[:shards] if args.key?(:shards) end |