Class: Google::Apis::DataflowV1b3::SourceSplitResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

The response to a SourceSplitRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceSplitResponse

Returns a new instance of SourceSplitResponse.



5827
5828
5829
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundlesArray<Google::Apis::DataflowV1b3::DerivedSource>

If outcome is SPLITTING_HAPPENED, then this is a list of bundles into which the source was split. Otherwise this field is ignored. This list can be empty, which means the source represents an empty input. Corresponds to the JSON property bundles



5811
5812
5813
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5811

def bundles
  @bundles
end

#outcomeString

Indicates whether splitting happened and produced a list of bundles. If this is USE_CURRENT_SOURCE_AS_IS, the current source should be processed "as is" without splitting. "bundles" is ignored in this case. If this is SPLITTING_HAPPENED, then "bundles" contains a list of bundles into which the source was split. Corresponds to the JSON property outcome

Returns:

  • (String)


5820
5821
5822
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5820

def outcome
  @outcome
end

#shardsArray<Google::Apis::DataflowV1b3::SourceSplitShard>

DEPRECATED in favor of bundles. Corresponds to the JSON property shards



5825
5826
5827
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5825

def shards
  @shards
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5832
5833
5834
5835
5836
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5832

def update!(**args)
  @bundles = args[:bundles] if args.key?(:bundles)
  @outcome = args[:outcome] if args.key?(:outcome)
  @shards = args[:shards] if args.key?(:shards)
end