Class: Google::Apis::DataflowV1b3::SourceSplitResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

The response to a SourceSplitRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceSplitResponse

Returns a new instance of SourceSplitResponse.



5819
5820
5821
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5819

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundlesArray<Google::Apis::DataflowV1b3::DerivedSource>

If outcome is SPLITTING_HAPPENED, then this is a list of bundles into which the source was split. Otherwise this field is ignored. This list can be empty, which means the source represents an empty input. Corresponds to the JSON property bundles



5803
5804
5805
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5803

def bundles
  @bundles
end

#outcomeString

Indicates whether splitting happened and produced a list of bundles. If this is USE_CURRENT_SOURCE_AS_IS, the current source should be processed "as is" without splitting. "bundles" is ignored in this case. If this is SPLITTING_HAPPENED, then "bundles" contains a list of bundles into which the source was split. Corresponds to the JSON property outcome

Returns:

  • (String)


5812
5813
5814
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5812

def outcome
  @outcome
end

#shardsArray<Google::Apis::DataflowV1b3::SourceSplitShard>

DEPRECATED in favor of bundles. Corresponds to the JSON property shards



5817
5818
5819
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5817

def shards
  @shards
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5824
5825
5826
5827
5828
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5824

def update!(**args)
  @bundles = args[:bundles] if args.key?(:bundles)
  @outcome = args[:outcome] if args.key?(:outcome)
  @shards = args[:shards] if args.key?(:shards)
end