Class: Google::Apis::DataflowV1b3::Stack
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::Stack
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
A structuredstacktrace for a process running on the worker.
Instance Attribute Summary collapse
-
#stack_content ⇒ String
The raw stack trace.
-
#thread_count ⇒ Fixnum
With java thread dumps we may get collapsed stacks e.g., N threads in stack "".
-
#thread_name ⇒ String
Thread name.
-
#thread_state ⇒ String
The state of the thread.
-
#timestamp ⇒ String
Timestamp at which the stack was captured.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stack
constructor
A new instance of Stack.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stack
Returns a new instance of Stack.
6057 6058 6059 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6057 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stack_content ⇒ String
The raw stack trace.
Corresponds to the JSON property stackContent
6033 6034 6035 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6033 def stack_content @stack_content end |
#thread_count ⇒ Fixnum
With java thread dumps we may get collapsed stacks e.g., N threads in stack "".
Instead of having to copy over the same stack trace N times, this int field
captures this.
Corresponds to the JSON property threadCount
6040 6041 6042 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6040 def thread_count @thread_count end |
#thread_name ⇒ String
Thread name. For example, "CommitThread-0,10,main"
Corresponds to the JSON property threadName
6045 6046 6047 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6045 def thread_name @thread_name end |
#thread_state ⇒ String
The state of the thread. For example, "WAITING".
Corresponds to the JSON property threadState
6050 6051 6052 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6050 def thread_state @thread_state end |
#timestamp ⇒ String
Timestamp at which the stack was captured.
Corresponds to the JSON property timestamp
6055 6056 6057 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6055 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6062 6063 6064 6065 6066 6067 6068 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6062 def update!(**args) @stack_content = args[:stack_content] if args.key?(:stack_content) @thread_count = args[:thread_count] if args.key?(:thread_count) @thread_name = args[:thread_name] if args.key?(:thread_name) @thread_state = args[:thread_state] if args.key?(:thread_state) @timestamp = args[:timestamp] if args.key?(:timestamp) end |