Class: Google::Apis::DataflowV1b3::Stack
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::Stack
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
A structuredstacktrace for a process running on the worker.
Instance Attribute Summary collapse
-
#stack_content ⇒ String
The raw stack trace.
-
#thread_count ⇒ Fixnum
With java thread dumps we may get collapsed stacks e.g., N threads in stack "".
-
#thread_name ⇒ String
Thread name.
-
#thread_state ⇒ String
The state of the thread.
-
#timestamp ⇒ String
Timestamp at which the stack was captured.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stack
constructor
A new instance of Stack.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stack
Returns a new instance of Stack.
5944 5945 5946 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5944 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stack_content ⇒ String
The raw stack trace.
Corresponds to the JSON property stackContent
5920 5921 5922 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5920 def stack_content @stack_content end |
#thread_count ⇒ Fixnum
With java thread dumps we may get collapsed stacks e.g., N threads in stack "".
Instead of having to copy over the same stack trace N times, this int field
captures this.
Corresponds to the JSON property threadCount
5927 5928 5929 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5927 def thread_count @thread_count end |
#thread_name ⇒ String
Thread name. For example, "CommitThread-0,10,main"
Corresponds to the JSON property threadName
5932 5933 5934 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5932 def thread_name @thread_name end |
#thread_state ⇒ String
The state of the thread. For example, "WAITING".
Corresponds to the JSON property threadState
5937 5938 5939 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5937 def thread_state @thread_state end |
#timestamp ⇒ String
Timestamp at which the stack was captured.
Corresponds to the JSON property timestamp
5942 5943 5944 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5942 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5949 5950 5951 5952 5953 5954 5955 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 5949 def update!(**args) @stack_content = args[:stack_content] if args.key?(:stack_content) @thread_count = args[:thread_count] if args.key?(:thread_count) @thread_name = args[:thread_name] if args.key?(:thread_name) @thread_state = args[:thread_state] if args.key?(:thread_state) @timestamp = args[:timestamp] if args.key?(:timestamp) end |