Class: Google::Apis::DataflowV1b3::StageSummary
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::StageSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Information about a particular execution stage of a job.
Instance Attribute Summary collapse
-
#end_time ⇒ String
End time of this stage.
-
#metrics ⇒ Array<Google::Apis::DataflowV1b3::MetricUpdate>
Metrics for this stage.
-
#progress ⇒ Google::Apis::DataflowV1b3::ProgressTimeseries
Information about the progress of some component of job execution.
-
#stage_id ⇒ String
ID of this stage Corresponds to the JSON property
stageId. -
#start_time ⇒ String
Start time of this stage.
-
#state ⇒ String
State of this stage.
-
#straggler_summary ⇒ Google::Apis::DataflowV1b3::StragglerSummary
Summarized straggler identification details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StageSummary
constructor
A new instance of StageSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StageSummary
Returns a new instance of StageSummary.
6175 6176 6177 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
End time of this stage. If the work item is completed, this is the actual end
time of the stage. Otherwise, it is the predicted end time.
Corresponds to the JSON property endTime
6143 6144 6145 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6143 def end_time @end_time end |
#metrics ⇒ Array<Google::Apis::DataflowV1b3::MetricUpdate>
Metrics for this stage.
Corresponds to the JSON property metrics
6148 6149 6150 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6148 def metrics @metrics end |
#progress ⇒ Google::Apis::DataflowV1b3::ProgressTimeseries
Information about the progress of some component of job execution.
Corresponds to the JSON property progress
6153 6154 6155 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6153 def progress @progress end |
#stage_id ⇒ String
ID of this stage
Corresponds to the JSON property stageId
6158 6159 6160 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6158 def stage_id @stage_id end |
#start_time ⇒ String
Start time of this stage.
Corresponds to the JSON property startTime
6163 6164 6165 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6163 def start_time @start_time end |
#state ⇒ String
State of this stage.
Corresponds to the JSON property state
6168 6169 6170 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6168 def state @state end |
#straggler_summary ⇒ Google::Apis::DataflowV1b3::StragglerSummary
Summarized straggler identification details.
Corresponds to the JSON property stragglerSummary
6173 6174 6175 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6173 def straggler_summary @straggler_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6180 6181 6182 6183 6184 6185 6186 6187 6188 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6180 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @metrics = args[:metrics] if args.key?(:metrics) @progress = args[:progress] if args.key?(:progress) @stage_id = args[:stage_id] if args.key?(:stage_id) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @straggler_summary = args[:straggler_summary] if args.key?(:straggler_summary) end |