Class: Google::Apis::DataflowV1b3::StageSummary
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::StageSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Information about a particular execution stage of a job.
Instance Attribute Summary collapse
-
#end_time ⇒ String
End time of this stage.
-
#metrics ⇒ Array<Google::Apis::DataflowV1b3::MetricUpdate>
Metrics for this stage.
-
#progress ⇒ Google::Apis::DataflowV1b3::ProgressTimeseries
Information about the progress of some component of job execution.
-
#stage_id ⇒ String
ID of this stage Corresponds to the JSON property
stageId. -
#start_time ⇒ String
Start time of this stage.
-
#state ⇒ String
State of this stage.
-
#straggler_summary ⇒ Google::Apis::DataflowV1b3::StragglerSummary
Summarized straggler identification details.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StageSummary
constructor
A new instance of StageSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StageSummary
Returns a new instance of StageSummary.
6070 6071 6072 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
End time of this stage. If the work item is completed, this is the actual end
time of the stage. Otherwise, it is the predicted end time.
Corresponds to the JSON property endTime
6038 6039 6040 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6038 def end_time @end_time end |
#metrics ⇒ Array<Google::Apis::DataflowV1b3::MetricUpdate>
Metrics for this stage.
Corresponds to the JSON property metrics
6043 6044 6045 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6043 def metrics @metrics end |
#progress ⇒ Google::Apis::DataflowV1b3::ProgressTimeseries
Information about the progress of some component of job execution.
Corresponds to the JSON property progress
6048 6049 6050 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6048 def progress @progress end |
#stage_id ⇒ String
ID of this stage
Corresponds to the JSON property stageId
6053 6054 6055 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6053 def stage_id @stage_id end |
#start_time ⇒ String
Start time of this stage.
Corresponds to the JSON property startTime
6058 6059 6060 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6058 def start_time @start_time end |
#state ⇒ String
State of this stage.
Corresponds to the JSON property state
6063 6064 6065 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6063 def state @state end |
#straggler_summary ⇒ Google::Apis::DataflowV1b3::StragglerSummary
Summarized straggler identification details.
Corresponds to the JSON property stragglerSummary
6068 6069 6070 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6068 def straggler_summary @straggler_summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6075 6076 6077 6078 6079 6080 6081 6082 6083 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6075 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @metrics = args[:metrics] if args.key?(:metrics) @progress = args[:progress] if args.key?(:progress) @stage_id = args[:stage_id] if args.key?(:stage_id) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @straggler_summary = args[:straggler_summary] if args.key?(:straggler_summary) end |