Class: Google::Apis::DataflowV1b3::StageSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Information about a particular execution stage of a job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StageSummary

Returns a new instance of StageSummary.



6062
6063
6064
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

End time of this stage. If the work item is completed, this is the actual end time of the stage. Otherwise, it is the predicted end time. Corresponds to the JSON property endTime

Returns:

  • (String)


6030
6031
6032
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6030

def end_time
  @end_time
end

#metricsArray<Google::Apis::DataflowV1b3::MetricUpdate>

Metrics for this stage. Corresponds to the JSON property metrics



6035
6036
6037
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6035

def metrics
  @metrics
end

#progressGoogle::Apis::DataflowV1b3::ProgressTimeseries

Information about the progress of some component of job execution. Corresponds to the JSON property progress



6040
6041
6042
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6040

def progress
  @progress
end

#stage_idString

ID of this stage Corresponds to the JSON property stageId

Returns:

  • (String)


6045
6046
6047
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6045

def stage_id
  @stage_id
end

#start_timeString

Start time of this stage. Corresponds to the JSON property startTime

Returns:

  • (String)


6050
6051
6052
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6050

def start_time
  @start_time
end

#stateString

State of this stage. Corresponds to the JSON property state

Returns:

  • (String)


6055
6056
6057
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6055

def state
  @state
end

#straggler_summaryGoogle::Apis::DataflowV1b3::StragglerSummary

Summarized straggler identification details. Corresponds to the JSON property stragglerSummary



6060
6061
6062
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6060

def straggler_summary
  @straggler_summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6067
6068
6069
6070
6071
6072
6073
6074
6075
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6067

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @metrics = args[:metrics] if args.key?(:metrics)
  @progress = args[:progress] if args.key?(:progress)
  @stage_id = args[:stage_id] if args.key?(:stage_id)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @straggler_summary = args[:straggler_summary] if args.key?(:straggler_summary)
end