Class: Google::Apis::DataflowV1b3::StreamingComputationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::StreamingComputationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Configuration information for a single streaming computation.
Instance Attribute Summary collapse
-
#computation_id ⇒ String
Unique identifier for this computation.
-
#instructions ⇒ Array<Google::Apis::DataflowV1b3::ParallelInstruction>
Instructions that comprise the computation.
-
#stage_name ⇒ String
Stage name of this computation.
-
#system_name ⇒ String
System defined name for this computation.
-
#transform_user_name_to_state_family ⇒ Hash<String,String>
Map from user name of stateful transforms in this stage to their state family.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamingComputationConfig
constructor
A new instance of StreamingComputationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamingComputationConfig
Returns a new instance of StreamingComputationConfig.
6386 6387 6388 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6386 def initialize(**args) update!(**args) end |
Instance Attribute Details
#computation_id ⇒ String
Unique identifier for this computation.
Corresponds to the JSON property computationId
6364 6365 6366 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6364 def computation_id @computation_id end |
#instructions ⇒ Array<Google::Apis::DataflowV1b3::ParallelInstruction>
Instructions that comprise the computation.
Corresponds to the JSON property instructions
6369 6370 6371 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6369 def instructions @instructions end |
#stage_name ⇒ String
Stage name of this computation.
Corresponds to the JSON property stageName
6374 6375 6376 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6374 def stage_name @stage_name end |
#system_name ⇒ String
System defined name for this computation.
Corresponds to the JSON property systemName
6379 6380 6381 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6379 def system_name @system_name end |
#transform_user_name_to_state_family ⇒ Hash<String,String>
Map from user name of stateful transforms in this stage to their state family.
Corresponds to the JSON property transformUserNameToStateFamily
6384 6385 6386 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6384 def transform_user_name_to_state_family @transform_user_name_to_state_family end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6391 6392 6393 6394 6395 6396 6397 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6391 def update!(**args) @computation_id = args[:computation_id] if args.key?(:computation_id) @instructions = args[:instructions] if args.key?(:instructions) @stage_name = args[:stage_name] if args.key?(:stage_name) @system_name = args[:system_name] if args.key?(:system_name) @transform_user_name_to_state_family = args[:transform_user_name_to_state_family] if args.key?(:transform_user_name_to_state_family) end |