Class: Google::Apis::DataflowV1b3::StreamingOperationalLimits
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::StreamingOperationalLimits
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Operational limits imposed on streaming jobs by the backend.
Instance Attribute Summary collapse
-
#max_bag_element_bytes ⇒ Fixnum
The maximum size for an element in bag state.
-
#max_global_data_bytes ⇒ Fixnum
The maximum size for an element in global data.
-
#max_key_bytes ⇒ Fixnum
The maximum size allowed for a key.
-
#max_production_output_bytes ⇒ Fixnum
The maximum size for a single output element.
-
#max_sorted_list_element_bytes ⇒ Fixnum
The maximum size for an element in sorted list state.
-
#max_source_state_bytes ⇒ Fixnum
The maximum size for a source state update.
-
#max_tag_bytes ⇒ Fixnum
The maximum size for a state tag.
-
#max_value_bytes ⇒ Fixnum
The maximum size for a value state field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamingOperationalLimits
constructor
A new instance of StreamingOperationalLimits.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamingOperationalLimits
Returns a new instance of StreamingOperationalLimits.
6595 6596 6597 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_bag_element_bytes ⇒ Fixnum
The maximum size for an element in bag state.
Corresponds to the JSON property maxBagElementBytes
6558 6559 6560 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6558 def max_bag_element_bytes @max_bag_element_bytes end |
#max_global_data_bytes ⇒ Fixnum
The maximum size for an element in global data.
Corresponds to the JSON property maxGlobalDataBytes
6563 6564 6565 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6563 def max_global_data_bytes @max_global_data_bytes end |
#max_key_bytes ⇒ Fixnum
The maximum size allowed for a key.
Corresponds to the JSON property maxKeyBytes
6568 6569 6570 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6568 def max_key_bytes @max_key_bytes end |
#max_production_output_bytes ⇒ Fixnum
The maximum size for a single output element.
Corresponds to the JSON property maxProductionOutputBytes
6573 6574 6575 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6573 def max_production_output_bytes @max_production_output_bytes end |
#max_sorted_list_element_bytes ⇒ Fixnum
The maximum size for an element in sorted list state.
Corresponds to the JSON property maxSortedListElementBytes
6578 6579 6580 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6578 def max_sorted_list_element_bytes @max_sorted_list_element_bytes end |
#max_source_state_bytes ⇒ Fixnum
The maximum size for a source state update.
Corresponds to the JSON property maxSourceStateBytes
6583 6584 6585 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6583 def max_source_state_bytes @max_source_state_bytes end |
#max_tag_bytes ⇒ Fixnum
The maximum size for a state tag.
Corresponds to the JSON property maxTagBytes
6588 6589 6590 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6588 def max_tag_bytes @max_tag_bytes end |
#max_value_bytes ⇒ Fixnum
The maximum size for a value state field.
Corresponds to the JSON property maxValueBytes
6593 6594 6595 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6593 def max_value_bytes @max_value_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6600 6601 6602 6603 6604 6605 6606 6607 6608 6609 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6600 def update!(**args) @max_bag_element_bytes = args[:max_bag_element_bytes] if args.key?(:max_bag_element_bytes) @max_global_data_bytes = args[:max_global_data_bytes] if args.key?(:max_global_data_bytes) @max_key_bytes = args[:max_key_bytes] if args.key?(:max_key_bytes) @max_production_output_bytes = args[:max_production_output_bytes] if args.key?(:max_production_output_bytes) @max_sorted_list_element_bytes = args[:max_sorted_list_element_bytes] if args.key?(:max_sorted_list_element_bytes) @max_source_state_bytes = args[:max_source_state_bytes] if args.key?(:max_source_state_bytes) @max_tag_bytes = args[:max_tag_bytes] if args.key?(:max_tag_bytes) @max_value_bytes = args[:max_value_bytes] if args.key?(:max_value_bytes) end |