Class: Google::Apis::DataflowV1b3::StreamingOperationalLimits

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Operational limits imposed on streaming jobs by the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamingOperationalLimits

Returns a new instance of StreamingOperationalLimits.



6587
6588
6589
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_bag_element_bytesFixnum

The maximum size for an element in bag state. Corresponds to the JSON property maxBagElementBytes

Returns:

  • (Fixnum)


6550
6551
6552
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6550

def max_bag_element_bytes
  @max_bag_element_bytes
end

#max_global_data_bytesFixnum

The maximum size for an element in global data. Corresponds to the JSON property maxGlobalDataBytes

Returns:

  • (Fixnum)


6555
6556
6557
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6555

def max_global_data_bytes
  @max_global_data_bytes
end

#max_key_bytesFixnum

The maximum size allowed for a key. Corresponds to the JSON property maxKeyBytes

Returns:

  • (Fixnum)


6560
6561
6562
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6560

def max_key_bytes
  @max_key_bytes
end

#max_production_output_bytesFixnum

The maximum size for a single output element. Corresponds to the JSON property maxProductionOutputBytes

Returns:

  • (Fixnum)


6565
6566
6567
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6565

def max_production_output_bytes
  @max_production_output_bytes
end

#max_sorted_list_element_bytesFixnum

The maximum size for an element in sorted list state. Corresponds to the JSON property maxSortedListElementBytes

Returns:

  • (Fixnum)


6570
6571
6572
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6570

def max_sorted_list_element_bytes
  @max_sorted_list_element_bytes
end

#max_source_state_bytesFixnum

The maximum size for a source state update. Corresponds to the JSON property maxSourceStateBytes

Returns:

  • (Fixnum)


6575
6576
6577
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6575

def max_source_state_bytes
  @max_source_state_bytes
end

#max_tag_bytesFixnum

The maximum size for a state tag. Corresponds to the JSON property maxTagBytes

Returns:

  • (Fixnum)


6580
6581
6582
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6580

def max_tag_bytes
  @max_tag_bytes
end

#max_value_bytesFixnum

The maximum size for a value state field. Corresponds to the JSON property maxValueBytes

Returns:

  • (Fixnum)


6585
6586
6587
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6585

def max_value_bytes
  @max_value_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6592
6593
6594
6595
6596
6597
6598
6599
6600
6601
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6592

def update!(**args)
  @max_bag_element_bytes = args[:max_bag_element_bytes] if args.key?(:max_bag_element_bytes)
  @max_global_data_bytes = args[:max_global_data_bytes] if args.key?(:max_global_data_bytes)
  @max_key_bytes = args[:max_key_bytes] if args.key?(:max_key_bytes)
  @max_production_output_bytes = args[:max_production_output_bytes] if args.key?(:max_production_output_bytes)
  @max_sorted_list_element_bytes = args[:max_sorted_list_element_bytes] if args.key?(:max_sorted_list_element_bytes)
  @max_source_state_bytes = args[:max_source_state_bytes] if args.key?(:max_source_state_bytes)
  @max_tag_bytes = args[:max_tag_bytes] if args.key?(:max_tag_bytes)
  @max_value_bytes = args[:max_value_bytes] if args.key?(:max_value_bytes)
end