Class: Google::Apis::DataflowV1b3::StreamingSideInputLocation
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::StreamingSideInputLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Identifies the location of a streaming side input.
Instance Attribute Summary collapse
-
#state_family ⇒ String
Identifies the state family where this side input is stored.
-
#tag ⇒ String
Identifies the particular side input within the streaming Dataflow job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StreamingSideInputLocation
constructor
A new instance of StreamingSideInputLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StreamingSideInputLocation
Returns a new instance of StreamingSideInputLocation.
6751 6752 6753 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#state_family ⇒ String
Identifies the state family where this side input is stored.
Corresponds to the JSON property stateFamily
6744 6745 6746 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6744 def state_family @state_family end |
#tag ⇒ String
Identifies the particular side input within the streaming Dataflow job.
Corresponds to the JSON property tag
6749 6750 6751 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6749 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6756 6757 6758 6759 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6756 def update!(**args) @state_family = args[:state_family] if args.key?(:state_family) @tag = args[:tag] if args.key?(:tag) end |