Class: Google::Apis::DataflowV1b3::StreamingStragglerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Information useful for streaming straggler identification and debugging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StreamingStragglerInfo

Returns a new instance of StreamingStragglerInfo.



6811
6812
6813
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_watermark_lagString

The event-time watermark lag at the time of the straggler detection. Corresponds to the JSON property dataWatermarkLag

Returns:

  • (String)


6789
6790
6791
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6789

def data_watermark_lag
  @data_watermark_lag
end

#end_timeString

End time of this straggler. Corresponds to the JSON property endTime

Returns:

  • (String)


6794
6795
6796
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6794

def end_time
  @end_time
end

#start_timeString

Start time of this straggler. Corresponds to the JSON property startTime

Returns:

  • (String)


6799
6800
6801
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6799

def start_time
  @start_time
end

#system_watermark_lagString

The system watermark lag at the time of the straggler detection. Corresponds to the JSON property systemWatermarkLag

Returns:

  • (String)


6804
6805
6806
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6804

def system_watermark_lag
  @system_watermark_lag
end

#worker_nameString

Name of the worker where the straggler was detected. Corresponds to the JSON property workerName

Returns:

  • (String)


6809
6810
6811
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6809

def worker_name
  @worker_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6816
6817
6818
6819
6820
6821
6822
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6816

def update!(**args)
  @data_watermark_lag = args[:data_watermark_lag] if args.key?(:data_watermark_lag)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @system_watermark_lag = args[:system_watermark_lag] if args.key?(:system_watermark_lag)
  @worker_name = args[:worker_name] if args.key?(:worker_name)
end