Class: Google::Apis::DataflowV1b3::TaskRunnerSettings
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::TaskRunnerSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Taskrunner configuration settings.
Instance Attribute Summary collapse
-
#alsologtostderr ⇒ Boolean
(also: #alsologtostderr?)
Whether to also send taskrunner log info to stderr.
-
#base_task_dir ⇒ String
The location on the worker for task-specific subdirectories.
-
#base_url ⇒ String
The base URL for the taskrunner to use when accessing Google Cloud APIs.
-
#commandlines_file_name ⇒ String
The file to store preprocessing commands in.
-
#continue_on_exception ⇒ Boolean
(also: #continue_on_exception?)
Whether to continue taskrunner if an exception is hit.
-
#dataflow_api_version ⇒ String
The API version of endpoint, e.g.
-
#harness_command ⇒ String
The command to launch the worker harness.
-
#language_hint ⇒ String
The suggested backend language.
-
#log_dir ⇒ String
The directory on the VM to store logs.
-
#log_to_serialconsole ⇒ Boolean
(also: #log_to_serialconsole?)
Whether to send taskrunner log info to Google Compute Engine VM serial console.
-
#log_upload_location ⇒ String
Indicates where to put logs.
-
#oauth_scopes ⇒ Array<String>
The OAuth2 scopes to be requested by the taskrunner in order to access the Cloud Dataflow API.
-
#parallel_worker_settings ⇒ Google::Apis::DataflowV1b3::WorkerSettings
Provides data to pass through to the worker harness.
-
#streaming_worker_main_class ⇒ String
The streaming worker main class name.
-
#task_group ⇒ String
The UNIX group ID on the worker VM to use for tasks launched by taskrunner; e.
-
#task_user ⇒ String
The UNIX user ID on the worker VM to use for tasks launched by taskrunner; e.g.
-
#temp_storage_prefix ⇒ String
The prefix of the resources the taskrunner should use for temporary storage.
-
#vm_id ⇒ String
The ID string of the VM.
-
#workflow_file_name ⇒ String
The file to store the workflow in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TaskRunnerSettings
constructor
A new instance of TaskRunnerSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TaskRunnerSettings
Returns a new instance of TaskRunnerSettings.
7105 7106 7107 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alsologtostderr ⇒ Boolean Also known as: alsologtostderr?
Whether to also send taskrunner log info to stderr.
Corresponds to the JSON property alsologtostderr
6998 6999 7000 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6998 def alsologtostderr @alsologtostderr end |
#base_task_dir ⇒ String
The location on the worker for task-specific subdirectories.
Corresponds to the JSON property baseTaskDir
7004 7005 7006 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7004 def base_task_dir @base_task_dir end |
#base_url ⇒ String
The base URL for the taskrunner to use when accessing Google Cloud APIs. When
workers access Google Cloud APIs, they logically do so via relative URLs. If
this field is specified, it supplies the base URL to use for resolving these
relative URLs. The normative algorithm used is defined by RFC 1808, "Relative
Uniform Resource Locators". If not specified, the default value is "http://www.
googleapis.com/"
Corresponds to the JSON property baseUrl
7014 7015 7016 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7014 def base_url @base_url end |
#commandlines_file_name ⇒ String
The file to store preprocessing commands in.
Corresponds to the JSON property commandlinesFileName
7019 7020 7021 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7019 def commandlines_file_name @commandlines_file_name end |
#continue_on_exception ⇒ Boolean Also known as: continue_on_exception?
Whether to continue taskrunner if an exception is hit.
Corresponds to the JSON property continueOnException
7024 7025 7026 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7024 def continue_on_exception @continue_on_exception end |
#dataflow_api_version ⇒ String
The API version of endpoint, e.g. "v1b3"
Corresponds to the JSON property dataflowApiVersion
7030 7031 7032 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7030 def dataflow_api_version @dataflow_api_version end |
#harness_command ⇒ String
The command to launch the worker harness.
Corresponds to the JSON property harnessCommand
7035 7036 7037 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7035 def harness_command @harness_command end |
#language_hint ⇒ String
The suggested backend language.
Corresponds to the JSON property languageHint
7040 7041 7042 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7040 def language_hint @language_hint end |
#log_dir ⇒ String
The directory on the VM to store logs.
Corresponds to the JSON property logDir
7045 7046 7047 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7045 def log_dir @log_dir end |
#log_to_serialconsole ⇒ Boolean Also known as: log_to_serialconsole?
Whether to send taskrunner log info to Google Compute Engine VM serial console.
Corresponds to the JSON property logToSerialconsole
7050 7051 7052 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7050 def log_to_serialconsole @log_to_serialconsole end |
#log_upload_location ⇒ String
Indicates where to put logs. If this is not specified, the logs will not be
uploaded. The supported resource type is: Google Cloud Storage: storage.
googleapis.com/bucket/object bucket.storage.googleapis.com/object
Corresponds to the JSON property logUploadLocation
7058 7059 7060 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7058 def log_upload_location @log_upload_location end |
#oauth_scopes ⇒ Array<String>
The OAuth2 scopes to be requested by the taskrunner in order to access the
Cloud Dataflow API.
Corresponds to the JSON property oauthScopes
7064 7065 7066 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7064 def oauth_scopes @oauth_scopes end |
#parallel_worker_settings ⇒ Google::Apis::DataflowV1b3::WorkerSettings
Provides data to pass through to the worker harness.
Corresponds to the JSON property parallelWorkerSettings
7069 7070 7071 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7069 def parallel_worker_settings @parallel_worker_settings end |
#streaming_worker_main_class ⇒ String
The streaming worker main class name.
Corresponds to the JSON property streamingWorkerMainClass
7074 7075 7076 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7074 def streaming_worker_main_class @streaming_worker_main_class end |
#task_group ⇒ String
The UNIX group ID on the worker VM to use for tasks launched by taskrunner; e.
g. "wheel".
Corresponds to the JSON property taskGroup
7080 7081 7082 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7080 def task_group @task_group end |
#task_user ⇒ String
The UNIX user ID on the worker VM to use for tasks launched by taskrunner; e.g.
"root".
Corresponds to the JSON property taskUser
7086 7087 7088 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7086 def task_user @task_user end |
#temp_storage_prefix ⇒ String
The prefix of the resources the taskrunner should use for temporary storage.
The supported resource type is: Google Cloud Storage: storage.googleapis.com/
bucket/object bucket.storage.googleapis.com/object
Corresponds to the JSON property tempStoragePrefix
7093 7094 7095 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7093 def temp_storage_prefix @temp_storage_prefix end |
#vm_id ⇒ String
The ID string of the VM.
Corresponds to the JSON property vmId
7098 7099 7100 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7098 def vm_id @vm_id end |
#workflow_file_name ⇒ String
The file to store the workflow in.
Corresponds to the JSON property workflowFileName
7103 7104 7105 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7103 def workflow_file_name @workflow_file_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7110 7111 7112 7113 7114 7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7110 def update!(**args) @alsologtostderr = args[:alsologtostderr] if args.key?(:alsologtostderr) @base_task_dir = args[:base_task_dir] if args.key?(:base_task_dir) @base_url = args[:base_url] if args.key?(:base_url) @commandlines_file_name = args[:commandlines_file_name] if args.key?(:commandlines_file_name) @continue_on_exception = args[:continue_on_exception] if args.key?(:continue_on_exception) @dataflow_api_version = args[:dataflow_api_version] if args.key?(:dataflow_api_version) @harness_command = args[:harness_command] if args.key?(:harness_command) @language_hint = args[:language_hint] if args.key?(:language_hint) @log_dir = args[:log_dir] if args.key?(:log_dir) @log_to_serialconsole = args[:log_to_serialconsole] if args.key?(:log_to_serialconsole) @log_upload_location = args[:log_upload_location] if args.key?(:log_upload_location) @oauth_scopes = args[:oauth_scopes] if args.key?(:oauth_scopes) @parallel_worker_settings = args[:parallel_worker_settings] if args.key?(:parallel_worker_settings) @streaming_worker_main_class = args[:streaming_worker_main_class] if args.key?(:streaming_worker_main_class) @task_group = args[:task_group] if args.key?(:task_group) @task_user = args[:task_user] if args.key?(:task_user) @temp_storage_prefix = args[:temp_storage_prefix] if args.key?(:temp_storage_prefix) @vm_id = args[:vm_id] if args.key?(:vm_id) @workflow_file_name = args[:workflow_file_name] if args.key?(:workflow_file_name) end |