Class: Google::Apis::DataflowV1b3::TaskRunnerSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Taskrunner configuration settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TaskRunnerSettings

Returns a new instance of TaskRunnerSettings.



7000
7001
7002
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alsologtostderrBoolean Also known as: alsologtostderr?

Whether to also send taskrunner log info to stderr. Corresponds to the JSON property alsologtostderr

Returns:

  • (Boolean)


6893
6894
6895
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6893

def alsologtostderr
  @alsologtostderr
end

#base_task_dirString

The location on the worker for task-specific subdirectories. Corresponds to the JSON property baseTaskDir

Returns:

  • (String)


6899
6900
6901
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6899

def base_task_dir
  @base_task_dir
end

#base_urlString

The base URL for the taskrunner to use when accessing Google Cloud APIs. When workers access Google Cloud APIs, they logically do so via relative URLs. If this field is specified, it supplies the base URL to use for resolving these relative URLs. The normative algorithm used is defined by RFC 1808, "Relative Uniform Resource Locators". If not specified, the default value is "http://www. googleapis.com/" Corresponds to the JSON property baseUrl

Returns:

  • (String)


6909
6910
6911
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6909

def base_url
  @base_url
end

#commandlines_file_nameString

The file to store preprocessing commands in. Corresponds to the JSON property commandlinesFileName

Returns:

  • (String)


6914
6915
6916
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6914

def commandlines_file_name
  @commandlines_file_name
end

#continue_on_exceptionBoolean Also known as: continue_on_exception?

Whether to continue taskrunner if an exception is hit. Corresponds to the JSON property continueOnException

Returns:

  • (Boolean)


6919
6920
6921
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6919

def continue_on_exception
  @continue_on_exception
end

#dataflow_api_versionString

The API version of endpoint, e.g. "v1b3" Corresponds to the JSON property dataflowApiVersion

Returns:

  • (String)


6925
6926
6927
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6925

def dataflow_api_version
  @dataflow_api_version
end

#harness_commandString

The command to launch the worker harness. Corresponds to the JSON property harnessCommand

Returns:

  • (String)


6930
6931
6932
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6930

def harness_command
  @harness_command
end

#language_hintString

The suggested backend language. Corresponds to the JSON property languageHint

Returns:

  • (String)


6935
6936
6937
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6935

def language_hint
  @language_hint
end

#log_dirString

The directory on the VM to store logs. Corresponds to the JSON property logDir

Returns:

  • (String)


6940
6941
6942
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6940

def log_dir
  @log_dir
end

#log_to_serialconsoleBoolean Also known as: log_to_serialconsole?

Whether to send taskrunner log info to Google Compute Engine VM serial console. Corresponds to the JSON property logToSerialconsole

Returns:

  • (Boolean)


6945
6946
6947
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6945

def log_to_serialconsole
  @log_to_serialconsole
end

#log_upload_locationString

Indicates where to put logs. If this is not specified, the logs will not be uploaded. The supported resource type is: Google Cloud Storage: storage. googleapis.com/bucket/object bucket.storage.googleapis.com/object Corresponds to the JSON property logUploadLocation

Returns:

  • (String)


6953
6954
6955
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6953

def log_upload_location
  @log_upload_location
end

#oauth_scopesArray<String>

The OAuth2 scopes to be requested by the taskrunner in order to access the Cloud Dataflow API. Corresponds to the JSON property oauthScopes

Returns:

  • (Array<String>)


6959
6960
6961
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6959

def oauth_scopes
  @oauth_scopes
end

#parallel_worker_settingsGoogle::Apis::DataflowV1b3::WorkerSettings

Provides data to pass through to the worker harness. Corresponds to the JSON property parallelWorkerSettings



6964
6965
6966
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6964

def parallel_worker_settings
  @parallel_worker_settings
end

#streaming_worker_main_classString

The streaming worker main class name. Corresponds to the JSON property streamingWorkerMainClass

Returns:

  • (String)


6969
6970
6971
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6969

def streaming_worker_main_class
  @streaming_worker_main_class
end

#task_groupString

The UNIX group ID on the worker VM to use for tasks launched by taskrunner; e. g. "wheel". Corresponds to the JSON property taskGroup

Returns:

  • (String)


6975
6976
6977
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6975

def task_group
  @task_group
end

#task_userString

The UNIX user ID on the worker VM to use for tasks launched by taskrunner; e.g. "root". Corresponds to the JSON property taskUser

Returns:

  • (String)


6981
6982
6983
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6981

def task_user
  @task_user
end

#temp_storage_prefixString

The prefix of the resources the taskrunner should use for temporary storage. The supported resource type is: Google Cloud Storage: storage.googleapis.com/ bucket/object bucket.storage.googleapis.com/object Corresponds to the JSON property tempStoragePrefix

Returns:

  • (String)


6988
6989
6990
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6988

def temp_storage_prefix
  @temp_storage_prefix
end

#vm_idString

The ID string of the VM. Corresponds to the JSON property vmId

Returns:

  • (String)


6993
6994
6995
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6993

def vm_id
  @vm_id
end

#workflow_file_nameString

The file to store the workflow in. Corresponds to the JSON property workflowFileName

Returns:

  • (String)


6998
6999
7000
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 6998

def workflow_file_name
  @workflow_file_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
7021
7022
7023
7024
7025
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7005

def update!(**args)
  @alsologtostderr = args[:alsologtostderr] if args.key?(:alsologtostderr)
  @base_task_dir = args[:base_task_dir] if args.key?(:base_task_dir)
  @base_url = args[:base_url] if args.key?(:base_url)
  @commandlines_file_name = args[:commandlines_file_name] if args.key?(:commandlines_file_name)
  @continue_on_exception = args[:continue_on_exception] if args.key?(:continue_on_exception)
  @dataflow_api_version = args[:dataflow_api_version] if args.key?(:dataflow_api_version)
  @harness_command = args[:harness_command] if args.key?(:harness_command)
  @language_hint = args[:language_hint] if args.key?(:language_hint)
  @log_dir = args[:log_dir] if args.key?(:log_dir)
  @log_to_serialconsole = args[:log_to_serialconsole] if args.key?(:log_to_serialconsole)
  @log_upload_location = args[:log_upload_location] if args.key?(:log_upload_location)
  @oauth_scopes = args[:oauth_scopes] if args.key?(:oauth_scopes)
  @parallel_worker_settings = args[:parallel_worker_settings] if args.key?(:parallel_worker_settings)
  @streaming_worker_main_class = args[:streaming_worker_main_class] if args.key?(:streaming_worker_main_class)
  @task_group = args[:task_group] if args.key?(:task_group)
  @task_user = args[:task_user] if args.key?(:task_user)
  @temp_storage_prefix = args[:temp_storage_prefix] if args.key?(:temp_storage_prefix)
  @vm_id = args[:vm_id] if args.key?(:vm_id)
  @workflow_file_name = args[:workflow_file_name] if args.key?(:workflow_file_name)
end