Class: Google::Apis::DataflowV1b3::TemplateMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Metadata describing a template.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TemplateMetadata

Returns a new instance of TemplateMetadata.



7069
7070
7071
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7069

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_streaming_modeString

Optional. Indicates the default streaming mode for a streaming template. Only valid if both supports_at_least_once and supports_exactly_once are true. Possible values: UNSPECIFIED, EXACTLY_ONCE and AT_LEAST_ONCE Corresponds to the JSON property defaultStreamingMode

Returns:

  • (String)


7029
7030
7031
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7029

def default_streaming_mode
  @default_streaming_mode
end

#descriptionString

Optional. A description of the template. Corresponds to the JSON property description

Returns:

  • (String)


7034
7035
7036
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7034

def description
  @description
end

#nameString

Required. The name of the template. Corresponds to the JSON property name

Returns:

  • (String)


7039
7040
7041
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7039

def name
  @name
end

#parametersArray<Google::Apis::DataflowV1b3::ParameterMetadata>

The parameters for the template. Corresponds to the JSON property parameters



7044
7045
7046
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7044

def parameters
  @parameters
end

#streamingBoolean Also known as: streaming?

Optional. Indicates if the template is streaming or not. Corresponds to the JSON property streaming

Returns:

  • (Boolean)


7049
7050
7051
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7049

def streaming
  @streaming
end

#supports_at_least_onceBoolean Also known as: supports_at_least_once?

Optional. Indicates if the streaming template supports at least once mode. Corresponds to the JSON property supportsAtLeastOnce

Returns:

  • (Boolean)


7055
7056
7057
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7055

def supports_at_least_once
  @supports_at_least_once
end

#supports_exactly_onceBoolean Also known as: supports_exactly_once?

Optional. Indicates if the streaming template supports exactly once mode. Corresponds to the JSON property supportsExactlyOnce

Returns:

  • (Boolean)


7061
7062
7063
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7061

def supports_exactly_once
  @supports_exactly_once
end

#yaml_definitionString

Optional. For future use. Corresponds to the JSON property yamlDefinition

Returns:

  • (String)


7067
7068
7069
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7067

def yaml_definition
  @yaml_definition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7074
7075
7076
7077
7078
7079
7080
7081
7082
7083
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7074

def update!(**args)
  @default_streaming_mode = args[:default_streaming_mode] if args.key?(:default_streaming_mode)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @streaming = args[:streaming] if args.key?(:streaming)
  @supports_at_least_once = args[:supports_at_least_once] if args.key?(:supports_at_least_once)
  @supports_exactly_once = args[:supports_exactly_once] if args.key?(:supports_exactly_once)
  @yaml_definition = args[:yaml_definition] if args.key?(:yaml_definition)
end