Class: Google::Apis::DataflowV1b3::TransformSummary
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::TransformSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Description of the type, names/ids, and input/outputs for a transform.
Instance Attribute Summary collapse
-
#display_data ⇒ Array<Google::Apis::DataflowV1b3::DisplayData>
Transform-specific display data.
-
#id ⇒ String
SDK generated id of this transform instance.
-
#input_collection_name ⇒ Array<String>
User names for all collection inputs to this transform.
-
#kind ⇒ String
Type of transform.
-
#name ⇒ String
User provided name for this transform instance.
-
#output_collection_name ⇒ Array<String>
User names for all collection outputs to this transform.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransformSummary
constructor
A new instance of TransformSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransformSummary
Returns a new instance of TransformSummary.
7164 7165 7166 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_data ⇒ Array<Google::Apis::DataflowV1b3::DisplayData>
Transform-specific display data.
Corresponds to the JSON property displayData
7137 7138 7139 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7137 def display_data @display_data end |
#id ⇒ String
SDK generated id of this transform instance.
Corresponds to the JSON property id
7142 7143 7144 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7142 def id @id end |
#input_collection_name ⇒ Array<String>
User names for all collection inputs to this transform.
Corresponds to the JSON property inputCollectionName
7147 7148 7149 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7147 def input_collection_name @input_collection_name end |
#kind ⇒ String
Type of transform.
Corresponds to the JSON property kind
7152 7153 7154 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7152 def kind @kind end |
#name ⇒ String
User provided name for this transform instance.
Corresponds to the JSON property name
7157 7158 7159 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7157 def name @name end |
#output_collection_name ⇒ Array<String>
User names for all collection outputs to this transform.
Corresponds to the JSON property outputCollectionName
7162 7163 7164 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7162 def output_collection_name @output_collection_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7169 7170 7171 7172 7173 7174 7175 7176 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7169 def update!(**args) @display_data = args[:display_data] if args.key?(:display_data) @id = args[:id] if args.key?(:id) @input_collection_name = args[:input_collection_name] if args.key?(:input_collection_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @output_collection_name = args[:output_collection_name] if args.key?(:output_collection_name) end |