Class: Google::Apis::DataflowV1b3::WorkItem
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
WorkItem represents basic information about a WorkItem to be executed in the cloud.
Instance Attribute Summary collapse
-
#configuration ⇒ String
Work item-specific configuration as an opaque blob.
-
#id ⇒ Fixnum
Identifies this WorkItem.
-
#initial_report_index ⇒ Fixnum
The initial index to use when reporting the status of the WorkItem.
-
#job_id ⇒ String
Identifies the workflow job this WorkItem belongs to.
-
#lease_expire_time ⇒ String
Time when the lease on this Work will expire.
-
#map_task ⇒ Google::Apis::DataflowV1b3::MapTask
MapTask consists of an ordered set of instructions, each of which describes one particular low-level operation for the worker to perform in order to accomplish the MapTask's WorkItem.
-
#packages ⇒ Array<Google::Apis::DataflowV1b3::Package>
Any required packages that need to be fetched in order to execute this WorkItem.
-
#project_id ⇒ String
Identifies the cloud project this WorkItem belongs to.
-
#report_status_interval ⇒ String
Recommended reporting interval.
-
#seq_map_task ⇒ Google::Apis::DataflowV1b3::SeqMapTask
Describes a particular function to invoke.
-
#shell_task ⇒ Google::Apis::DataflowV1b3::ShellTask
A task which consists of a shell command for the worker to execute.
-
#source_operation_task ⇒ Google::Apis::DataflowV1b3::SourceOperationRequest
A work item that represents the different operations that can be performed on a user-defined Source specification.
-
#streaming_computation_task ⇒ Google::Apis::DataflowV1b3::StreamingComputationTask
A task which describes what action should be performed for the specified streaming computation ranges.
-
#streaming_config_task ⇒ Google::Apis::DataflowV1b3::StreamingConfigTask
A task that carries configuration information for streaming computations.
-
#streaming_setup_task ⇒ Google::Apis::DataflowV1b3::StreamingSetupTask
A task which initializes part of a streaming Dataflow job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkItem
constructor
A new instance of WorkItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkItem
Returns a new instance of WorkItem.
7265 7266 7267 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration ⇒ String
Work item-specific configuration as an opaque blob.
Corresponds to the JSON property configuration
7187 7188 7189 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7187 def configuration @configuration end |
#id ⇒ Fixnum
Identifies this WorkItem.
Corresponds to the JSON property id
7192 7193 7194 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7192 def id @id end |
#initial_report_index ⇒ Fixnum
The initial index to use when reporting the status of the WorkItem.
Corresponds to the JSON property initialReportIndex
7197 7198 7199 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7197 def initial_report_index @initial_report_index end |
#job_id ⇒ String
Identifies the workflow job this WorkItem belongs to.
Corresponds to the JSON property jobId
7202 7203 7204 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7202 def job_id @job_id end |
#lease_expire_time ⇒ String
Time when the lease on this Work will expire.
Corresponds to the JSON property leaseExpireTime
7207 7208 7209 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7207 def lease_expire_time @lease_expire_time end |
#map_task ⇒ Google::Apis::DataflowV1b3::MapTask
MapTask consists of an ordered set of instructions, each of which describes
one particular low-level operation for the worker to perform in order to
accomplish the MapTask's WorkItem. Each instruction must appear in the list
before any instructions which depends on its output.
Corresponds to the JSON property mapTask
7215 7216 7217 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7215 def map_task @map_task end |
#packages ⇒ Array<Google::Apis::DataflowV1b3::Package>
Any required packages that need to be fetched in order to execute this
WorkItem.
Corresponds to the JSON property packages
7221 7222 7223 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7221 def packages @packages end |
#project_id ⇒ String
Identifies the cloud project this WorkItem belongs to.
Corresponds to the JSON property projectId
7226 7227 7228 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7226 def project_id @project_id end |
#report_status_interval ⇒ String
Recommended reporting interval.
Corresponds to the JSON property reportStatusInterval
7231 7232 7233 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7231 def report_status_interval @report_status_interval end |
#seq_map_task ⇒ Google::Apis::DataflowV1b3::SeqMapTask
Describes a particular function to invoke.
Corresponds to the JSON property seqMapTask
7236 7237 7238 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7236 def seq_map_task @seq_map_task end |
#shell_task ⇒ Google::Apis::DataflowV1b3::ShellTask
A task which consists of a shell command for the worker to execute.
Corresponds to the JSON property shellTask
7241 7242 7243 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7241 def shell_task @shell_task end |
#source_operation_task ⇒ Google::Apis::DataflowV1b3::SourceOperationRequest
A work item that represents the different operations that can be performed on
a user-defined Source specification.
Corresponds to the JSON property sourceOperationTask
7247 7248 7249 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7247 def source_operation_task @source_operation_task end |
#streaming_computation_task ⇒ Google::Apis::DataflowV1b3::StreamingComputationTask
A task which describes what action should be performed for the specified
streaming computation ranges.
Corresponds to the JSON property streamingComputationTask
7253 7254 7255 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7253 def streaming_computation_task @streaming_computation_task end |
#streaming_config_task ⇒ Google::Apis::DataflowV1b3::StreamingConfigTask
A task that carries configuration information for streaming computations.
Corresponds to the JSON property streamingConfigTask
7258 7259 7260 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7258 def streaming_config_task @streaming_config_task end |
#streaming_setup_task ⇒ Google::Apis::DataflowV1b3::StreamingSetupTask
A task which initializes part of a streaming Dataflow job.
Corresponds to the JSON property streamingSetupTask
7263 7264 7265 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7263 def streaming_setup_task @streaming_setup_task end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7270 7271 7272 7273 7274 7275 7276 7277 7278 7279 7280 7281 7282 7283 7284 7285 7286 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7270 def update!(**args) @configuration = args[:configuration] if args.key?(:configuration) @id = args[:id] if args.key?(:id) @initial_report_index = args[:initial_report_index] if args.key?(:initial_report_index) @job_id = args[:job_id] if args.key?(:job_id) @lease_expire_time = args[:lease_expire_time] if args.key?(:lease_expire_time) @map_task = args[:map_task] if args.key?(:map_task) @packages = args[:packages] if args.key?(:packages) @project_id = args[:project_id] if args.key?(:project_id) @report_status_interval = args[:report_status_interval] if args.key?(:report_status_interval) @seq_map_task = args[:seq_map_task] if args.key?(:seq_map_task) @shell_task = args[:shell_task] if args.key?(:shell_task) @source_operation_task = args[:source_operation_task] if args.key?(:source_operation_task) @streaming_computation_task = args[:streaming_computation_task] if args.key?(:streaming_computation_task) @streaming_config_task = args[:streaming_config_task] if args.key?(:streaming_config_task) @streaming_setup_task = args[:streaming_setup_task] if args.key?(:streaming_setup_task) end |