Class: Google::Apis::DataflowV1b3::WorkItemDetails
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkItemDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Information about an individual work item execution.
Instance Attribute Summary collapse
-
#attempt_id ⇒ String
Attempt ID of this work item Corresponds to the JSON property
attemptId. -
#end_time ⇒ String
End time of this work item attempt.
-
#metrics ⇒ Array<Google::Apis::DataflowV1b3::MetricUpdate>
Metrics for this work item.
-
#progress ⇒ Google::Apis::DataflowV1b3::ProgressTimeseries
Information about the progress of some component of job execution.
-
#start_time ⇒ String
Start time of this work item attempt.
-
#state ⇒ String
State of this work item.
-
#straggler_info ⇒ Google::Apis::DataflowV1b3::StragglerInfo
Information useful for straggler identification and debugging.
-
#task_id ⇒ String
Name of this work item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkItemDetails
constructor
A new instance of WorkItemDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkItemDetails
Returns a new instance of WorkItemDetails.
7342 7343 7344 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attempt_id ⇒ String
Attempt ID of this work item
Corresponds to the JSON property attemptId
7304 7305 7306 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7304 def attempt_id @attempt_id end |
#end_time ⇒ String
End time of this work item attempt. If the work item is completed, this is the
actual end time of the work item. Otherwise, it is the predicted end time.
Corresponds to the JSON property endTime
7310 7311 7312 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7310 def end_time @end_time end |
#metrics ⇒ Array<Google::Apis::DataflowV1b3::MetricUpdate>
Metrics for this work item.
Corresponds to the JSON property metrics
7315 7316 7317 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7315 def metrics @metrics end |
#progress ⇒ Google::Apis::DataflowV1b3::ProgressTimeseries
Information about the progress of some component of job execution.
Corresponds to the JSON property progress
7320 7321 7322 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7320 def progress @progress end |
#start_time ⇒ String
Start time of this work item attempt.
Corresponds to the JSON property startTime
7325 7326 7327 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7325 def start_time @start_time end |
#state ⇒ String
State of this work item.
Corresponds to the JSON property state
7330 7331 7332 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7330 def state @state end |
#straggler_info ⇒ Google::Apis::DataflowV1b3::StragglerInfo
Information useful for straggler identification and debugging.
Corresponds to the JSON property stragglerInfo
7335 7336 7337 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7335 def straggler_info @straggler_info end |
#task_id ⇒ String
Name of this work item.
Corresponds to the JSON property taskId
7340 7341 7342 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7340 def task_id @task_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7347 7348 7349 7350 7351 7352 7353 7354 7355 7356 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7347 def update!(**args) @attempt_id = args[:attempt_id] if args.key?(:attempt_id) @end_time = args[:end_time] if args.key?(:end_time) @metrics = args[:metrics] if args.key?(:metrics) @progress = args[:progress] if args.key?(:progress) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @straggler_info = args[:straggler_info] if args.key?(:straggler_info) @task_id = args[:task_id] if args.key?(:task_id) end |