Class: Google::Apis::DataflowV1b3::WorkItemStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Conveys a worker's progress through the work described by a WorkItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkItemStatus

Returns a new instance of WorkItemStatus.



7535
7536
7537
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completedBoolean Also known as: completed?

True if the WorkItem was completed (successfully or unsuccessfully). Corresponds to the JSON property completed

Returns:

  • (Boolean)


7453
7454
7455
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7453

def completed
  @completed
end

#counter_updatesArray<Google::Apis::DataflowV1b3::CounterUpdate>

Worker output counters for this WorkItem. Corresponds to the JSON property counterUpdates



7459
7460
7461
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7459

def counter_updates
  @counter_updates
end

#dynamic_source_splitGoogle::Apis::DataflowV1b3::DynamicSourceSplit

When a task splits using WorkItemStatus.dynamic_source_split, this message describes the two parts of the split relative to the description of the current task's input. Corresponds to the JSON property dynamicSourceSplit



7466
7467
7468
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7466

def dynamic_source_split
  @dynamic_source_split
end

#errorsArray<Google::Apis::DataflowV1b3::Status>

Specifies errors which occurred during processing. If errors are provided, and completed = true, then the WorkItem is considered to have failed. Corresponds to the JSON property errors



7472
7473
7474
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7472

def errors
  @errors
end

#metric_updatesArray<Google::Apis::DataflowV1b3::MetricUpdate>

DEPRECATED in favor of counter_updates. Corresponds to the JSON property metricUpdates



7477
7478
7479
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7477

def metric_updates
  @metric_updates
end

#progressGoogle::Apis::DataflowV1b3::ApproximateProgress

Obsolete in favor of ApproximateReportedProgress and ApproximateSplitRequest. Corresponds to the JSON property progress



7482
7483
7484
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7482

def progress
  @progress
end

#report_indexFixnum

The report index. When a WorkItem is leased, the lease will contain an initial report index. When a WorkItem's status is reported to the system, the report should be sent with that report index, and the response will contain the index the worker should use for the next report. Reports received with unexpected index values will be rejected by the service. In order to preserve idempotency, the worker should not alter the contents of a report, even if the worker must submit the same report multiple times before getting back a response. The worker should not submit a subsequent report until the response for the previous report had been received from the service. Corresponds to the JSON property reportIndex

Returns:

  • (Fixnum)


7495
7496
7497
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7495

def report_index
  @report_index
end

#reported_progressGoogle::Apis::DataflowV1b3::ApproximateReportedProgress

A progress measurement of a WorkItem by a worker. Corresponds to the JSON property reportedProgress



7500
7501
7502
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7500

def reported_progress
  @reported_progress
end

#requested_lease_durationString

Amount of time the worker requests for its lease. Corresponds to the JSON property requestedLeaseDuration

Returns:

  • (String)


7505
7506
7507
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7505

def requested_lease_duration
  @requested_lease_duration
end

#source_forkGoogle::Apis::DataflowV1b3::SourceFork

DEPRECATED in favor of DynamicSourceSplit. Corresponds to the JSON property sourceFork



7510
7511
7512
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7510

def source_fork
  @source_fork
end

#source_operation_responseGoogle::Apis::DataflowV1b3::SourceOperationResponse

The result of a SourceOperationRequest, specified in ReportWorkItemStatusRequest.source_operation when the work item is completed. Corresponds to the JSON property sourceOperationResponse



7516
7517
7518
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7516

def source_operation_response
  @source_operation_response
end

#stop_positionGoogle::Apis::DataflowV1b3::Position

Position defines a position within a collection of data. The value can be either the end position, a key (used with ordered collections), a byte offset, or a record index. Corresponds to the JSON property stopPosition



7523
7524
7525
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7523

def stop_position
  @stop_position
end

#total_throttler_wait_time_secondsFloat

Total time the worker spent being throttled by external systems. Corresponds to the JSON property totalThrottlerWaitTimeSeconds

Returns:

  • (Float)


7528
7529
7530
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7528

def total_throttler_wait_time_seconds
  @total_throttler_wait_time_seconds
end

#work_item_idString

Identifies the WorkItem. Corresponds to the JSON property workItemId

Returns:

  • (String)


7533
7534
7535
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7533

def work_item_id
  @work_item_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7540
7541
7542
7543
7544
7545
7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7540

def update!(**args)
  @completed = args[:completed] if args.key?(:completed)
  @counter_updates = args[:counter_updates] if args.key?(:counter_updates)
  @dynamic_source_split = args[:dynamic_source_split] if args.key?(:dynamic_source_split)
  @errors = args[:errors] if args.key?(:errors)
  @metric_updates = args[:metric_updates] if args.key?(:metric_updates)
  @progress = args[:progress] if args.key?(:progress)
  @report_index = args[:report_index] if args.key?(:report_index)
  @reported_progress = args[:reported_progress] if args.key?(:reported_progress)
  @requested_lease_duration = args[:requested_lease_duration] if args.key?(:requested_lease_duration)
  @source_fork = args[:source_fork] if args.key?(:source_fork)
  @source_operation_response = args[:source_operation_response] if args.key?(:source_operation_response)
  @stop_position = args[:stop_position] if args.key?(:stop_position)
  @total_throttler_wait_time_seconds = args[:total_throttler_wait_time_seconds] if args.key?(:total_throttler_wait_time_seconds)
  @work_item_id = args[:work_item_id] if args.key?(:work_item_id)
end