Class: Google::Apis::DataflowV1b3::WorkItemStatus
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkItemStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Conveys a worker's progress through the work described by a WorkItem.
Instance Attribute Summary collapse
-
#completed ⇒ Boolean
(also: #completed?)
True if the WorkItem was completed (successfully or unsuccessfully).
-
#counter_updates ⇒ Array<Google::Apis::DataflowV1b3::CounterUpdate>
Worker output counters for this WorkItem.
-
#dynamic_source_split ⇒ Google::Apis::DataflowV1b3::DynamicSourceSplit
When a task splits using WorkItemStatus.dynamic_source_split, this message describes the two parts of the split relative to the description of the current task's input.
-
#errors ⇒ Array<Google::Apis::DataflowV1b3::Status>
Specifies errors which occurred during processing.
-
#metric_updates ⇒ Array<Google::Apis::DataflowV1b3::MetricUpdate>
DEPRECATED in favor of counter_updates.
-
#progress ⇒ Google::Apis::DataflowV1b3::ApproximateProgress
Obsolete in favor of ApproximateReportedProgress and ApproximateSplitRequest.
-
#report_index ⇒ Fixnum
The report index.
-
#reported_progress ⇒ Google::Apis::DataflowV1b3::ApproximateReportedProgress
A progress measurement of a WorkItem by a worker.
-
#requested_lease_duration ⇒ String
Amount of time the worker requests for its lease.
-
#source_fork ⇒ Google::Apis::DataflowV1b3::SourceFork
DEPRECATED in favor of DynamicSourceSplit.
-
#source_operation_response ⇒ Google::Apis::DataflowV1b3::SourceOperationResponse
The result of a SourceOperationRequest, specified in ReportWorkItemStatusRequest.source_operation when the work item is completed.
-
#stop_position ⇒ Google::Apis::DataflowV1b3::Position
Position defines a position within a collection of data.
-
#total_throttler_wait_time_seconds ⇒ Float
Total time the worker spent being throttled by external systems.
-
#work_item_id ⇒ String
Identifies the WorkItem.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkItemStatus
constructor
A new instance of WorkItemStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkItemStatus
Returns a new instance of WorkItemStatus.
7527 7528 7529 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed ⇒ Boolean Also known as: completed?
True if the WorkItem was completed (successfully or unsuccessfully).
Corresponds to the JSON property completed
7445 7446 7447 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7445 def completed @completed end |
#counter_updates ⇒ Array<Google::Apis::DataflowV1b3::CounterUpdate>
Worker output counters for this WorkItem.
Corresponds to the JSON property counterUpdates
7451 7452 7453 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7451 def counter_updates @counter_updates end |
#dynamic_source_split ⇒ Google::Apis::DataflowV1b3::DynamicSourceSplit
When a task splits using WorkItemStatus.dynamic_source_split, this message
describes the two parts of the split relative to the description of the
current task's input.
Corresponds to the JSON property dynamicSourceSplit
7458 7459 7460 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7458 def dynamic_source_split @dynamic_source_split end |
#errors ⇒ Array<Google::Apis::DataflowV1b3::Status>
Specifies errors which occurred during processing. If errors are provided, and
completed = true, then the WorkItem is considered to have failed.
Corresponds to the JSON property errors
7464 7465 7466 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7464 def errors @errors end |
#metric_updates ⇒ Array<Google::Apis::DataflowV1b3::MetricUpdate>
DEPRECATED in favor of counter_updates.
Corresponds to the JSON property metricUpdates
7469 7470 7471 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7469 def metric_updates @metric_updates end |
#progress ⇒ Google::Apis::DataflowV1b3::ApproximateProgress
Obsolete in favor of ApproximateReportedProgress and ApproximateSplitRequest.
Corresponds to the JSON property progress
7474 7475 7476 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7474 def progress @progress end |
#report_index ⇒ Fixnum
The report index. When a WorkItem is leased, the lease will contain an initial
report index. When a WorkItem's status is reported to the system, the report
should be sent with that report index, and the response will contain the index
the worker should use for the next report. Reports received with unexpected
index values will be rejected by the service. In order to preserve idempotency,
the worker should not alter the contents of a report, even if the worker must
submit the same report multiple times before getting back a response. The
worker should not submit a subsequent report until the response for the
previous report had been received from the service.
Corresponds to the JSON property reportIndex
7487 7488 7489 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7487 def report_index @report_index end |
#reported_progress ⇒ Google::Apis::DataflowV1b3::ApproximateReportedProgress
A progress measurement of a WorkItem by a worker.
Corresponds to the JSON property reportedProgress
7492 7493 7494 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7492 def reported_progress @reported_progress end |
#requested_lease_duration ⇒ String
Amount of time the worker requests for its lease.
Corresponds to the JSON property requestedLeaseDuration
7497 7498 7499 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7497 def requested_lease_duration @requested_lease_duration end |
#source_fork ⇒ Google::Apis::DataflowV1b3::SourceFork
DEPRECATED in favor of DynamicSourceSplit.
Corresponds to the JSON property sourceFork
7502 7503 7504 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7502 def source_fork @source_fork end |
#source_operation_response ⇒ Google::Apis::DataflowV1b3::SourceOperationResponse
The result of a SourceOperationRequest, specified in
ReportWorkItemStatusRequest.source_operation when the work item is completed.
Corresponds to the JSON property sourceOperationResponse
7508 7509 7510 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7508 def source_operation_response @source_operation_response end |
#stop_position ⇒ Google::Apis::DataflowV1b3::Position
Position defines a position within a collection of data. The value can be
either the end position, a key (used with ordered collections), a byte offset,
or a record index.
Corresponds to the JSON property stopPosition
7515 7516 7517 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7515 def stop_position @stop_position end |
#total_throttler_wait_time_seconds ⇒ Float
Total time the worker spent being throttled by external systems.
Corresponds to the JSON property totalThrottlerWaitTimeSeconds
7520 7521 7522 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7520 def total_throttler_wait_time_seconds @total_throttler_wait_time_seconds end |
#work_item_id ⇒ String
Identifies the WorkItem.
Corresponds to the JSON property workItemId
7525 7526 7527 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7525 def work_item_id @work_item_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7532 7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7532 def update!(**args) @completed = args[:completed] if args.key?(:completed) @counter_updates = args[:counter_updates] if args.key?(:counter_updates) @dynamic_source_split = args[:dynamic_source_split] if args.key?(:dynamic_source_split) @errors = args[:errors] if args.key?(:errors) @metric_updates = args[:metric_updates] if args.key?(:metric_updates) @progress = args[:progress] if args.key?(:progress) @report_index = args[:report_index] if args.key?(:report_index) @reported_progress = args[:reported_progress] if args.key?(:reported_progress) @requested_lease_duration = args[:requested_lease_duration] if args.key?(:requested_lease_duration) @source_fork = args[:source_fork] if args.key?(:source_fork) @source_operation_response = args[:source_operation_response] if args.key?(:source_operation_response) @stop_position = args[:stop_position] if args.key?(:stop_position) @total_throttler_wait_time_seconds = args[:total_throttler_wait_time_seconds] if args.key?(:total_throttler_wait_time_seconds) @work_item_id = args[:work_item_id] if args.key?(:work_item_id) end |