Class: Google::Apis::DataflowV1b3::WorkerHealthReportResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkerHealthReportResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
WorkerHealthReportResponse contains information returned to the worker in response to a health ping.
Instance Attribute Summary collapse
-
#report_interval ⇒ String
A positive value indicates the worker should change its reporting interval to the specified value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerHealthReportResponse
constructor
A new instance of WorkerHealthReportResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerHealthReportResponse
Returns a new instance of WorkerHealthReportResponse.
7660 7661 7662 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#report_interval ⇒ String
A positive value indicates the worker should change its reporting interval to
the specified value. The default value of zero means no change in report rate
is requested by the server.
Corresponds to the JSON property reportInterval
7658 7659 7660 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7658 def report_interval @report_interval end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7665 7666 7667 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7665 def update!(**args) @report_interval = args[:report_interval] if args.key?(:report_interval) end |