Class: Google::Apis::DataflowV1b3::WorkerHealthReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

WorkerHealthReportResponse contains information returned to the worker in response to a health ping.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkerHealthReportResponse

Returns a new instance of WorkerHealthReportResponse.



7652
7653
7654
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#report_intervalString

A positive value indicates the worker should change its reporting interval to the specified value. The default value of zero means no change in report rate is requested by the server. Corresponds to the JSON property reportInterval

Returns:

  • (String)


7650
7651
7652
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7650

def report_interval
  @report_interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7657
7658
7659
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7657

def update!(**args)
  @report_interval = args[:report_interval] if args.key?(:report_interval)
end