Class: Google::Apis::DataflowV1b3::WorkerLifecycleEvent
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkerLifecycleEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
A report of an event in a worker's lifecycle. The proto contains one event, because the worker is expected to asynchronously send each message immediately after the event. Due to this asynchrony, messages may arrive out of order (or missing), and it is up to the consumer to interpret. The timestamp of the event is in the enclosing WorkerMessage proto.
Instance Attribute Summary collapse
-
#container_start_time ⇒ String
The start time of this container.
-
#event ⇒ String
The event being reported.
-
#metadata ⇒ Hash<String,String>
Other stats that can accompany an event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerLifecycleEvent
constructor
A new instance of WorkerLifecycleEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerLifecycleEvent
Returns a new instance of WorkerLifecycleEvent.
7686 7687 7688 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7686 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_start_time ⇒ String
The start time of this container. All events will report this so that events
can be grouped together across container/VM restarts.
Corresponds to the JSON property containerStartTime
7674 7675 7676 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7674 def container_start_time @container_start_time end |
#event ⇒ String
The event being reported.
Corresponds to the JSON property event
7679 7680 7681 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7679 def event @event end |
#metadata ⇒ Hash<String,String>
Other stats that can accompany an event. E.g. "downloaded_bytes" : "123456"
Corresponds to the JSON property metadata
7684 7685 7686 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7684 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7691 7692 7693 7694 7695 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7691 def update!(**args) @container_start_time = args[:container_start_time] if args.key?(:container_start_time) @event = args[:event] if args.key?(:event) @metadata = args[:metadata] if args.key?(:metadata) end |