Class: Google::Apis::DataflowV1b3::WorkerMessageResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

A worker_message response allows the server to pass information to the sender.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkerMessageResponse

Returns a new instance of WorkerMessageResponse.



7870
7871
7872
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7870

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#streaming_scaling_report_responseGoogle::Apis::DataflowV1b3::StreamingScalingReportResponse

Contains per-user-worker streaming scaling recommendation from the backend. Corresponds to the JSON property streamingScalingReportResponse



7847
7848
7849
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7847

def streaming_scaling_report_response
  @streaming_scaling_report_response
end

#worker_health_report_responseGoogle::Apis::DataflowV1b3::WorkerHealthReportResponse

WorkerHealthReportResponse contains information returned to the worker in response to a health ping. Corresponds to the JSON property workerHealthReportResponse



7853
7854
7855
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7853

def worker_health_report_response
  @worker_health_report_response
end

#worker_metrics_responseGoogle::Apis::DataflowV1b3::ResourceUtilizationReportResponse

Service-side response to WorkerMessage reporting resource utilization. Corresponds to the JSON property workerMetricsResponse



7858
7859
7860
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7858

def worker_metrics_response
  @worker_metrics_response
end

#worker_shutdown_notice_responseGoogle::Apis::DataflowV1b3::WorkerShutdownNoticeResponse

Service-side response to WorkerMessage issuing shutdown notice. Corresponds to the JSON property workerShutdownNoticeResponse



7863
7864
7865
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7863

def worker_shutdown_notice_response
  @worker_shutdown_notice_response
end

#worker_thread_scaling_report_responseGoogle::Apis::DataflowV1b3::WorkerThreadScalingReportResponse

Contains the thread scaling recommendation for a worker from the backend. Corresponds to the JSON property workerThreadScalingReportResponse



7868
7869
7870
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7868

def worker_thread_scaling_report_response
  @worker_thread_scaling_report_response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7875
7876
7877
7878
7879
7880
7881
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 7875

def update!(**args)
  @streaming_scaling_report_response = args[:streaming_scaling_report_response] if args.key?(:streaming_scaling_report_response)
  @worker_health_report_response = args[:worker_health_report_response] if args.key?(:worker_health_report_response)
  @worker_metrics_response = args[:worker_metrics_response] if args.key?(:worker_metrics_response)
  @worker_shutdown_notice_response = args[:worker_shutdown_notice_response] if args.key?(:worker_shutdown_notice_response)
  @worker_thread_scaling_report_response = args[:worker_thread_scaling_report_response] if args.key?(:worker_thread_scaling_report_response)
end