Class: Google::Apis::DataflowV1b3::WorkerSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Provides data to pass through to the worker harness.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkerSettings

Returns a new instance of WorkerSettings.



8115
8116
8117
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_urlString

The base URL for accessing Google Cloud APIs. When workers access Google Cloud APIs, they logically do so via relative URLs. If this field is specified, it supplies the base URL to use for resolving these relative URLs. The normative algorithm used is defined by RFC 1808, "Relative Uniform Resource Locators". If not specified, the default value is "http://www.googleapis.com/" Corresponds to the JSON property baseUrl

Returns:

  • (String)


8083
8084
8085
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8083

def base_url
  @base_url
end

#reporting_enabledBoolean Also known as: reporting_enabled?

Whether to send work progress updates to the service. Corresponds to the JSON property reportingEnabled

Returns:

  • (Boolean)


8088
8089
8090
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8088

def reporting_enabled
  @reporting_enabled
end

#service_pathString

The Cloud Dataflow service path relative to the root URL, for example, " dataflow/v1b3/projects". Corresponds to the JSON property servicePath

Returns:

  • (String)


8095
8096
8097
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8095

def service_path
  @service_path
end

#shuffle_service_pathString

The Shuffle service path relative to the root URL, for example, "shuffle/ v1beta1". Corresponds to the JSON property shuffleServicePath

Returns:

  • (String)


8101
8102
8103
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8101

def shuffle_service_path
  @shuffle_service_path
end

#temp_storage_prefixString

The prefix of the resources the system should use for temporary storage. The supported resource type is: Google Cloud Storage: storage.googleapis.com/ bucket/object bucket.storage.googleapis.com/object Corresponds to the JSON property tempStoragePrefix

Returns:

  • (String)


8108
8109
8110
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8108

def temp_storage_prefix
  @temp_storage_prefix
end

#worker_idString

The ID of the worker running this pipeline. Corresponds to the JSON property workerId

Returns:

  • (String)


8113
8114
8115
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8113

def worker_id
  @worker_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8120
8121
8122
8123
8124
8125
8126
8127
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8120

def update!(**args)
  @base_url = args[:base_url] if args.key?(:base_url)
  @reporting_enabled = args[:reporting_enabled] if args.key?(:reporting_enabled)
  @service_path = args[:service_path] if args.key?(:service_path)
  @shuffle_service_path = args[:shuffle_service_path] if args.key?(:shuffle_service_path)
  @temp_storage_prefix = args[:temp_storage_prefix] if args.key?(:temp_storage_prefix)
  @worker_id = args[:worker_id] if args.key?(:worker_id)
end