Class: Google::Apis::DataflowV1b3::WorkerShutdownNotice
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkerShutdownNotice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Shutdown notification from workers. This is to be sent by the shutdown script of the worker VM so that the backend knows that the VM is being shut down.
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason for the worker shutdown.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerShutdownNotice
constructor
A new instance of WorkerShutdownNotice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerShutdownNotice
Returns a new instance of WorkerShutdownNotice.
8255 8256 8257 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8255 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reason ⇒ String
The reason for the worker shutdown. Current possible values are: "UNKNOWN":
shutdown reason is unknown. "PREEMPTION": shutdown reason is preemption. Other
possible reasons may be added in the future.
Corresponds to the JSON property reason
8253 8254 8255 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8253 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8260 8261 8262 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8260 def update!(**args) @reason = args[:reason] if args.key?(:reason) end |