Class: Google::Apis::DataflowV1b3::WorkerShutdownNotice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb

Overview

Shutdown notification from workers. This is to be sent by the shutdown script of the worker VM so that the backend knows that the VM is being shut down.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkerShutdownNotice

Returns a new instance of WorkerShutdownNotice.



8150
8151
8152
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonString

The reason for the worker shutdown. Current possible values are: "UNKNOWN": shutdown reason is unknown. "PREEMPTION": shutdown reason is preemption. Other possible reasons may be added in the future. Corresponds to the JSON property reason

Returns:

  • (String)


8148
8149
8150
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8148

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8155
8156
8157
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8155

def update!(**args)
  @reason = args[:reason] if args.key?(:reason)
end