Class: Google::Apis::DataflowV1b3::WorkerShutdownNotice
- Inherits:
-
Object
- Object
- Google::Apis::DataflowV1b3::WorkerShutdownNotice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataflow_v1b3/classes.rb,
lib/google/apis/dataflow_v1b3/representations.rb,
lib/google/apis/dataflow_v1b3/representations.rb
Overview
Shutdown notification from workers. This is to be sent by the shutdown script of the worker VM so that the backend knows that the VM is being shut down.
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason for the worker shutdown.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkerShutdownNotice
constructor
A new instance of WorkerShutdownNotice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkerShutdownNotice
Returns a new instance of WorkerShutdownNotice.
8142 8143 8144 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reason ⇒ String
The reason for the worker shutdown. Current possible values are: "UNKNOWN":
shutdown reason is unknown. "PREEMPTION": shutdown reason is preemption. Other
possible reasons may be added in the future.
Corresponds to the JSON property reason
8140 8141 8142 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8140 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8147 8148 8149 |
# File 'lib/google/apis/dataflow_v1b3/classes.rb', line 8147 def update!(**args) @reason = args[:reason] if args.key?(:reason) end |